@@ -1,9 +1,9 @@
 ;;; cd-tool.el --- Play  CDs from Emacs
-;;;$Id: cd-tool.el,v 17.0 2002/11/23 01:28:58 raman Exp $
+;;;$Id: cd-tool.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
 ;;;Emacs front-end to CDTool
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2002, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -29,31 +29,38 @@
 ;;; Provide an emacs front-end to cdtool.
 ;;; cdtool can be obtained as an rpm
 ;;; check using rpmfind
-;;; or from its home site at 
+;;; or from its home site at
 ;;;   sunsite.unc.edu /pub/Linux/apps/sound/cdrom/cli
-;;; This module also provides the ability to play or save 
+;;; This module also provides the ability to play or save
 ;;; clips from a CD if you have cdda2wav installed.
 ;;; cdda2wav is a cd to wav convertor.
 ;;;
-
+;;; Code:
 ;;}}}
 ;;{{{ required packages
 
-(eval-when-compile (require 'cl))
+(require 'cl)
+(declaim  (optimize  (safety 0) (speed 3)))
 
 ;;}}}
-;;{{{ top level 
+;;{{{ top level
 
 ;;; Code:
 
+(defcustom cd-tool-start-command "cdstart"
+  "*Name of cdstart command; most likely either \"cdstart\" or \"cdplay\"."
+  :options '("cdstart" "cdplay")
+  :group 'cd-tool
+  :type 'string)
+
 (defvar cd-tool-message
   " +Next  - Previous  p play s stop = shuffle i info e eject t track"
-  "Short message to display if user hits invalid key.")              
-
+  "Short message to display if user hits invalid key.")
+;;;###autoload
 (defun cd-tool ()
   "Front-end to CDTool.
 Bind this function to a convenient key-
-Emacspeak users automatically have 
+Emacspeak users automatically have
 this bound to <DEL> in the emacspeak keymap.
 
 Key     Action
@@ -76,27 +83,26 @@ cap C   Save clip to disk
     (while (null command)
       (setq command
             (case (read-char "CD Action? ")
-              (?+ "cdstart +")
-              (?> "cdstart +")
-              (?. "cdstart +")
-              (?- "cdstart -")
-              (?< "cdstart -")
-              (?, "cdstart -")
-              (?t (format "cdstart %s"
-                          (read-from-minibuffer "Enter track
-number: ")))
-              (?p "cdstart")
+              (?+ (concat cd-tool-start-command " +"))
+              (?> (concat cd-tool-start-command " +"))
+              (?. (concat cd-tool-start-command " +"))
+              (?- (concat cd-tool-start-command " -"))
+              (?< (concat cd-tool-start-command " -"))
+              (?, (concat cd-tool-start-command " -"))
+              (?t (format (concat cd-tool-start-command " %s")
+                          (read-from-minibuffer "Enter track number: ")))
+              (?p cd-tool-start-command)
               (?s "cdstop")
               (?= "cdshuffle")
               (?\ "cdpause")
-              (?r "cdstart")
+              (?r cd-tool-start-command)
               (?i "cdir ")
               (?e "cdeject")
               (?c (cd-tool-get-clip-command))
               (?C (cd-tool-get-clip-command 'save))
               (otherwise (message cd-tool-message)
-			 (sit-for 5)
-			 nil))))
+                         (sit-for 5)
+                         nil))))
     (shell-command
      (format "%s &"
              command ))))
@@ -125,7 +131,7 @@ number: ")))
   (let ((filename (when save
                     (read-file-name
                      "File name to save clip to: ")))
-        (track (read-from-minibuffer(format 
+        (track (read-from-minibuffer(format
                                      "Track to clip%s: "
                                      (if save  "to file" ""))
                                     (car cd-tool-clip-track-history) ;INITIAL-CONTENTS
@@ -146,10 +152,10 @@ number: ")))
     (pushnew  skip cd-tool-clip-skip-history)
     (pushnew duration cd-tool-clip-duration-history)
     (format "%s %s -t %s -o %s -d %s %s"
-	    cd-tool-clipper
-	    cd-tool-clipper-default-args 
-	    track skip duration
-	    (if save filename "-e"))))
+            cd-tool-clipper
+            cd-tool-clipper-default-args
+            track skip duration
+            (if save filename "-e"))))
 
 ;;}}}
 
