@@ -1,23 +1,23 @@
 ;;; dtk-interp.el --- Language specific (e.g. TCL) interface to speech server
-;;; $Id: dtk-interp.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: dtk-interp.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Interfacing to the speech server
 ;;; Keywords: TTS, Dectalk, Speech Server
-;;{{{  LCD Archive entry: 
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
-;;; All Rights Reserved. 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -38,8 +38,6 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
 ;;{{{ introduction
 
 ;;; All requests to the speech server are factored out into
@@ -50,6 +48,39 @@
 ;;; but gives us the flexibility to call out to different
 ;;; speech servers.
 
+;;}}}
+;;{{{ requires
+
+;;;Code:
+
+(require 'cl)
+(declaim  (optimize  (safety 0) (speed 3)))
+
+;;}}}
+;;{{{ macros
+
+(defmacro tts-with-punctuations (setting &rest body)
+  "Safely set punctuation mode for duration of body form."
+  (`
+   (progn
+     (declare (special dtk-punctuation-mode))
+     (let    ((save-punctuation-mode dtk-punctuation-mode))
+       (unwind-protect
+           (progn
+             (unless (eq (, setting) save-punctuation-mode)
+               (process-send-string dtk-speaker-process
+                                    (format "tts_set_punctuations %s  \n "
+                                            (, setting)))
+               (setq dtk-punctuation-mode (, setting)))
+             (,@ body)
+             (dtk-force))
+         (unless (eq  (, setting)  save-punctuation-mode)
+           (setq dtk-punctuation-mode save-punctuation-mode)
+           (process-send-string dtk-speaker-process
+                                (format "tts_set_punctuations %s  \n "
+                                        dtk-punctuation-mode ))
+           (dtk-force)))))))
+
 ;;}}}
 ;;{{{ silence
 
@@ -82,14 +113,14 @@
                                       &optional target step force)
   (declare (special dtk-speaker-process))
   (process-send-string dtk-speaker-process
-                       (format "n %s %s %s %s %s%s\n"
+                       (format "n %s %s %s %s %s %s\n"
                                instrument pitch duration
                                (or target 0)
                                (or step 5)
                                (if force "\nd" ""))))
 
 ;;}}}
-;;{{{  queue 
+;;{{{  queue
 
 (defsubst dtk-interp-queue (text)
   (declare (special dtk-speaker-process))
@@ -141,12 +172,12 @@
 
 (defsubst dtk-interp-sync()
   (declare (special dtk-speaker-process
-                    dtk-punctuation-mode dtk-speech-rate 
+                    dtk-punctuation-mode dtk-speech-rate
                     dtk-capitalize dtk-split-caps
                     dtk-allcaps-beep))
   (process-send-string dtk-speaker-process
                        (format "tts_sync_state %s %s %s %s %s \n"
-                               dtk-punctuation-mode 
+                               dtk-punctuation-mode
                                (if dtk-capitalize 1  0 )
                                (if dtk-allcaps-beep 1  0 )
                                (if dtk-split-caps 1 0 )
@@ -160,9 +191,42 @@
   (process-send-string dtk-speaker-process
                        (format "l {%s}\n" letter )))
 
+;;}}}
+;;{{{  language
+
+(defsubst dtk-interp-next-language (&optional say_it)
+  (declare (special dtk-speaker-process))
+  (process-send-string dtk-speaker-process
+                       (format "set_next_lang %s\n" say_it)))
+
+(defsubst dtk-interp-previous-language (&optional say_it)
+  (declare (special dtk-speaker-process))
+  (process-send-string dtk-speaker-process
+                       (format "set_previous_lang %s\n" say_it )))
+
+(defsubst dtk-interp-language (language say_it)
+  (declare (special dtk-speaker-process))
+  (process-send-string dtk-speaker-process
+                       (format "set_lang %s %s \n" language say_it)))
+
+(defsubst dtk-interp-preferred-language (alias language)
+  (declare (special dtk-speaker-process))
+  (process-send-string dtk-speaker-process
+                       (format "set_preferred_lang %s %s \n" alias language )))
+
+(defsubst dtk-interp-list-language ()
+  (declare (special dtk-speaker-process))
+  (process-send-string dtk-speaker-process
+                       (format "list_lang\n" )))
+
 ;;}}}
 ;;{{{  rate
 
+(defsubst dtk-interp-say-version ()
+  "Speak version."
+  (declare (special dtk-speaker-process))
+  (process-send-string dtk-speaker-process "version\n"))
+
 (defsubst dtk-interp-set-rate (rate)
   (declare (special dtk-speaker-process))
   (process-send-string dtk-speaker-process
@@ -179,7 +243,7 @@
                                factor)))
 
 ;;}}}
-;;{{{  split caps 
+;;{{{  split caps
 
 (defsubst dtk-interp-toggle-split-caps (dtk-split-caps)
   (declare (special dtk-speaker-process))
@@ -192,7 +256,7 @@
 
 (defsubst dtk-interp-toggle-capitalization (dtk-capitalize)
   (declare (special dtk-speaker-process))
-  (process-send-string dtk-speaker-process 
+  (process-send-string dtk-speaker-process
                        (format "tts_capitalize  %s\n"
                                (if dtk-capitalize  1 0 ))))
 
@@ -201,7 +265,7 @@
 
 (defsubst dtk-interp-toggle-allcaps-beep  (dtk-allcaps-beep)
   (declare (special dtk-speaker-process))
-  (process-send-string dtk-speaker-process 
+  (process-send-string dtk-speaker-process
                        (format "tts_allcaps_beep  %s\n"
                                (if dtk-allcaps-beep  1 0
                                    ))))
@@ -211,7 +275,7 @@
 
 (defsubst dtk-interp-set-punctuations(mode)
   (declare (special dtk-speaker-process))
-  (process-send-string dtk-speaker-process  
+  (process-send-string dtk-speaker-process
                        (format "tts_set_punctuations %s\n"
                                mode)))
 
@@ -246,7 +310,6 @@
 ;;; local variables:
 ;;; folded-file: t
 ;;; byte-compile-dynamic: t
-;;; byte-compile-dynamic: nil
-;;; end: 
+;;; end:
 
 ;;}}}
