@@ -1,6 +1,6 @@
-;;; emacspeak-analog.el --- Speech-enable
-;;; $Id: emacspeak-analog.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $
+;;; emacspeak-analog.el --- Speech-enable analog -- a log viewer
+;;; $Id: emacspeak-analog.el 4150 2006-08-30 00:25:40Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for ANALOG log analyzer 
 ;;; Keywords: Emacspeak, analog 
 ;;{{{  LCD Archive entry:
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2006-08-29 17:25:40 -0700 (Tue, 29 Aug 2006) $ |
+;;;  $Revision: 4150 $ |
 ;;; Location undetermined
 ;;;
 
@@ -38,7 +38,9 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+
 ;;{{{  Introduction:
+;;; Commentary:
 
 ;;; Speech-enables package analog --convenient log analyzer 
 
@@ -46,15 +48,8 @@
 ;;{{{ required modules
 
 ;;; Code:
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'backquote)
-(eval-when-compile
-  (require 'emacspeak-speak)
-  (require 'emacspeak-sounds))
-
+(require 'cl)
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ advice interactive commands
 (defadvice analog (after emacspeak pre act comp)
@@ -92,6 +87,12 @@
             (emacspeak-auditory-icon 'select-object))))))
 
 ;;}}}
+;;{{{ voice setup 
+(voice-setup-add-map
+ '(
+   (analog-entry-header-face voice-bolden)
+   ))
+;;}}}
 ;;{{{ field navigation
 
 ;;; You can add a fields property that holds a list of field start
@@ -223,13 +224,15 @@ Speak field or char moved to."
 
 ;;}}}
 ;;{{{ key bindings
+(when (boundp 'analog-mode-map)
+  (declaim (special analog-mode-map))
+  (define-key analog-mode-map '[left]
+    'emacspeak-analog-backward-field-or-char)
+  (define-key analog-mode-map '[right] 'emacspeak-analog-forward-field-or-char)
+  (define-key analog-mode-map '[up] 'emacspeak-analog-previous-line)
+  (define-key analog-mode-map '[down] 'emacspeak-analog-next-line)
+  )
 
-(declaim (special analog-mode-map))
-(define-key analog-mode-map '[left]
-  'emacspeak-analog-backward-field-or-char)
-(define-key analog-mode-map '[right] 'emacspeak-analog-forward-field-or-char)
-(define-key analog-mode-map '[up] 'emacspeak-analog-previous-line)
-(define-key analog-mode-map '[down] 'emacspeak-analog-next-line)
 (defun emacspeak-analog-update-edit-keys ()
   "We define keys that invoke editting commands to invoke
 emacspeak-speak-and-skip-extent-upto-char "
@@ -237,12 +240,12 @@ emacspeak-speak-and-skip-extent-upto-char "
   (mapcar 
    #'(lambda (cmd)
        (loop for k in
-	     (where-is-internal cmd)
-	     do
-	     (define-key analog-mode-map k
-	       'emacspeak-speak-and-skip-extent-upto-this-char )))
+             (where-is-internal cmd)
+             do
+             (define-key analog-mode-map k
+               'emacspeak-speak-and-skip-extent-upto-this-char )))
    (list 'emacspeak-self-insert-command
-	 'completion-separator-self-insert-command)))
+         'completion-separator-self-insert-command)))
 
 ;;}}}
 (provide 'emacspeak-analog)
@@ -250,7 +253,7 @@ emacspeak-speak-and-skip-extent-upto-char "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
