@@ -1,6 +1,6 @@
-;;; emacspeak-ansi-color.el --- Voiceify ansi-color 
-;;; $Id: emacspeak-ansi-color.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $
+;;; emacspeak-ansi-color.el --- Speech-enable ansi-color terminal
+;;; $Id: emacspeak-ansi-color.el 4502 2007-05-01 00:29:30Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for ansi-color
 ;;; Keywords: Emacspeak, ansi-color
 ;;{{{  LCD Archive entry:
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-04-30 17:29:30 -0700 (Mon, 30 Apr 2007) $ |
+;;;  $Revision: 4502 $ |
 ;;; Location undetermined
 ;;;
 
@@ -41,6 +41,7 @@
 ;;{{{  Introduction:
 
 ;;; Commentary:
+
 ;;; Module ansi-color (bundled with Emacs 21)
 ;;; handles ansi escape sequences and turns them into
 ;;; appropriate faces.
@@ -51,14 +52,7 @@
 ;;{{{ required modules
 
 ;;; Code:
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-speak)
-(require 'dtk-css-speech)
-(require 'voice-lock)
-(require 'emacspeak-sounds)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ color to voice
 
@@ -74,15 +68,15 @@
           (when color
             (position  color ansi-color-names-vector
                        :test #'string-equal)))
-         (acss-spec nil)
+         (style nil)
          (color-parameter nil)
          (style-parameter nil))
     (setq voice-name
           (intern (format "emacspeak-ansi-color-%s-%s"
-                          color
+                          (if color color "default")
                           (if style style "default"))))
-    (unless (dtk-voice-defined-p voice-name)
-      (setq acss-spec (make-dtk-speech-style ))
+    (unless (tts-voice-defined-p voice-name)
+      (setq style (make-acss ))
       (setq style-parameter
             (if style-index
                 (+ 1 style-index)
@@ -91,11 +85,11 @@
             (if color-index
                 (+ 1 color-index)
               1))
-      (setf (dtk-speech-style-average-pitch acss-spec) color-parameter)
-      (setf (dtk-speech-style-pitch-range acss-spec) style-parameter)
-      (setf (dtk-speech-style-richness acss-spec) color-parameter)
-      (setf (dtk-speech-style-stress acss-spec) style-parameter)
-      (dtk-define-voice-from-speech-style voice-name acss-spec))
+      (setf (acss-average-pitch style) color-parameter)
+      (setf (acss-pitch-range style) color-parameter)
+      (setf (acss-richness style) color-parameter)
+      (setf (acss-stress style) color-parameter)
+      (tts-define-voice-from-speech-style voice-name style))
     voice-name))
 
 (defadvice ansi-color-set-extent-face (after emacspeak pre act comp)
@@ -105,11 +99,11 @@
          (start (overlay-start extent))
          (end (overlay-end extent))
          (voice (when (listp face)
-		  (emacspeak-ansi-color-to-voice face))))
+                  (emacspeak-ansi-color-to-voice face))))
     (when voice
       (ems-modify-buffer-safely
        (put-text-property start end
-			  'personality voice)))))
+                          'personality voice)))))
 
 ;;}}}
 ;;{{{ advice interactive commands
@@ -122,7 +116,7 @@
     (message "Ansi escape sequences will be processed.")))
 
 (defadvice ansi-color-for-comint-mode-off (after emacspeak
-						 pre act comp)
+                                                 pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'off)
