@@ -1,6 +1,6 @@
 ;;; emacspeak-auctex.el --- Speech enable AucTeX -- a powerful TeX/LaTeX authoring environment
-;;; $Id: emacspeak-auctex.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-auctex.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; DescriptionEmacspeak extensions for auctex-mode
 ;;; Keywords:emacspeak, audio interface to emacs AUCTEX
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -37,11 +37,9 @@
 ;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ;;}}}
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'voice-lock)
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
+;;{{{ Required modules 
+(require 'emacspeak-preamble)
+;;}}}
 ;;{{{  Introduction:
 
 ;;; Provide additional advice to auctex
@@ -49,31 +47,29 @@
 ;;}}}
 ;;{{{ voice locking:
 
-(defvar tex-voice-lock-keywords
-  (list
-   '("\\(\\\\\\([a-zA-Z@]+\\|.\\)\\)" 1 voice-lock-keyword-personality t)
-   '("{\\\\em\\([^}]+\\)}" 1 voice-lock-italic-personality t)
-   '("{\\\\bf\\([^}]+\\)}" 1 voice-lock-bold-personality t)
-   '("^[ \t\n]*\\\\def[\\\\@]\\(\\w+\\)" 1 voice-lock-function-name-personality t)
-   '("\\\\\\(begin\\|end\\){\\([a-zA-Z0-9\\*]+\\)}"
-     2 voice-lock-function-name-personality t)
-   '("[^\\\\]\\$\\([^$]*\\)\\$" 1 voice-lock-string-personality t)
-					;   '("\\$\\([^$]*\\)\\$" 1 voice-lock-string-personality t)
-   )
-  "Additional expressions to highlight in TeX mode.")
-
-(mapcar 
- (function
-  (lambda (mode)
-    (voice-lock-set-major-mode-keywords mode 'tex-voice-lock-keywords)))
- (list 
-  'plain-tex-mode  
-  'latex-mode      
-  'slitex-mode     
-  'latex2e-mode))
+;;; faces from AUCTeX 11
+(voice-setup-add-map
+ '(
+   (font-latex-bold-face voice-bolden)
+   (font-latex-doctex-documentation-face voice-monotone-medium)
+   (font-latex-doctex-preprocessor-face voice-brighten-medium)
+   (font-latex-italic-face voice-animate)
+   (font-latex-math-face voice-brighten-extra)
+   (font-latex-sedate-face voice-smoothen)
+   (font-latex-string-face voice-lighten)
+   (font-latex-subscript-face voice-smoothen)
+   (font-latex-superscript-face voice-brighten)
+   (font-latex-title-1-face voice-bolden-extra)
+   (font-latex-title-2-face voice-bolden-medium)
+   (font-latex-title-3-face voice-bolden)
+   (font-latex-title-4-face voice-smoothen-extra)
+   (font-latex-verbatim-face voice-monotone)
+   (font-latex-warning-face voice-bolden-and-animate)
+   ))
 
 ;;}}}
 ;;{{{  Marking structured objects:
+
 (defadvice LaTeX-fill-paragraph (after emacspeak pre act  comp)
   "Provide auditory feedback."
   (when (interactive-p)
@@ -109,7 +105,6 @@ Provide auditory feedback after formatting region"
     (message "Reformatted region"))
    ((not (interactive-p)) ad-do-it))
   ad-return-value)
-    
 
 ;;}}}
 ;;{{{  delimiter matching:
@@ -130,6 +125,16 @@ Provide auditory feedback after formatting region"
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-read-previous-line)))
 
+(defadvice TeX-insert-quote(around emacspeak pre act com)
+  "Speak quotes that were inserted."
+  (cond
+   ((interactive-p)
+    (let ((orig (point)))
+      ad-do-it
+      (emacspeak-speak-region orig (point))))
+   (t ad-do-it))
+  ad-return-value)
+
 (defadvice TeX-insert-dollar (after emacspeak pre act comp)
   "Speak what you inserted"
   (when (interactive-p)
@@ -138,13 +143,18 @@ Provide auditory feedback after formatting region"
 ;;}}}
 ;;{{{  Inserting structures
 
+(defadvice TeX-newline (after emacspeak pre act comp)
+  "Provide auditory feedback to indicate indentation."
+  (when (interactive-p)
+    (emacspeak-speak-line)))
+
 (defadvice LaTeX-insert-item (after emacspeak pre act)
   "Provide auditory feedback. "
   (when (interactive-p)
     (emacspeak-speak-line )))
 
 (defadvice LaTeX-environment (after emacspeak pre act)
-  "Provide auditory feedback, by speaking 
+  "Provide auditory feedback, by speaking
 the opening line of the newly inserted environment. "
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)
@@ -184,7 +194,6 @@ the opening line of the newly inserted environment. "
     (emacspeak-auditory-icon 'select-object)))
 
 ;;}}}
-
 ;;{{{  Debugging tex
 
 (defadvice TeX-next-error (after emacspeak pre act)
@@ -201,28 +210,32 @@ the opening line of the newly inserted environment. "
 (add-hook  'LaTeX-mode-hook
            (function
             (lambda ()
-	      (declare (special imenu-generic-expression
-				imenu-create-index-function))
-	      (require 'imenu)
-	      (setq imenu-create-index-function 'imenu-default-create-index-function)
-	      (setq imenu-generic-expression
-		    '(
-		      (nil
-		       "^ *\\\\\\(sub\\)*section{\\([^}]+\\)"
-		       2))))))
+              (declare (special imenu-generic-expression
+                                imenu-create-index-function))
+              (require 'imenu)
+              (setq imenu-create-index-function 'imenu-default-create-index-function)
+              (setq imenu-generic-expression
+                    '(
+                      (nil
+                       "^ *\\\\\\(sub\\)*section{\\([^}]+\\)"
+                       2))))))
               
 
 ;;}}}
 ;;{{{ advice font changes 
+
 (defadvice TeX-font (around emacspeak pre act comp)
   "Speak the font we inserted"
   (cond 
    ((interactive-p)
     (let ((orig (point)))
       ad-do-it
-      (emacspeak-speak-region orig (point))))
+      (if (ad-get-arg 0)
+          (emacspeak-speak-line)
+        (emacspeak-speak-region orig (point)))))
    (t ad-do-it))
   ad-return-value)
+
 ;;}}}
 (provide  'emacspeak-auctex)
 ;;{{{  emacs local variables 
