@@ -1,6 +1,6 @@
 ;;; emacspeak-bookmark.el --- Speech enable Emacs' builtin bookmarks
-;;; $Id: emacspeak-bookmark.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-bookmark.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to bookmark
 ;;; Keywords: Emacspeak, Speak, Spoken Output, bookmark
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2002, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,12 +40,7 @@
 
 ;;{{{  Required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
-(eval-when (compile)
-  (require 'bookmark))
+(require 'emacspeak-preamble)
 
 ;;}}}
 ;;{{{  Introduction 
