@@ -1,14 +1,14 @@
 ;;; emacspeak-browse-kill-ring.el --- browse-kill-ring  for emacspeak desktop
-;;; $Id: emacspeak-browse-kill-ring.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-browse-kill-ring.el 4074 2006-08-19 17:48:45Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for BROWSE-KILL-RING
 ;;; Keywords: Emacspeak, browse-kill-ring
 ;;{{{  LCD Archive entry:
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2006-08-19 10:48:45 -0700 (Sat, 19 Aug 2006) $ |
+;;;  $Revision: 4074 $ |
 ;;; Location undetermined
 ;;;
 
@@ -47,15 +47,7 @@
 ;;{{{ required modules
 
 ;;; Code:
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(require 'emacspeak-speak)
-(require 'emacspeak-keymap)
-(require 'voice-lock)
-(require 'emacspeak-sounds)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ speech-enable interactive commands
 
@@ -67,68 +59,68 @@
     (emacspeak-auditory-icon 'unmodified-object)))
 
 (defadvice browse-kill-ring-insert (after
-				    emacspeak pre act comp)
+                                    emacspeak pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'yank-object)))
 
 (defadvice browse-kill-ring-delete (after
-				    emacspeak pre act comp)
+                                    emacspeak pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'delete-object)))
 (defadvice browse-kill-ring-forward (after
-				     emacspeak pre
-				     act comp)
+                                     emacspeak pre
+                                     act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice browse-kill-ring-previous (after
-				      emacspeak pre
-				      act comp)
+                                      emacspeak pre
+                                      act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice browse-kill-ring-quit (after
-				  emacspeak pre act comp)
+                                  emacspeak pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice browse-kill-ring-edit (after
-				  emacspeak pre
-				  act comp)
+                                  emacspeak pre
+                                  act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)))
 (defadvice browse-kill-ring-edit-finish (after
-					 emacspeak pre
-					 act comp)
+                                         emacspeak pre
+                                         act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)))
 
 (defadvice browse-kill-ring-occur (after
-				   emacspeak pre
-				   act comp)
+                                   emacspeak pre
+                                   act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)))
 
 (defadvice browse-kill-ring-update (after
-				    emacspeak pre
-				    act comp)
+                                    emacspeak pre
+                                    act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'task-done)))
 (defadvice browse-kill-ring (after
-			     emacspeak pre
-			     act comp)
+                             emacspeak pre
+                             act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)
@@ -148,16 +140,16 @@
 ;;; end:
 
 (defadvice browse-kill-ring-search-forward (after
-					    emacspeak pre
-					    act comp)
+                                            emacspeak pre
+                                            act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice browse-kill-ring-search-backward (after
-					     emacspeak pre
-					     act comp)
+                                             emacspeak pre
+                                             act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-speak-line)
