@@ -1,6 +1,6 @@
 ;;; emacspeak-bs.el --- speech-enable bs buffer selection
-;;; $Id: emacspeak-bs.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-bs.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable bs
 ;;; Keywords: Emacspeak, Audio Desktop
 ;;{{{  LCD Archive entry:
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2002, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,12 +40,8 @@
 
 ;;{{{ required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
-(require 'emacspeak-fix-interactive)
-
+(require 'emacspeak-preamble)
+(require 'bs)
 ;;}}}
 ;;{{{  Introduction:
 
@@ -77,14 +73,14 @@
             this-buffer-modified-p
             this-buffer-size
             this-buffer-mode-name
-	    mode-name
+            mode-name
             this-buffer-directory
             (dtk-stop-immediately nil))
         (put-text-property 0 (length document)
-                           'personality 'paul-smooth
+                           'personality voice-smoothen
                            document)
         (put-text-property 0 (length with)
-                           'personality 'paul-smooth with)
+                           'personality voice-smoothen  with)
         (save-excursion
           (set-buffer buffer)
           (setq this-buffer-read-only buffer-read-only)
@@ -101,8 +97,8 @@
         (when this-buffer-modified-p (dtk-tone 700 70))
         (when this-buffer-read-only (dtk-tone 250 50))
         (put-text-property 0 (length this-buffer-mode-name)
-			   'personality 'paul-smooth
-			   this-buffer-mode-name)
+                           'personality voice-smoothen
+                           this-buffer-mode-name)
         (dtk-speak
          (concat 
           name
@@ -136,7 +132,7 @@
   "Speech-enable bs mode"
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)
-    (emacspeak-spea-mode-line)))
+    (emacspeak-speak-mode-line)))
 (defadvice bs-set-configuration-and-refresh (after emacspeak pre act comp)
   "Speech-enable bs mode"
   (when (interactive-p)
