@@ -1,6 +1,6 @@
 ;;; emacspeak-buff-sel.el --- Speech enable buf-sel -- an alternative technique for switching buffers
-;;; $Id: emacspeak-buff-sel.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-buff-sel.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak pronunciation dictionaries
 ;;; Keywords:emacspeak, audio interface to emacs interactive buffer selection
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -37,19 +37,22 @@
 
 ;;}}}
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-sounds)
-(require 'emacspeak-speak)
 ;;{{{  Introduction
 
 ;;; Advice for buff-sel
 
+;;}}}
+;;{{{ 
+;;; Code:
+
+(require 'emacspeak-preamble)
+
 ;;}}}
 ;;{{{ Advice for interactive commands.
 (defadvice select-buffer (after emacspeak pre act comp)
   "Provide auditory feedback"
   (when (interactive-p)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice select-buffer-other-window (after emacspeak pre act comp)
