@@ -1,6 +1,6 @@
 ;;; emacspeak-c.el --- Speech enable CC-mode and friends -- supports C, C++, Java 
-;;; $Id: emacspeak-c.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-c.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for C and C++ mode
 ;;; Keywords:emacspeak, audio interface to emacs C, C++
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -36,26 +36,21 @@
 ;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ;;}}}
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(eval-when-compile (require 'dtk-speak)
-                   (require 'emacspeak-speak)
-                   (require 'emacspeak-sounds)
-                   (and (locate-library "cc-mode")
-                        (require 'cc-mode )))
 ;;{{{ Introduction:
 
+;;; Commentary:
+
 ;;; Make some of C and C++ mode more emacspeak friendly
 ;;; Works with both boring c-mode 
 ;;; and the excellent cc-mode
 
 ;;}}}
-;;{{{  emacs 19.30
+;;{{{  Required modules
 
-;;; things got renamed in 19.30.
+;;; Code:
 
-(when  (string-lessp emacs-version "19.29")
-  (defalias 'c-guess-basic-syntax 'c-guess-basic-semantics))
+(require 'emacspeak-preamble)
+(require 'cc-mode)
 
 ;;}}}
 ;;{{{ advice electric deletion
@@ -72,17 +67,11 @@
 
 (defadvice c-electric-backspace (around emacspeak pre act)
   "Speak character you're deleting."
-  (declare (special
-            emacspeak-backward-delete-char-speak-deleted-char
-            emacspeak-backward-delete-char-speak-current-char))
   (cond
    ((interactive-p )
     (dtk-tone 500 30 'force)
-    (and emacspeak-backward-delete-char-speak-deleted-char
-	 (emacspeak-speak-this-char (preceding-char )))
-    ad-do-it
-    (and emacspeak-backward-delete-char-speak-current-char
-	 (emacspeak-speak-this-char (preceding-char ))))
+    (emacspeak-speak-this-char (preceding-char ))
+    ad-do-it)
    (t ad-do-it))
   ad-return-value)
 
@@ -202,7 +191,7 @@
     (let ((dtk-stop-immediately nil))
       (emacspeak-auditory-icon 'mark-object)
       (dtk-speak "Marked function containing %s lines "
-		 (count-lines (point) (mark)))
+                 (count-lines (point) (mark)))
       (emacspeak-speak-line ))))
 
 ;;}}}
@@ -239,7 +228,7 @@
   (emacspeak-auditory-icon 'large-movement)
   (let  ((opoint (point))
          (semantics (c-guess-basic-syntax )))
-         ;;; skip across a comment
+;;; skip across a comment
     (cond
      ((or (assq 'c semantics )
           (assq 'comment-intro semantics ))
@@ -271,7 +260,7 @@ this level")
   (emacspeak-auditory-icon 'large-movement)
   (let  ((opoint (point))
          (semantics (c-guess-basic-syntax )))
-         ;;; skip across a comment
+;;; skip across a comment
     (cond
      ((or (assq 'c semantics )
           (assq 'comment-intro semantics ))
@@ -422,6 +411,11 @@ and their meanings. ")
     (emacspeak-auditory-icon 'fill-object)
     (message "Indented function")))
 
+(defadvice c-indent-command (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-speak-line )))
+
 ;;}}}
 ;;{{{ Additional keybindings:
 
@@ -449,6 +443,14 @@ and their meanings. ")
                       (or dtk-allcaps-beep
                           (dtk-toggle-allcaps-beep)))))
 
+;;}}}
+;;{{{ personalities 
+
+(voice-setup-add-map
+ '(
+   (c-nonbreakable-space-face voice-brighten)
+   ))
+
 ;;}}}
 (provide  'emacspeak-c)
 ;;{{{  emacs local variables 
