@@ -1,6 +1,6 @@
 ;;; emacspeak-checkdoc.el --- Speech-enable checkdoc
-;;; $Id: emacspeak-checkdoc.el,v 17.0 2002/11/23 01:28:58 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-checkdoc.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:Speech-enable checkdoc
 ;;; Keywords: Emacspeak, Speak, Spoken Output, maintain code 
 ;;{{{  LCD Archive entry:
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -48,11 +48,7 @@
 
 ;;}}}
 ;;; Code:
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(eval-when-compile (require 'dtk-speak)
-                   (require 'emacspeak-speak))
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ implementation
 
@@ -62,10 +58,10 @@
    ((interactive-p)
     (save-match-data
       (ad-enable-advice  'read-event 'before 'emacspeak-checkdoc )
-      (ad-activate-on 'read-event)
+      (ad-activate 'read-event)
       ad-do-it
       (ad-disable-advice  'read-event 'before 'emacspeak-checkdoc )
-      (ad-activate-off 'read-event)))
+      (ad-deactivate 'read-event)))
    (t  ad-do-it))
   ad-return-value)
 
