@@ -1,5 +1,5 @@
 ;;; emacspeak-compile.el --- Speech enable  navigation of  compile errors, grep matches
-;;; $Author: raman $ 
+;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extensions to  the compile package 
 ;;; Keywords: Emacspeak compile
 ;;{{{  LCD Archive entry: 
@@ -7,14 +7,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:58 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -37,11 +37,6 @@
 ;;}}}
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'emacspeak-speak)
-
 ;;{{{  Introduction:
 
 ;;; Commentary:
@@ -50,45 +45,62 @@
 ;;; It is an example of how a little amount of code can make Emacspeak even better.
 ;;; Code:
 
+;;}}}
+;;{{{ Required modules
+(require 'emacspeak-preamble)
+
+;;}}}
+;;{{{ Personalities  
+(voice-setup-add-map
+ '(
+   (compilation-line-number voice-smoothen)
+   (compilation-column-number voice-smoothen)
+   (compilation-info voice-lighten)
+   (compilation-error voice-animate-extra)
+   (compilation-warning voice-animate)
+   ))
+
 ;;}}}
 ;;{{{  functions
 
 (defun emacspeak-compilation-speak-error ()
   "Speech feedback about the compilation error. "
   (interactive)
-  (let ((dtk-stop-immediately nil))
+  (let ((dtk-stop-immediately nil)
+        (emacspeak-show-point t))
     (emacspeak-speak-line)))
 
 ;;}}}
-;;{{{  advice 
-
-(defadvice next-error (after  emacspeak pre act )
-  "Speak the line containing the error. "
-  (when (interactive-p)
-    (emacspeak-compilation-speak-error)))
-  
-
-(defadvice previous-error (after emacspeak pre act )
-  "Speak the line containing the error. "
-  (when (interactive-p)
-    (emacspeak-compilation-speak-error)))
-  
-
-(defadvice compile-goto-error (after emacspeak pre act)
-  "Speak the compilation error. "
-  (when (interactive-p)
-    (emacspeak-compilation-speak-error)))
-
-(defadvice compilation-next-file (after emacspeak pre act)
-  "Speak the error line. "
-  (when (interactive-p) (emacspeak-compilation-speak-error ))
-  )
-
-(defadvice compilation-previous-file (after emacspeak pre act)
-  "Speak the error line. "
-  (when (interactive-p) (emacspeak-compilation-speak-error ))
-  )
+;;{{{  advice  interactive commands
+(loop for f in 
+      '(
+        next-error previous-error
+        compilation-next-file compilation-previous-file
+        compile-goto-error compile-mouse-goto-error
+        )
+      do
+      (eval
+       (`
+        (defadvice (, f) (after  emacspeak pre act )
+          "Speak the line containing the error. "
+          (when (interactive-p)
+            (dtk-stop)
+            (emacspeak-compilation-speak-error))))))
 
+(loop for f in 
+      '(
+        compilation-next-error
+        compilation-previous-error
+        next-error-no-select
+        previous-error-no-select)
+      do
+      (eval
+       (`
+        (defadvice (, f) (after emacspeak pre act comp)
+          "Provide spoken feedback."
+          (when (interactive-p)
+            (emacspeak-speak-line)
+            (emacspeak-auditory-icon 'select-object))))))
 ;;}}}
 ;;{{{ advise process filter and sentinels
 
