@@ -1,6 +1,6 @@
-;;; emacspeak-perl.el --- Speech enable CPerl Mode 
-;;; $Id: emacspeak-cperl.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $ 
+;;; emacspeak-cperl.el --- Speech enable CPerl Mode 
+;;; $Id: emacspeak-cperl.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for CPerl mode
 ;;; Keywords:emacspeak, audio interface to emacs CPerl
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -37,13 +37,10 @@
 
 ;;}}}
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(eval-when-compile (require 'dtk-speak)
-		   (require 'emacspeak-speak)
-		   (require 'emacspeak-sounds)
-		   (require 'voice-lock))
+;;{{{ required modules 
 
+(require 'emacspeak-preamble)
+;;}}}
 ;;{{{  Introduction:
 
 ;;; Commentary:
@@ -58,8 +55,6 @@
 ;;; first pull in emacspeak-perl for voice lock definitions 
 (require 'emacspeak-perl)
 
-(voice-lock-set-major-mode-keywords 'cperl-mode 'perl-voice-lock-keywords)
-
 ;;}}}
 ;;{{{  Advice electric insertion to talk:
 
@@ -80,19 +75,16 @@
 Cue electric insertion with a tone."
           (when (interactive-p)
             (let ((emacspeak-speak-messages nil))
-	      (emacspeak-speak-this-char last-input-char)
-	      (dtk-tone 800 50 t)))))))
+              (emacspeak-speak-this-char last-input-char)
+              (dtk-tone 800 50 t)))))))
 
 (defadvice cperl-electric-backspace (around emacspeak pre act)
   "Speak character you're deleting."
   (cond
    ((interactive-p )
     (dtk-tone 500 30 'force)
-    (and emacspeak-backward-delete-char-speak-deleted-char
-         (emacspeak-speak-this-char (preceding-char )))
-    ad-do-it
-    (and emacspeak-backward-delete-char-speak-current-char
-         (emacspeak-speak-this-char (preceding-char ))))
+    (emacspeak-speak-this-char (preceding-char ))
+    ad-do-it)
    (t ad-do-it))
   ad-return-value)
 
@@ -108,7 +100,7 @@ Otherwise cue user to the line just created. "
       (emacspeak-speak-line )
       ad-do-it)
      (t ad-do-it       
-        (dtk-speak-using-voice 'annotation-voice
+        (dtk-speak-using-voice voice-annotate
                                (format
                                 "indent %s"
                                 (current-column)))
@@ -132,8 +124,8 @@ Otherwise cue user to the line just created. "
     (message "Displayed info in other window")))
 
 (defadvice cperl-info-on-command (after emacspeak
-					pre act
-					comp)
+                                        pre act
+                                        comp)
   "Speak the displayed info"
   (when (interactive-p)
     (emacspeak-auditory-icon 'help)
@@ -212,13 +204,13 @@ Otherwise cue user to the line just created. "
 
 (add-hook 'cperl-mode-hook
           (function (lambda ()
-		      (voice-lock-mode 1)
-		      (dtk-set-punctuations "all")
-		      (or dtk-split-caps
-			  (dtk-toggle-split-caps))
-		      (or emacspeak-audio-indentation
-			  (emacspeak-toggle-audio-indentation))
-		      (emacspeak-dtk-sync))))
+                      (voice-lock-mode 1)
+                      (dtk-set-punctuations 'all)
+                      (or dtk-split-caps
+                          (dtk-toggle-split-caps))
+                      (or emacspeak-audio-indentation
+                          (emacspeak-toggle-audio-indentation))
+                      (emacspeak-dtk-sync))))
 
 ;;}}}
 (provide  'emacspeak-cperl)
