@@ -1,6 +1,6 @@
 ;;; emacspeak-custom.el --- Speech enable interactive Emacs customization 
-;;; $Id: emacspeak-custom.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-custom.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to custom
 ;;; Keywords: Emacspeak, Speak, Spoken Output, custom
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2002, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,17 +40,7 @@
 
 ;;{{{  Required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(eval-when-compile (require 'dtk-speak)
-		   (require 'emacspeak-speak)
-		   (require 'voice-lock)
-		   (require 'emacspeak-keymap)
-		   (require 'emacspeak-sounds)
-		   (require 'widget)
-		   (require 'wid-edit)
-		   (require 'emacspeak-widget))
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction
 
@@ -59,7 +49,43 @@
 ;;; which speech-enables the widget libraries.
 
 ;;}}}
-;;{{{ Advice
+
+;;{{{ advice
+
+(defadvice Custom-reset-current (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'item)
+    (dtk-speak "Reset current")))
+
+(defadvice Custom-reset-saved(after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'unmodified-object)
+    (dtk-speak "Reset to saved")))
+
+(defadvice Custom-reset-standard (after emacspeak act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'delete-object)
+    (dtk-speak "Erase customization")))
+
+(defadvice Custom-set (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'button)
+    (dtk-speak "Set for current session")))
+
+(defadvice Custom-save (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'save-object)
+    (dtk-speak "Set and saved")))
+
+(defadvice Custom-buffer-done (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'close-object)))
 
 (defadvice customize-save-customized (after emacspeak pre act comp)
   "Provide auditory feedback. "
@@ -68,7 +94,7 @@
     (message "Saved customizations.")))
 
 (defadvice custom-save-all (after emacspeak pre
-				  act comp)
+                                  act comp)
   "Provide auditory feedback. "
   (when (interactive-p)
     (emacspeak-auditory-icon 'save-object)
@@ -138,6 +164,11 @@
     (voice-lock-mode 1)
     (emacspeak-speak-line)))
 
+(defadvice Custom-newline (after emacspeak pre act comp)
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'button)))
+
 ;;}}}
 ;;{{{ custom hook
 
@@ -147,6 +178,35 @@
              (voice-lock-mode 1)
              (emacspeak-pronounce-refresh-pronunciations))))
 
+;;}}}
+;;{{{ define voices
+(voice-setup-add-map
+ '(
+   (custom-button voice-bolden)
+   (custom-button-pressed voice-bolden-extra)
+   (custom-button-pressed-unraised voice-bolden-extra)
+   (custom-button-mouse voice-bolden-medium)
+   (custom-button-unraised voice-smoothen)
+   (custom-changed voice-smoothen)
+   (custom-comment-face voice-monotone-medium)
+   (custom-comment-tag voice-monotone)
+   (custom-comment-tag-face voice-monotone)
+   (custom-documentation voice-brighten-medium)
+   (custom-face-tag voice-lighten)
+   (custom-group-tag voice-bolden)
+   (custom-group-tag-1 voice-lighten-medium)
+   (custom-group-tag-face voice-bolden)
+   (custom-invalid voice-animate-extra)
+   (custom-link voice-bolden)
+   (custom-modified voice-lighten-medium)
+   (custom-rogue voice-bolden-and-animate)
+   (custom-modified-face voice-lighten-medium)
+   (custom-saved voice-smoothen-extra)
+   (custom-set voice-smoothen-medium)
+   (custom-state voice-smoothen)
+   (custom-variable-button voice-animate)
+   (custom-variable-tag voice-bolden-medium)))
+
 ;;}}}
 ;;{{{  custom navigation
 
@@ -155,7 +215,7 @@
   "Pattern identifying start of custom group."
   :type 'regexp
   :group 'emacspeak-custom)
-
+;;;###autoload
 (defun emacspeak-custom-goto-group ()
   "Jump to custom group when in a customization buffer."
   (interactive)
@@ -172,7 +232,7 @@
   "Pattern that identifies toolbar section."
   :type 'regexp
   :group 'emacspeak-custom)
-
+;;;###autoload
 (defun emacspeak-custom-goto-toolbar ()
   "Jump to custom toolbar when in a customization buffer."
   (interactive)
@@ -188,6 +248,12 @@
 ;;{{{  bind emacspeak commands 
 
 (declaim (special custom-mode-map))
+(define-key custom-mode-map "E" 'Custom-reset-standard)
+(define-key custom-mode-map "r" 'Custom-reset-current)
+(define-key custom-mode-map "R" 'Custom-reset-saved)
+(define-key custom-mode-map "s" 'Custom-set)
+(define-key  custom-mode-map "S" 'Custom-save)
+
 (define-key custom-mode-map "," 'backward-paragraph)
 (define-key custom-mode-map "." 'forward-paragraph)
 (define-key custom-mode-map  "\M-t" 'emacspeak-custom-goto-toolbar)
