@@ -1,6 +1,6 @@
 ;;; emacspeak-dired.el --- Speech enable Dired Mode -- A powerful File Manager
-;;; $Id: emacspeak-dired.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-dired.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enable dired
 ;;; Keywords: Emacspeak, Dired, Spoken Output
 ;;{{{  LCD Archive entry:
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -49,18 +49,22 @@
 ;;{{{  required packages 
 
 ;;; Code:
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'voice-lock)
-(eval-when-compile
-  (require 'dired)
-  (require 'emacspeak-keymap))
-(require 'dtk-speak)
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
-(require 'emacspeak-pronounce)
-
+(require 'emacspeak-preamble)
+(require 'desktop)
+(require 'dired)
+;;}}}
+;;{{{ Define personalities 
+(voice-setup-add-map
+ '(
+   (dired-header voice-smoothen)
+   (dired-mark voice-lighten)
+   (dired-marked voice-bolden-and-animate)
+   (dired-warning voice-animate-extra)
+   (dired-directory voice-bolden-medium)
+   (dired-symlink voice-animate-extra)
+   (dired-ignored voice-lighten-extra)
+   (dired-flagged voice-animate-extra)
+   ))
 ;;}}}
 ;;{{{  configure dired
 
@@ -80,13 +84,13 @@ pronunciations only once.")
 (defun emacspeak-dired-define-pronunciations ()
   "Define pronunciations specific to Dired buffers."
   (declare (special emacspeak-dired-pronunciations-defined
-                    emacspeak-pronounce-dictionaries-loaded))
-  (require 'emacspeak-pronounce)
+                    emacspeak-pronounce-pronunciation-table emacspeak-pronounce-dictionaries-loaded))
   (unless emacspeak-dired-pronunciations-defined
     (setq emacspeak-dired-pronunciations-defined t)
-    (emacspeak-pronounce-set-dictionary
-     'dired-mode
-     '(("Dired" . " Directory Sorted "))))
+    (emacspeak-pronounce-add-dictionary-entry 'dired-mode "Dired"
+                                              " DirEd  ")
+    (emacspeak-pronounce-add-dictionary-entry 'dired-mode "dired"
+                                              " DirEd  "))
   (when (or (not (boundp 'emacspeak-pronounce-pronunciation-table))
             (not emacspeak-pronounce-pronunciation-table))
     (emacspeak-pronounce-toggle-use-of-dictionaries)))
@@ -140,14 +144,15 @@ pronunciations only once.")
       (emacspeak-dired-label-fields)
       (emacspeak-auditory-icon 'open-object )
       (emacspeak-speak-mode-line))))
-(defadvice dired (after emacspeak pre act)
-  "Produce an auditory icon."
-  (when (interactive-p)
-    (let ((emacspeak-speak-messages nil))
-      (voice-lock-mode 1)
-      (emacspeak-dired-label-fields)
-      (emacspeak-auditory-icon 'open-object )
-      (emacspeak-speak-mode-line))))
+(defun emacspeak-dired-initialize ()
+  "Set up emacspeak dired."
+  (emacspeak-dired-label-fields)
+  (emacspeak-auditory-icon 'open-object )
+  (emacspeak-speak-mode-line))
+
+(defadvice dired (after emacspeak pre act comp)
+  "Hook is not reliable."
+  (emacspeak-dired-initialize))
 
 (defadvice dired-find-file  (around  emacspeak pre act)
   "Produce an auditory icon."
@@ -303,17 +308,29 @@ unless `dired-listing-switches' contains -al"
 
 ;;}}}
 ;;{{{ Additional status speaking commands
-(if (fboundp 'dired-show-file-type)
-    (defalias 'emacspeak-dired-show-file-type 'dired-show-file-type)
-  (defun emacspeak-dired-show-file-type ()
-    "Displays type of current file by running command file."
-    (interactive)
-    (let ((filename (dired-get-filename t t)))
-      (if filename 
-	  (shell-command 
-	   (format "file %s"
-		   filename))
-	(message "No file on this line")))))
+(defcustom emacspeak-dired-file-cmd-options "-b"
+  "Options passed to Unix builtin `file' command."
+  :type '(choice
+          (const :tag "Brief" "-b")
+          (const :tag "Detailed" nil))
+  :group 'emacspeak-dired)
+
+(defun emacspeak-dired-show-file-type (&optional file deref-symlinks)
+  "Displays type of current file by running command file.
+Like Emacs' built-in dired-show-file-type but allows user to customize
+options passed to command `file'."
+  (interactive (list (dired-get-filename t) current-prefix-arg))
+  (declare (special emacspeak-dired-file-cmd-options))
+  (with-temp-buffer 
+    (if deref-symlinks
+        (call-process "file" nil t t  "-l"
+                      emacspeak-dired-file-cmd-options  file)
+      (call-process "file" nil t t
+                    emacspeak-dired-file-cmd-options file))
+    (when (bolp)
+      (backward-delete-char 1))
+    (message (buffer-string))))
+    
 
 (defun emacspeak-dired-speak-header-line()
   "Speak the header line of the dired buffer. "
@@ -334,7 +351,7 @@ On a directory line, run du -s on the directory to speak its size."
      ((and filename
            (file-directory-p filename))
       (emacspeak-auditory-icon 'progress)
-      (shell-command (format "du -s %s" filename )))
+      (shell-command (format "du -s \'%s\'" filename )))
      (filename
       (setq size (nth 7 (file-attributes filename )))
                                         ; check for ange-ftp
@@ -410,10 +427,10 @@ On a directory line, run du -s on the directory to speak its size."
   (define-key  dired-mode-map "a" 'emacspeak-dired-speak-file-access-time)
   (define-key dired-mode-map "c" 'emacspeak-dired-speak-file-modification-time)
   (define-key dired-mode-map "z" 'emacspeak-dired-speak-file-size)
-  (define-key dired-mode-map "t" 'emacspeak-dired-speak-symlink-target)
+  (define-key dired-mode-map "\C-t" 'emacspeak-dired-speak-symlink-target)
   (define-key dired-mode-map "\C-i" 'emacspeak-speak-next-field)
   (define-key dired-mode-map  "," 'emacspeak-speak-previous-field))
-
+(add-hook 'dired-mode-hook 'emacspeak-dired-initialize 'append)
 (add-hook 'dired-mode-hook 'emacspeak-dired-setup-keys)
 (add-hook 'dired-mode-hook 'emacspeak-dired-define-pronunciations)
 ;;}}}
