@@ -1,6 +1,6 @@
 ;;; emacspeak-dismal.el --- Speech enable Dismal -- An Emacs Spreadsheet program
-;;; $Id: emacspeak-dismal.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-dismal.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: spread sheet extension
 ;;; Keywords:emacspeak, audio interface to emacs spread sheets
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -44,15 +44,8 @@
 
 ;;}}}
 ;;{{{  requires 
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(eval-when-compile (require 'dtk-speak)
-                   (require 'emacspeak-sounds)
-                   (require 'emacspeak-speak)
-                   (require 'emacspeak-keymap))
-
+(require 'cl)
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ custom
 
@@ -111,9 +104,9 @@ The `row header' is the entry in column 0."
   (interactive)
   (declare (special))
   (let ((row-head  (emacspeak-dismal-current-row-header))
-	(value (emacspeak-dismal-current-cell-value)))
+        (value (emacspeak-dismal-current-cell-value)))
     (message "%s is %s"
-	     row-head value)))
+             row-head value)))
 
 (defun emacspeak-dismal-display-cell-with-col-header ()
   "Display current cell along with its column header.
@@ -177,7 +170,7 @@ The `column header' is the entry in row 0."
 (setq-default emacspeak-dismal-row-summarizer-list nil)
 (setq-default emacspeak-dismal-col-summarizer-list nil)
 (setq-default emacspeak-dismal-sheet-summarizer-list nil)
-(defcustom emacspeak-dismal-value-personality 'paul-animated
+(defcustom emacspeak-dismal-value-personality voice-animate
   "Personality used for speaking cell values in summaries."
   :group 'emacspeak-dismal
   :type 'symbol)
@@ -205,8 +198,10 @@ emacspeak-dismal-row-summarizer-list"
                 (cond
                  ((stringp token) token)
                  ((numberp token)
-                  (setq value (emacspeak-dismal-cell-value
-                               dismal-current-row token))
+                  (setq value
+                        (format "%s"
+                                (emacspeak-dismal-cell-value
+                                 dismal-current-row token)))
                   (put-text-property  0   (length value)
                                       'personality  emacspeak-dismal-value-personality 
                                       value )
@@ -214,9 +209,11 @@ emacspeak-dismal-row-summarizer-list"
                  ((and (listp token)
                        (numberp (first token))
                        (numberp (second token )))
-                  (setq value (emacspeak-dismal-cell-value
-                               (first token)
-                               (second token)))
+                  (setq value
+                        (format "%s"
+                                (emacspeak-dismal-cell-value
+                                 (first token)
+                                 (second token))))
                   (put-text-property 0   (length value )
                                      'personality emacspeak-dismal-value-personality 
                                      value)
@@ -248,8 +245,10 @@ emacspeak-dismal-col-summarizer-list"
                 (cond
                  ((stringp token) token)
                  ((numberp token)
-                  (setq value (emacspeak-dismal-cell-value token
-                                                           dismal-current-col))
+                  (setq value
+                        (format "%s"
+                                (emacspeak-dismal-cell-value token
+                                                             dismal-current-col)))
                   (put-text-property 0 (length value)
                                      'personality
                                      emacspeak-dismal-value-personality value)
@@ -257,9 +256,11 @@ emacspeak-dismal-col-summarizer-list"
                  ((and (listp token)
                        (numberp (first token))
                        (numberp (second token )))
-                  (setq value (emacspeak-dismal-cell-value
-                               (first token)
-                               (second token)))
+                  (setq value
+                        (format "%s"
+                                (emacspeak-dismal-cell-value
+                                 (first token)
+                                 (second token))))
                   (put-text-property 0 (length value)
                                      'personality
                                      emacspeak-dismal-value-personality value)
@@ -338,11 +339,11 @@ Checked by emacspeak specific dis-mode-hooks entry.")
              (unless emacspeak-dismal-already-customized-dismal
                (setq emacspeak-dismal-already-customized-dismal t)
                (push 'emacspeak-dismal-sheet-summarizer-list
-		     dismal-saved-variables)
-	       (push 'emacspeak-dismal-row-summarizer-list
-		     dismal-saved-variables)
-	       (push 'emacspeak-dismal-col-summarizer-list
-		     dismal-saved-variables)))))
+                     dismal-saved-variables)
+               (push 'emacspeak-dismal-row-summarizer-list
+                     dismal-saved-variables)
+               (push 'emacspeak-dismal-col-summarizer-list
+                     dismal-saved-variables)))))
 
 (declaim (special dismal-map))
 (eval-when (load)
