@@ -1,6 +1,6 @@
 ;;; emacspeak-ecb.el --- speech-enable Emacs Class Browser
-;;; $Id: emacspeak-ecb.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-ecb.el 4074 2006-08-19 17:48:45Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for speech-enabling Emacs
 ;;; Class Browser
 ;;; Keywords: Emacspeak, ecb
@@ -9,8 +9,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2006-08-19 10:48:45 -0700 (Sat, 19 Aug 2006) $ |
+;;;  $Revision: 4074 $ |
 ;;; Location undetermined
 ;;;
 
@@ -41,15 +41,7 @@
 
 ;;{{{ required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'backquote)
-(require 'thingatpt)
-(require 'emacspeak-speak)
-(require 'voice-lock)
-(require 'emacspeak-sounds)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
 
@@ -57,7 +49,13 @@
 ;;; This module speech-enables ECB
 
 ;;}}}
-;;{{{  advice interactive commands.
+;;{{{  advice interactive commands
+
+(defadvice ecb-activate (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'open-object)
+    (emacspeak-speak-mode-line)))
 
 (defadvice ecb-cancel-dialog (after emacspeak pre act comp)
   "Provide auditory feedback."
@@ -76,7 +74,6 @@
         ecb-nav-goto-next
         ecb-nav-goto-previous
         ecb-goto-window-compilation
-        ecb-eshell-goto-eshell
         ecb-goto-window-directories 
         ecb-goto-window-sources 
         ecb-goto-window-methods 
@@ -89,16 +86,68 @@
         (defadvice (, f) (after emacspeak pre act comp)
           "Provide auditory feedback."
           (when (interactive-p)
-            (emacspeak-speak-mode-line)
+            (emacspeak-speak-line)
             (emacspeak-auditory-icon 'select-object))))))
 
+(defadvice ecb-select-ecb-frame (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-speak-mode-line)
+    (emacspeak-auditory-icon 'select-object)))
+
 ;;}}}
 ;;{{{  inform tree browser about emacspeak
 
+;;; define emacspeak versions of these special tree search
+;;; commands
+;;; need these to get ECB working outside X
+
+(defun emacspeak-ecb-tree-backspace ()
+  "Back up during incremental search in tree buffers."
+  (interactive)
+  (declare (special tree-buffer-incr-searchpattern))
+  ;; reduce by one from the end
+  (setq tree-buffer-incr-searchpattern
+        (substring tree-buffer-incr-searchpattern
+                   0
+                   (max 0 (1- (length
+                               tree-buffer-incr-searchpattern)))))
+  (dtk-speak  tree-buffer-incr-searchpattern)
+  (emacspeak-auditory-icon 'delete-object))
+
+             
+(defun emacspeak-ecb-tree-clear ()
+  "Clear search pattern during incremental search in tree buffers."
+  (interactive)
+  (declare (special tree-buffer-incr-searchpattern))  
+  (setq tree-buffer-incr-searchpattern "")
+  (dtk-speak "Cleared search pattern."))
+
+(defun emacspeak-ecb-tree-expand-common-prefix ()
+  "Expand to longest common prefix in tree buffer."
+  (interactive)
+  (declare (special tree-buffer-incr-searchpattern
+                    tree-buffer-incr-search
+                    tree-buffer-root))
+  ;; expand to the max. common prefix
+  (let* ((node-name-list (tree-node-get-all-visible-node-names
+                          tree-buffer-root))
+         (common-prefix (tree-buffer-find-common-substring
+                         node-name-list tree-buffer-incr-searchpattern
+                         (if (equal tree-buffer-incr-search 'prefix) t))))
+    (if (stringp common-prefix)
+        (setq tree-buffer-incr-searchpattern
+              common-prefix))
+    (end-of-line)
+    (emacspeak-speak-line)))
+
+              
+             
 (defun emacspeak-ecb-tree-shift-return ()
   "Do shift return in ECB tree browser."
   (interactive)
   (tree-buffer-return-pressed 'shift nil))
+
 (defadvice tree-buffer-create (after emacspeak pre act comp)
   "Fixes up keybindings so incremental tree search is
 available."
@@ -109,12 +158,20 @@ available."
                                  tree-buffer-key-map
                                  global-map))
     (define-key tree-buffer-key-map "\M-\C-m"
-      'emacspeak-ecb-tree-shift-return)))
+      'emacspeak-ecb-tree-shift-return)
+    (define-key tree-buffer-key-map "\d"
+      'emacspeak-ecb-tree-backspace)
+    (define-key tree-buffer-key-map '[delete]
+      'emacspeak-ecb-tree-backspace)
+    (define-key tree-buffer-key-map '[home]
+      'emacspeak-ecb-tree-clear)
+    (define-key tree-buffer-key-map '[end]
+      'emacspeak-ecb-tree-expand-common-prefix)))
 
 (defadvice tree-buffer-incremental-node-search 
   (around emacspeak pre act comp)
   "Track search and provide appropriate auditory feedback."
-  (declare (special tree-buffer-incr-searchpattern))
+  
   (cond
    ((interactive-p)
     (let ((start (point))
@@ -132,8 +189,8 @@ available."
             (search-forward tree-buffer-incr-searchpattern)
             (setq end (point))
             (ems-modify-buffer-safely
-	     (ems-set-personality-temporarily
-	      beg end   'harry
+             (ems-set-personality-temporarily
+              beg end   voice-bolden
               (emacspeak-speak-line)))
             (emacspeak-auditory-icon 'search-hit))))
        (t (emacspeak-auditory-icon 'search-miss)))))
@@ -142,21 +199,24 @@ available."
 
 (defadvice tree-buffer-select (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (emacspeak-auditory-icon 'select-object)
-  (emacspeak-speak-line))
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-speak-line)))
 
 (defadvice tree-node-toggle-expanded (after emacspeak pre
                                             act comp)
   "Provide auditory feedback."
-  (let ((node (ad-get-arg 0))) ;; note that logic is reversed
-    (cond
-     ((tree-node-is-expanded node)
-      (emacspeak-auditory-icon 'open-object))
-     (t (emacspeak-auditory-icon 'close-object)))))
+  (when (interactive-p)
+    (let ((node (ad-get-arg 0))) ;; note that logic is reversed
+      (cond
+       ((tree-node-is-expanded node)
+        (emacspeak-auditory-icon 'open-object))
+       (t (emacspeak-auditory-icon 'close-object))))))
       
 (defadvice tree-buffer-update (after emacspeak pre act comp)
   "Provide context speech feedback."
-  (emacspeak-speak-line))
+  (when (interactive-p)
+    (emacspeak-speak-line)))
 
 (defadvice tree-buffer-nolog-message (after emacspeak pre
                                             act comp)
@@ -181,6 +241,15 @@ available."
     (emacspeak-auditory-icon 'button)
     (emacspeak-speak-line)))
 
+(defadvice tree-buffer-show-menu-keyboard (around emacspeak pre
+                                                  act comp)
+  "When on the console, always use TMM."
+  (cond
+   ((and (interactive-p)
+         (not window-system))
+    (tree-buffer-show-menu-keyboard 'use-tmm)    )
+   (t ad-do-it)))
+
 ;;}}}
 ;;{{{ commands to speak ECB windows without  moving
 
