@@ -1,23 +1,23 @@
 ;;; emacspeak-ediff.el --- Speech enable Emacs interface to diff and merge
-;;; $Id: emacspeak-ediff.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-ediff.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; DescriptionEmacspeak extensions for ediff
-;;; Keywords:emacspeak, audio interface to emacs, Comparing files 
-;;{{{  LCD Archive entry: 
+;;; Keywords:emacspeak, audio interface to emacs, Comparing files
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman
 ;;; Copyright (c) 1995 by .
-;;; All Rights Reserved. 
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -37,21 +37,9 @@
 
 ;;}}}
 
-;;{{{  required 
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'backquote)
-(require 'custom)
-(eval-when-compile (require 'dtk-speak)
-		   (require 'emacspeak-speak)
-		   (require 'emacspeak-keymap)
-		   (require 'emacspeak-sounds)
-		   (require 'voice-lock)
-		   (require 'ediff)
-		   (require 'ediff-init))
-    
+;;{{{  required
 
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
 
@@ -68,47 +56,34 @@
 ;;}}}
 ;;{{{  macros
 
-(defgroup  emacspeak-ediff nil
+(defgroup emacspeak-ediff nil
   "Emacspeak support for EDiff."
   :link '(custom-group-link :tag "ediff"
                             ediff)
   :group 'emacspeak
   :prefix "emacspeak-ediff-")
 
-(defmacro emacspeak-ediff-modify-buffer-safely   (&rest body )
-  (`
-   (let    ((save-read-only buffer-read-only)
-            (buffer-read-only nil )
-            (inhibit-read-only t)
-            (before-change-functions nil)
-            (after-change-functions nil)
-            (modification-flag (buffer-modified-p)))
-     (unwind-protect
-         (,@ body )
-       (setq buffer-read-only save-read-only )
-       (set-buffer-modified-p modification-flag )))))
-
 ;;}}}
 ;;{{{  Mapping faces to personalities:
 
-(defcustom emacspeak-ediff-A-personality 'paul-smooth
+(defcustom emacspeak-ediff-A-personality voice-smoothen
   "Personality used to voiceify difference chunk A"
   :type 'symbol
   :group 'emacspeak-ediff)
 
 (defcustom emacspeak-ediff-B-personality
-  'paul-monotone
+  voice-monotone
   "Personality used to voiceify difference chunk B"
   :type 'symbol
   :group 'emacspeak-ediff)
 
-(defcustom emacspeak-ediff-fine-A-personality 'harry
+(defcustom emacspeak-ediff-fine-A-personality voice-bolden
   "Personality used to voiceify difference chunk A"
   :type 'symbol
   :group 'emacspeak-ediff)
 
 (defcustom emacspeak-ediff-fine-B-personality
-  'harry
+  voice-bolden
   "Personality used to voiceify difference chunk B"
   :type 'symbol
   :group 'emacspeak-ediff)
@@ -135,7 +110,7 @@
           "There are only %s differences"
           ediff-number-of-differences)
   (aref (aref ediff-difference-vector-A n) 0))
-  
+
 (defsubst emacspeak-ediff-difference-b-overlay (n)
   (declare (special ediff-difference-vector-B
                     ediff-number-of-differences))
@@ -146,6 +121,7 @@
 
 (defsubst emacspeak-ediff-difference-c-overlay (n)
   (declare (special ediff-difference-vector-B
+                    ediff-difference-vector-C
                     ediff-number-of-differences))
   (assert (< n ediff-number-of-differences) t
           "There are only %s differences"
@@ -159,7 +135,7 @@
           "There are only %s differences"
           ediff-number-of-differences)
   (aref (aref ediff-difference-vector-A n) 1))
-  
+
 (defsubst emacspeak-ediff-fine-difference-b-overlays (n)
   (declare (special ediff-difference-vector-B
                     ediff-number-of-differences))
@@ -170,6 +146,7 @@
 
 (defsubst emacspeak-ediff-fine-difference-c-overlays (n)
   (declare (special ediff-difference-vector-B
+                    ediff-difference-vector-C
                     ediff-number-of-differences))
   (assert (< n ediff-number-of-differences) t
           "There are only %s differences"
@@ -200,7 +177,7 @@
         (counter 0))
     (save-excursion
       (set-buffer variant)
-      (emacspeak-ediff-modify-buffer-safely
+      (ems-modify-buffer-safely
        (while (< counter count)
          (emacspeak-ediff-voicify-extent
           (emacspeak-ediff-diff-overlay-from-difference  diff-vector counter )
@@ -223,7 +200,7 @@
           (and a-vector
                (save-excursion
                  (set-buffer ediff-buffer-A)
-                 (emacspeak-ediff-modify-buffer-safely
+                 (ems-modify-buffer-safely
                   (mapcar
                    (function
                     (lambda  (o)
@@ -234,7 +211,7 @@
           (and b-vector
                (save-excursion
                  (set-buffer ediff-buffer-B)
-                 (emacspeak-ediff-modify-buffer-safely
+                 (ems-modify-buffer-safely
                   (mapcar
                    (function
                     (lambda  (o)
@@ -254,7 +231,7 @@
         (end (overlay-end overlay )))
     (save-excursion
       (set-buffer buffer )
-      (emacspeak-ediff-modify-buffer-safely
+      (ems-modify-buffer-safely
        (put-text-property start end
                           'personality personality)))))
 
@@ -262,6 +239,7 @@
   "Voicify all the difference chunks"
   (declare (special ediff-buffer-A ediff-buffer-B
                     ediff-number-of-differences
+                    ediff-difference-vector-B ediff-difference-vector-A
                     emacspeak-ediff-A-personality
                     emacspeak-ediff-B-personality
                     emacspeak-ediff-fine-A-personality
@@ -311,14 +289,12 @@
               (lambda (overlay)
                 (emacspeak-ediff-voicify-extent overlay
                                                 emacspeak-ediff-fine-B-personality)))
-             (emacspeak-ediff-fine-difference-b-overlays  counter )) 
+             (emacspeak-ediff-fine-difference-b-overlays  counter ))
             (incf counter )))
         (message "Voicified fine differences ")))))
 (declaim (special ediff-auto-refine))
 (setq-default ediff-auto-refine 'on)
 
-  
-  
 (add-hook 'ediff-startup-hook
           (function (lambda ()
                       (declare (special ediff-mode-map
@@ -348,7 +324,7 @@
       (emacspeak-overlay-get-text  a-overlay)))
     (let ((dtk-stop-immediately nil ))
       (sit-for 2)
-      (setq key 
+      (setq key
             (read-key-sequence "Press any key to continue" )))
     (unless    (=  7  (string-to-char key ))
       (dtk-stop)
@@ -443,7 +419,7 @@ Set this to nil if things get too slow."
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-ediff-speak-current-difference)))
 
-;;; advice meta panel 
+;;; advice meta panel
 (defadvice ediff-previous-meta-item (after emacspeak pre act
                                            comp)
   "Provide auditory feedback."
@@ -480,11 +456,11 @@ Set this to nil if things get too slow."
 
 ;;}}}
 (provide  'emacspeak-ediff)
-;;{{{  emacs local variables 
+;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
 ;;; byte-compile-dynamic: t
-;;; end: 
+;;; end:
 
 ;;}}}
