@@ -1,6 +1,6 @@
 ;;; emacspeak-entertain.el --- Speech enable misc games
-;;; $Id: emacspeak-entertain.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-entertain.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to diversions
 ;;; Keywords: Emacspeak, Speak, Spoken Output, games
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2002, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -38,27 +38,19 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  Required modules
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-speak)
-(require 'emacspeak-pronounce)
-(require 'emacspeak-sounds)
-(eval-when (compile)
-  (condition-case nil
-      (require 'tetris)
-    (error nil)))
-
-;;}}}
 ;;{{{  Introduction 
 
 ;;; Commentary:
 
 ;;; Auditory interface to misc games
 
+;;; Code:
+
+;;}}}
+;;{{{  Required modules
+
+(require 'emacspeak-preamble)
 ;;}}}
-            
 ;;{{{ doctar
 
 (defadvice doctor-txtype (after emacspeak pre act )
@@ -71,17 +63,13 @@
 
 ;;}}}
 ;;{{{ mpuz
-
-(declaim (special mpuz-silent ))
-(setq mpuz-silent t )
-(defadvice mpuz-correct-guess (after emacspeak pre act )
-  "Provide an auditory icon"
-  (emacspeak-auditory-icon 'search-hit ))
-
-(defadvice mpuz-congratulate (after emacspeak pre act )
-  "Produce auditory icon"
-  (emacspeak-auditory-icon 'alarm ))
-
+(voice-setup-add-map
+ '(
+   (mpuz-trivial-face voice-monotone)
+   (mpuz-unsolved-face voice-bolden)
+   (mpuz-unsolved-face voice-lighten)
+   (mpuz-solved-face voice-animate)
+   ))
 ;;}}}
 ;;{{{ dunnet 
 
@@ -132,8 +120,8 @@
           (aset  string  i
                  (aref hm-current-guess-string (* i 2 ))))
     (message  "%s:  %s "
-	      (length string)
-	      (downcase string))))
+              (length string)
+              (downcase string))))
 
 (defadvice hangman (after emacseak pre act comp)
   "Speech enable hangman."
