@@ -1,6 +1,6 @@
 ;;; emacspeak-erc.el --- speech-enable erc irc client
-;;; $Id: emacspeak-erc.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-erc.el 4502 2007-05-01 00:29:30Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for speech-enabling erc.el
 ;;; Keywords: Emacspeak, erc
 ;;{{{  LCD Archive entry:
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-04-30 17:29:30 -0700 (Mon, 30 Apr 2007) $ |
+;;;  $Revision: 4502 $ |
 ;;; Location undetermined
 ;;;
 
@@ -38,19 +38,6 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{ required modules
-
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(require 'advice)
-(require 'thingatpt)
-(require 'emacspeak-speak)
-(require 'emacspeak-pronounce)
-(require 'voice-lock)
-(require 'emacspeak-sounds)
-
-;;}}}
 ;;{{{  Introduction:
 
 ;;; Commentary:
@@ -59,13 +46,16 @@
 ;;; erc.el - an Emacs IRC client (by Alexander L. Belikoff)
 ;;; http://www.cs.cmu.edu/~berez/irc/erc.el
 
+;;; Code:
+
+;;}}}
+;;{{{ required modules
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  variables
 
 (declaim (special emacspeak-sounds-directory))
 
-(add-to-list 'erc-sound-path emacspeak-sounds-directory)
-
 ;;}}}
 ;;{{{ personalities 
 
@@ -74,86 +64,34 @@
   :group 'emacspeak
   :prefix "emacspeak-erc-")
 
-(defcustom emacspeak-erc-default-personality 'paul
-  "Default personality for erc."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
 (defcustom emacspeak-erc-ignore-notices nil
-  "Set to T if you dont want to see notifcation messages from the
+  "Set to T if you dont want to see notification  messages from the
 server."
   :type 'boolean
-  :group 'eamcspeak-erc)
-
-(defcustom emacspeak-erc-direct-msg-personality
-  'paul-animated
-  "Personality for direct messages."
-  :type 'symbol
   :group 'emacspeak-erc)
 
-(defcustom emacspeak-erc-input-personality 
-  'paul-smooth
-  "Personality for input."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
-(defcustom emacspeak-erc-bold-personality
-  'paul-bold
-  "Personality for bold in erc."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
-(defcustom emacspeak-erc-inverse-personality
-  'betty
-  "Inverse personality in ERC."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
-(defcustom emacspeak-erc-underline-personality  'ursula
-  "Persnality for underlining in erc."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
-(defcustom emacspeak-erc-prompt-personality  'harry
-  "Personality for prompting in erc."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
-(defcustom emacspeak-erc-notice-personality 
-  'paul-italic
-  "Personality for notices in Erc."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
-(defcustom emacspeak-erc-action-personality 
-  'paul-monotone
-  "Personality for actions in erc."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
-(defcustom emacspeak-erc-error-personality 
-  'kid
-  "Personality for errors n ERC."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
-(defcustom emacspeak-erc-host-danger-personality 
-  'paul-surprized
-  "Personality for marking dangerous hosts."
-  :type 'symbol
-  :group 'emacspeak-erc)
-
-(defcustom emacspeak-erc-pal-personality
-  'paul-animated
-  "Personality for marking pals."
-  :type 'symbol
-  :group 'emacspeak-erc)
+(voice-setup-add-map
+ '(
+   (erc-direct-msg-face voice-animate)
+   (erc-input-face voice-smoothen)
+   (erc-bold-face voice-bolden)
+   (erc-inverse-face voice-lighten-extra)
+   (erc-underline-face voice-brighten-medium)
+   (erc-prompt-face voice-bolden)
+   (erc-notice-face (quote inaudible))
+   (erc-action-face voice-monotone)
+   (erc-error-face voice-bolden-and-animate)
+   (erc-dangerous-host-face voice-brighten-extra)
+   (erc-pal-face voice-animate-extra)
+   (erc-keyword-face voice-animate)
+   ))
 
 ;;}}}
 ;;{{{  helpers
 
 ;;}}}
 ;;{{{ advice interactive commands
+(declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
 (emacspeak-pronounce-augment-pronunciations 'erc-mode
                                             emacspeak-pronounce-internet-smileys-pronunciations)
 
@@ -181,66 +119,6 @@ server."
 
 ;;}}}
 (provide 'emacspeak-erc)
-;;{{{ advice for voicefication 
-
-(defcustom emacspeak-erc-faces-to-personalities
-  '((erc-default-face paul)
-    (erc-direct-msg-face paul-animated)
-    (erc-input-face paul-smooth)
-    (erc-bold-face paul-bold)
-    (erc-inverse-face betty)
-    (erc-underline-face ursula)
-    (erc-prompt-face harry)
-    (erc-notice-face paul-italic)
-    (erc-action-face paul-monotone)
-    (erc-error-face kid)
-    (erc-dangerous-host-face paul-surprized)
-    (erc-pal-face paul-animated)
-    (erc-fool-face paul-angry)
-    (erc-keyword-face paul-animated))
-  "Maps faces used in erc to speaker personalities in emacspeak."
-  :group 'emacspeak-erc
-  :type '(repeat
-	  (list :tag "mapping"
-		(symbol :tag "face")
-		(symbol :tag "personality"))))
-
-(defadvice erc-put-text-property (after emacspeak pre act comp)
-  "Voiceify faces."
-  (declare (special emacspeak-erc-faces-to-personalities))
-  (let ((start (ad-get-arg 0))
-        (end (ad-get-arg 1))
-        (property (ad-get-arg 2))
-        (value (ad-get-arg 3))
-        (object (or (ad-get-arg 4)
-                    nil))
-        (personality nil))
-    (setq personality
-          (cadr (assq value emacspeak-erc-faces-to-personalities)))
-    (when personality 
-      (ems-modify-buffer-safely
-       (put-text-property  start end
-                           'personality personality object)))))
-
-    
-
-(defadvice erc-highlight-error (after emacspeak pre act
-                                      comp)
-  "Apply aural highlighting as well."
-  (put-text-property 0 (length ad-return-value)
-                     'personality emacspeak-erc-error-personality
-                     ad-return-value)
-  ad-return-value)
-
-(defadvice erc-highlight-notice (after emacspeak pre act
-                                       comp)
-  "Apply aural highlighting as well."
-  (put-text-property 0 (length ad-return-value)
-                     'personality emacspeak-erc-notice-personality
-                     ad-return-value)
-  ad-return-value)
-
-;;}}}
 ;;{{{ monitoring chatrooms 
 (defvar emacspeak-erc-room-monitor nil
   "*Local to each chat room. If turned on,
@@ -259,7 +137,7 @@ spoken.")
 
 (make-variable-buffer-local 'emacspeak-erc-monitor-my-messages)
 
-(defcustom emacspeak-erc-my-nick nil
+(defcustom emacspeak-erc-my-nick ""
   "My IRC nick."
   :type 'string
   :group 'emacspeak-erc)
@@ -272,21 +150,26 @@ spoken.")
      (let ((start (point)))
        (search-backward  "<" (point-min) t)
        (when (not (= start (point)))
-	 (setq start (point))
-	 (search-forward " ")
-	 (buffer-substring start (1- (point))))))))
+         (setq start (point))
+         (search-forward " ")
+         (buffer-substring start (1- (point))))))))
      
-
-(defun emacspeak-erc-add-name-to-monitor (name)
-  "Add people to monitor in this room."
+(defun emacspeak-erc-add-name-to-monitor (name &optional
+                                               quiten-pronunciation)
+  "Add people to moniter in this room.
+Optional interactive prefix  arg defines a pronunciation that
+  silences speaking of this perso's name."
   (interactive
    (list
-    (emacspeak-erc-read-person "Add ")))
+    (emacspeak-erc-read-person "Add ")
+    current-prefix-arg))
   (declare (special emacspeak-erc-people-to-monitor))
   (unless (eq major-mode 'erc-mode)
     (error "Not in an ERC buffer."))
   (pushnew name emacspeak-erc-people-to-monitor
            :test #'string-equal)
+  (when quiten-pronunciation
+    (emacspeak-pronounce-add-buffer-local-dictionary-entry name ""))
   (emacspeak-auditory-icon 'select-object)
   (message "monitoring %s"
            (mapconcat #'identity 
@@ -310,16 +193,24 @@ spoken.")
   (message "monitoring %s"
            (mapconcat #'identity 
                       emacspeak-erc-people-to-monitor " ")))
+(defcustom emacspeak-erc-speak-all-participants nil
+  "Speak all things said if t."
+  :type 'boolean
+  :group 'emacspeak-erc)
+
+(make-variable-buffer-local 'emacspeak-erc-speak-all-participants)
 
 (defun emacspeak-erc-compute-message (string buffer)
   "Uses environment of buffer to decide what message to
 display. String is the original message."
   (declare (special emacspeak-erc-people-to-monitor
                     emacspeak-erc-my-nick
+                    emacspeak-erc-speak-all-participants
                     emacspeak-erc-monitor-my-messages))
   (let ((who-from (car (split-string string )))
         (case-fold-search t))
     (cond
+     (emacspeak-erc-speak-all-participants string)
      ((and
        (not (string-match "^\\*\\*\\*" who-from))
        emacspeak-erc-people-to-monitor
@@ -334,6 +225,14 @@ display. String is the original message."
       string)
      (t nil))))
 
+(ems-generate-switcher
+ 'emacspeak-erc-toggle-speak-all-participants
+ 'emacspeak-erc-speak-all-participants
+ "Toggle state of ERC speak all participants..
+Interactive 
+PREFIX arg means toggle the global default value, and then
+set the current local value to the result.")
+
 (defadvice erc-display-line-buffer  (after emacspeak pre act
                                            comp)
   "Speech-enable ERC."
@@ -345,7 +244,7 @@ display. String is the original message."
     (save-excursion
       (set-buffer buffer)
       (when (and emacspeak-erc-room-monitor
-		 emacspeak-erc-monitor-my-messages)
+                 emacspeak-erc-monitor-my-messages)
         (let ((emacspeak-speak-messages nil)
               (msg (emacspeak-erc-compute-message (ad-get-arg 0)
                                                   buffer)))
@@ -353,7 +252,7 @@ display. String is the original message."
             (emacspeak-auditory-icon 'progress)
             (message msg)
             (tts-with-punctuations dtk-punctuation-mode
-				   (dtk-speak  msg))))))))
+                                   (dtk-speak  msg))))))))
 
 (defadvice erc-display-line-1  (after emacspeak pre act comp)
   "Speech-enable ERC."
@@ -365,7 +264,7 @@ display. String is the original message."
     (save-excursion
       (set-buffer buffer)
       (when (and emacspeak-erc-room-monitor
-		 emacspeak-erc-monitor-my-messages)
+                 emacspeak-erc-monitor-my-messages)
         (let ((emacspeak-speak-messages nil)
               (msg (emacspeak-erc-compute-message (ad-get-arg 0)
                                                   buffer)))
@@ -373,55 +272,20 @@ display. String is the original message."
             (emacspeak-auditory-icon 'progress)
             (message msg)
             (tts-with-punctuations dtk-punctuation-mode
-				   (dtk-speak  msg))))))))
+                                   (dtk-speak  msg))))))))
 
-(defun emacspeak-erc-toggle-room-monitor  (&optional prefix)
-  "Toggle state of ERC room monitor.
+(ems-generate-switcher 'emacspeak-erc-toggle-room-monitor
+                       'emacspeak-erc-room-monitor
+                       "Toggle state of ERC room monitor.
 Interactive 
 PREFIX arg means toggle the global default value, and then
-set the current local value to the result."
+set the current local value to the result.")
 
-  (interactive  "P")
-  (declare  (special  emacspeak-erc-room-monitor))
-  (cond
-   (prefix
-    (setq-default  emacspeak-erc-room-monitor
-                   (not  (default-value 'emacspeak-erc-room-monitor )))
-    (setq emacspeak-erc-room-monitor (default-value 'emacspeak-comint-autospeak )))
-   (t
-    (setq emacspeak-erc-room-monitor
-          (not emacspeak-erc-room-monitor ))))
-  (and emacspeak-erc-room-monitor
-       
-       )
-  (emacspeak-auditory-icon
-   (if emacspeak-erc-room-monitor 'on 'off))
-  (message "Turned %s room monitor  %s "
-           (if emacspeak-erc-room-monitor "on" "off" )
-	   (if prefix "" "locally")))
-
-(defun emacspeak-erc-toggle-my-monitor  (&optional prefix)
-  "Toggle state of ERC  monitor of my messages.
+(ems-generate-switcher 'emacspeak-erc-toggle-my-monitor
+                       'emacspeak-erc-monitor-my-messages
+                       "Toggle state of ERC  monitor of my messages.
 Interactive PREFIX arg means toggle the global default value, and then
-set the current local value to the result."
-  (interactive  "P")
-  (declare  (special  emacspeak-erc-monitor-my-messages))
-  (cond
-   (prefix
-    (setq-default  emacspeak-erc-monitor-my-messages
-                   (not  (default-value 'emacspeak-erc-monitor-my-messages )))
-    (setq emacspeak-erc-monitor-my-messages (default-value 'emacspeak-comint-autospeak )))
-   (t
-    (setq emacspeak-erc-monitor-my-messages
-          (not emacspeak-erc-monitor-my-messages ))))
-  (and emacspeak-erc-monitor-my-messages
-       
-       )
-  (emacspeak-auditory-icon
-   (if emacspeak-erc-monitor-my-messages 'on 'off))
-  (message "Turned %s messages monitor  %s "
-           (if emacspeak-erc-monitor-my-messages "on" "off" )
-	   (if prefix "" "locally")))
+set the current local value to the result.")
 
 ;;}}}
 ;;{{{ silence server messages 
@@ -435,15 +299,16 @@ set the current local value to the result."
 
 (defadvice erc-make-notice (around emacspeak  pre act comp)
   "Ignore notices from server is emacspeak-erc-ignore-notices it set."
+  ad-do-it
   (cond
-   ((not emacspeak-erc-ignore-notices )
-    ad-do-it
-    ad-return-value)
-   (t "")))
+   ((not emacspeak-erc-ignore-notices ) ad-return-value)
+   (t " ")))
 
 ;;}}}
 ;;{{{ define emacspeak keys
 (declaim (special erc-mode-map))
+(define-key erc-mode-map "\C-c "
+  'emacspeak-erc-toggle-speak-all-participants)
 (define-key erc-mode-map "\C-cm"
   'emacspeak-erc-toggle-my-monitor)
 (define-key erc-mode-map "\C-c\C-m"
@@ -452,6 +317,77 @@ set the current local value to the result."
   'emacspeak-erc-add-name-to-monitor)
 (define-key erc-mode-map "\C-c\C-d" 'emacspeak-erc-delete-name-from-monitor)
 ;;}}}
+ 
+;;{{{ cricket rules 
+(defvar emacspeak-erc-cricket-bowling-figures-pattern
+  " [0-9]+-[0-9]+-[0-9]+-[0-9] "
+  "Pattern for matching bowling figures.")
+
+(defun emacspeak-erc-cricket-convert-bowling-figures (pattern)
+  "Pronounce bowling figures in cricket."
+  (let ((fields (split-string pattern "-")))
+    (format " %s for %s off %s overs with %s maidens "
+            (cond
+             ((string-equal "0" (fourth fields)) 
+              "none")
+             (t (fourth fields)))
+            (third fields)
+            (first fields)
+            (cond
+             ((string-equal "0" (second fields)) 
+              "no")
+             (t (second fields))))))
+
+(defvar emacspeak-erc-cricket-4-6-pattern
+  " [0-9]+x\[46]"
+  "Matches pattern used to  score number of fours and sixes in IRC #cricket.")
+
+(defun emacspeak-erc-cricket-convert-4-6-pattern (pattern)
+  "Convert 4/6 pattern for IRC cricket channels."
+  (format "%s %s"
+          (substring pattern 0 -2)
+          (cond
+           ((string-equal "4" 
+                          (substring pattern -1))
+            "fours")
+           (t "sixes"))))
+(defun emacspeak-erc-setup-cricket-rules ()
+  "Set up #cricket channels."
+  (interactive)
+  (emacspeak-pronounce-add-buffer-local-dictionary-entry
+   "km/h," " kays, ")
+  (emacspeak-pronounce-add-buffer-local-dictionary-entry
+   emacspeak-erc-cricket-bowling-figures-pattern
+   (cons 're-search-forward
+         'emacspeak-erc-cricket-convert-bowling-figures))
+  (emacspeak-pronounce-add-buffer-local-dictionary-entry
+   emacspeak-erc-cricket-4-6-pattern
+   (cons 're-search-forward
+         'emacspeak-erc-cricket-convert-4-6-pattern))
+  (emacspeak-pronounce-add-buffer-local-dictionary-entry
+   " [0-9]+nb"
+   (cons
+    're-search-forward
+    #'(lambda (pattern)
+        (format "%s no balls "
+                (substring pattern 0 -2)))))
+  (emacspeak-pronounce-add-buffer-local-dictionary-entry
+   "[0-9]+b"
+   (cons
+    're-search-forward
+    #'(lambda (pattern)
+        (format "%s balls "
+                (substring pattern 0 -1)))))
+  (emacspeak-pronounce-add-buffer-local-dictionary-entry
+   " [0-9]+w "
+   (cons
+    're-search-forward
+    #'(lambda (pattern)
+        (format "%s wides "
+                (substring pattern 0 -1)))))
+  (dtk-set-punctuations 'some))
+
+;;}}}
 ;;{{{ end of file
 
 ;;; local variables:
