@@ -1,6 +1,6 @@
 ;;; emacspeak-eterm.el --- Speech enable eterm -- Emacs' terminal emulator  term.el
-;;; $Id: emacspeak-eterm.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-eterm.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable eterm. 
 ;;; Keywords: Emacspeak, Eterm, Terminal emulation, Spoken Output
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -52,26 +52,11 @@
 ;; 
 ;;; Code:
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'custom)
-(eval-when-compile (require 'dtk-speak)
-                   (require 'dtk-voices )
-                   (require 'voice-lock)
-                   (require 'emacspeak-speak)
-                   (require 'emacspeak-sounds)
-                   (require 'emacspeak-keymap)
-                   (condition-case nil
-                       (progn
-                         (require 'term)
-                                        ;(require 'tshell)
-                         )
-                     (error nil )))
-
+(require 'emacspeak-preamble)
+(require 'term)
 ;;}}}
 ;;{{{ custom
-
+;;;###autoload
 (defgroup emacspeak-eterm nil
   "Terminal emulator for the Emacspeak Desktop."
   :group 'emacspeak
@@ -138,9 +123,13 @@
   (define-key emacspeak-eterm-keymap "\C-p"
     'emacspeak-eterm-toggle-pointer-mode)
   (define-key emacspeak-eterm-keymap "\C-w" 'emacspeak-eterm-define-window)
-  (define-key emacspeak-eterm-keymap "\C-y" 'emacspeak-eterm-yank-window)
+  (define-key emacspeak-eterm-keymap "\C-y"
+    'emacspeak-eterm-yank-window)
+  (define-key emacspeak-eterm-keymap "f"
+    'emacspeak-eterm-set-filter-window)
   (define-key emacspeak-eterm-keymap "\C-f"
     'emacspeak-eterm-set-focus-window)
+  (define-key emacspeak-eterm-keymap "A" 'emacspeak-eterm-toggle-filter-window)
   (define-key emacspeak-eterm-keymap "\C-a" 'emacspeak-eterm-toggle-focus-window)
   (define-key emacspeak-eterm-keymap "\C-d" 'emacspeak-eterm-describe-window)
   (define-key emacspeak-eterm-keymap "\C-m" 'emacspeak-eterm-speak-window)
@@ -162,7 +151,8 @@ Useful when eterm is in review mode.")
 
 (defun emacspeak-eterm-setup-raw-keys ()
   "Setup emacspeak keys for raw terminal mode."
-  (declare (special term-raw-map 
+  (declare (special term-raw-map
+                    emacspeak-prefix term-raw-escape-map
                     emacspeak-eterm-keymap
                     emacspeak-eterm-raw-prefix))
   (when term-raw-map 
@@ -179,7 +169,7 @@ Useful when eterm is in review mode.")
       (concat emacspeak-eterm-prefix emacspeak-eterm-prefix) 'emacspeak-eterm-maybe-send-raw)
     (define-key emacspeak-eterm-keymap emacspeak-eterm-raw-prefix
       term-raw-map)
-    ;;; handle emacs 21 wierdness 
+;;; handle emacs 21 wierdness 
     (local-unset-key "\eO")
     (local-unset-key "\e[")
     ))
@@ -187,13 +177,13 @@ Useful when eterm is in review mode.")
 ;;}}}
 ;;{{{  voice definitions  for eterm  highlight, underline etc
 
-(defcustom emacspeak-eterm-highlight-personality 'harry
+(defcustom emacspeak-eterm-highlight-personality voice-bolden
   "Personality to show terminal highlighting."
   :type 'symbol
   :group 'emacspeak-eterm)
 
-(defcustom emacspeak-eterm-bold-personality 'paul-bold
-  "Persnality to indicate terminal bold."
+(defcustom emacspeak-eterm-bold-personality voice-bolden
+  "Personality to indicate terminal bold."
   :type 'symbol
   :group 'emacspeak-eterm)
 
@@ -563,10 +553,8 @@ without sending input to the terminal itself."
                     eterm-char-mode
                     buffer-read-only emacspeak-eterm-keymap term-raw-map))
   (emacspeak-eterm-nuke-cached-info )
-  (or (assq 'emacspeak-eterm-review-p  minor-mode-alist)
-      (setq minor-mode-alist
-            (append minor-mode-alist
-                    '((emacspeak-eterm-review-p " Review")))))
+  (setq mode-line-process
+        '("review"))
   (if eterm-char-mode 
       (cond 
        (emacspeak-eterm-review-p        ;turn it off 
@@ -577,12 +565,10 @@ without sending input to the terminal itself."
         (message "Entering terminal review mode press  q  to return to normal")
         (setq emacspeak-eterm-review-p t)
         (use-local-map emacspeak-eterm-keymap)))
-    (message "Terminal review should be used when eterm is in
-character mode "))
+    (message
+     "Terminal review should be used when eterm is in character mode "))
   (emacspeak-auditory-icon
-   (if emacspeak-eterm-review-p
-       'on
-     'off)))
+   (if emacspeak-eterm-review-p 'on 'off)))
 
 ;;}}}
 ;;{{{  Cut and paste while reviewing:
@@ -679,24 +665,25 @@ sent to the terminal as if it were typed by the user."
 (defun  emacspeak-eterm-coordinate-within-window-p (coordinate id  )
   "Predicate to test if COORDINATE is within window.
 Argument ID specifies the window."
-  (let*  ((window  (emacspeak-eterm-get-window id ))
-          (row (cdr coordinate))
-          (column (car coordinate ))
-          (left-stretch (emacspeak-eterm-window-left-stretch window ))
-          (right-stretch (emacspeak-eterm-window-right-stretch window ))
-          (top-left-row (cdr
-                         (emacspeak-eterm-window-top-left window )))
-          (top-left-column (car
-                            (emacspeak-eterm-window-top-left window)))
-          (bottom-right-row (cdr 
-                             (emacspeak-eterm-window-bottom-right window )))
-          (bottom-right-column (car
-                                (emacspeak-eterm-window-bottom-right window  ))))
-    (not
-     (or  (< row top-left-row )
-          (> row bottom-right-row )
-          (and (not left-stretch ) (< column top-left-column ))
-          (and (not right-stretch ) (> column bottom-right-column ))))))
+  (when (and coordinate id)
+    (let*  ((window  (emacspeak-eterm-get-window id ))
+            (row (cdr coordinate))
+            (column (car coordinate ))
+            (left-stretch (emacspeak-eterm-window-left-stretch window ))
+            (right-stretch (emacspeak-eterm-window-right-stretch window ))
+            (top-left-row (cdr
+                           (emacspeak-eterm-window-top-left window )))
+            (top-left-column (car
+                              (emacspeak-eterm-window-top-left window)))
+            (bottom-right-row (cdr 
+                               (emacspeak-eterm-window-bottom-right window )))
+            (bottom-right-column (car
+                                  (emacspeak-eterm-window-bottom-right window  ))))
+      (not
+       (or  (< row top-left-row )
+            (> row bottom-right-row )
+            (and (not left-stretch ) (< column top-left-column ))
+            (and (not right-stretch ) (> column bottom-right-column )))))))
  
 ;;; Translate a screen position to a buffer position
 
@@ -804,7 +791,7 @@ Argument ETERM-WINDOW specifies a predefined eterm window."
   "Vector of window positions.
 A terminal window is recorded by the  positions of its top left
 and bottom right.")
-
+;;;###autoload
 (defun emacspeak-eterm-record-window  (window-id top-left bottom-right
                                                  &optional right-stretch left-stretch )
   "Insert this window definition into the table of terminal windows.
@@ -925,6 +912,7 @@ and bottom right at %s %s"
 
 (defvar emacspeak-eterm-focus-window nil
   "Current window that emacspeak eterm focuses on")
+(make-variable-buffer-local 'emacspeak-eterm-filter-window)
 
 (defun emacspeak-eterm-set-focus-window (flag)
   "Prompt for the id of a predefined window,
@@ -952,7 +940,39 @@ non-negative integer ")
         (setq emacspeak-eterm-focus-window nil))
        (t 
         (setq emacspeak-eterm-focus-window window-id )
-        (message "Set emacspeak eterm focus window  to %d " window-id )))))))
+        (message "Set emacspeak eterm focus window  to %d "
+                 window-id )))))))
+
+(defvar emacspeak-eterm-filter-window nil
+  "Window id used to filter screen activity.")
+
+(make-variable-buffer-local 'emacspeak-eterm-filter-window)
+(defun emacspeak-eterm-set-filter-window (flag)
+  "Prompt for the id of a predefined window,
+and set the `filter' window to it.
+Non-nil interactive prefix arg `unsets' the filter window;
+this is equivalent to having the entire terminal as the filter window (this is
+what eterm starts up with).
+Setting the filter window results in emacspeak  only monitoring screen
+activity within the filter window."
+  (interactive "P")
+  (declare (special emacspeak-eterm-filter-window ))
+  (let  ((window-id nil))
+    (cond
+     ( flag (setq emacspeak-eterm-filter-window nil)
+            (message "Emacspeak eterm filter set to entire screen "))
+     (t
+      (setq window-id
+            (read-minibuffer  "Specify eterm window to filter on "))
+      (assert (numberp window-id) t
+              "Please specify a valid window id, a non-negative integer ")
+      (cond
+       ((= 0 window-id)
+        (message "Unset filter window.")
+        (setq emacspeak-eterm-filter-window nil))
+       (t 
+        (setq emacspeak-eterm-filter-window window-id )
+        (message "Set emacspeak eterm filter window  to %d " window-id )))))))
 
 (defun emacspeak-eterm-toggle-focus-window ()
   "Toggle active state of focus window."
@@ -966,6 +986,18 @@ non-negative integer ")
    (if emacspeak-eterm-focus-window
        'on 'off)))
 
+(defun emacspeak-eterm-toggle-filter-window ()
+  "Toggle active state of filter window."
+  (interactive)
+  (declare (special emacspeak-eterm-filter-window))
+  (if emacspeak-eterm-filter-window
+      (setq emacspeak-eterm-filter-window nil)
+    (setq emacspeak-eterm-filter-window 1))
+  (dtk-stop)
+  (emacspeak-auditory-icon
+   (if emacspeak-eterm-filter-window
+       'on 'off)))
+
 (defun emacspeak-eterm-speak-predefined-window ()
   "Speak a predefined eterm window between 1 and 10."
   (interactive)
@@ -1027,27 +1059,13 @@ Use command emacspeak-toggle-eterm-autospeak bound to
   
 (make-variable-buffer-local 'emacspeak-eterm-autospeak)
   
-(defun emacspeak-toggle-eterm-autospeak (&optional prefix)
-  "Toggle state of eterm autospeak.
+(ems-generate-switcher 'emacspeak-toggle-eterm-autospeak
+                       'emacspeak-eterm-autospeak
+                       "Toggle state of eterm autospeak.
 When eterm autospeak is turned on and the terminal is in line mode,
 all output to the terminal is automatically spoken. 
   Interactive prefix arg means toggle  the global default value, and then set the
-  current local  value to the result. "
-  (interactive  "P")
-  (declare (special emacspeak-eterm-autospeak))
-  (let ((dtk-stop-immediately nil ))
-    (cond
-     (prefix
-      (setq-default  emacspeak-eterm-autospeak
-                     (not  (default-value 'emacspeak-eterm-autospeak )))
-      (setq emacspeak-eterm-autospeak (default-value 'emacspeak-eterm-autospeak )))
-     (t (setq emacspeak-eterm-autospeak 
-              (not emacspeak-eterm-autospeak ))))
-    (message "Turned %s eterm autospeak %s"
-             (if emacspeak-eterm-autospeak "on" "off")
-             (if prefix "globally" "locally"))
-    (emacspeak-auditory-icon
-     (if emacspeak-eterm-autospeak 'on 'off))))
+  current local  value to the result. ")
 
 (defvar eterm-line-mode nil 
   "T if eterm is in line mode.")
@@ -1063,22 +1081,21 @@ Use command emacspeak-eterm-toggle-pointer-mode bound to
 
 (defadvice  term-emulate-terminal (around emacspeak pre act compile )
   "Record position, emulate, then speak what happened.
-Also keep track of terminal highlighting etc.
-If a `current window`
-is set (see command emacspeak-eterm-set-focus-window
-bound to \\[emacspeak-eterm-set-focus-window].
-How output is spoken  depends on whether the terminal is in
-character or line mode.
-When in character mode, output is spoken like off a real terminal.
-When in line mode,
-behavior resembles that of comint mode;
-i.e. you hear the output if emacspeak-eterm-autospeak is t.
-Do not set this variable by hand:
-See command emacspeak-toggle-eterm-autospeak bound to 
+Also keep track of terminal highlighting etc.  Feedback is
+limited to current window If a `current window` is set (see
+command emacspeak-eterm-set-filter-window bound to
+\\[emacspeak-eterm-set-filter-window].  How output is spoken
+depends on whether the terminal is in character or line mode.
+
+When in character mode, output is spoken like off a real
+terminal.  When in line mode, behavior resembles that of comint
+mode; i.e. you hear the output if emacspeak-eterm-autospeak is t.
+Do not set this variable by hand: See command
+emacspeak-toggle-eterm-autospeak bound to
 \\[emacspeak-toggle-eterm-autospeak]"
   (declare (special emacspeak-eterm-row emacspeak-eterm-column
                     eterm-line-mode eterm-char-mode
-                    emacspeak-eterm-focus-window emacspeak-eterm-pointer-mode
+                    emacspeak-eterm-filter-window emacspeak-eterm-pointer-mode
                     emacspeak-eterm-autospeak 
                     term-current-row term-current-column))
   (let ((emacspeak-eterm-row (term-current-row ))
@@ -1090,12 +1107,7 @@ See command emacspeak-toggle-eterm-autospeak bound to
         (new-column nil )
         (old-point (point))
         (dtk-stop-immediately (not eterm-line-mode)))
-    (save-match-data 
-      (ad-enable-advice  'put-text-property 'after 'eterm )
-      (ad-activate 'put-text-property) 
-      ad-do-it
-      (ad-disable-advice  'put-text-property 'after 'eterm )
-      (ad-deactivate 'put-text-property))
+    ad-do-it
     (setq new-row (term-current-row )
           new-column (term-current-column )
           new-end (point-max))
@@ -1108,8 +1120,22 @@ See command emacspeak-toggle-eterm-autospeak bound to
                            emacspeak-eterm-focus-window )
                           (emacspeak-eterm-coordinate-within-window-p
                            (cons (term-current-column) (term-current-row))
-                           emacspeak-eterm-focus-window ))))
+                           emacspeak-eterm-focus-window ))
+                     (and (emacspeak-eterm-coordinate-within-window-p
+                           (cons new-column new-row )
+                           emacspeak-eterm-filter-window )
+                          (emacspeak-eterm-coordinate-within-window-p
+                           (cons (term-current-column) (term-current-row))
+                           emacspeak-eterm-filter-window ))))
       (cond
+       ((and eterm-char-mode
+             emacspeak-eterm-filter-window
+             (not (and (emacspeak-eterm-coordinate-within-window-p
+                        (cons new-column new-row )
+                        emacspeak-eterm-filter-window )
+                       (emacspeak-eterm-coordinate-within-window-p
+                        (cons (term-current-column) (term-current-row))
+                        emacspeak-eterm-filter-window )))) nil)
        ((and  eterm-line-mode
               emacspeak-eterm-autospeak)
         (setq dtk-stop-immediately nil)
@@ -1121,7 +1147,8 @@ See command emacspeak-toggle-eterm-autospeak bound to
           (error nil )))
        (emacspeak-eterm-focus-window
         (emacspeak-eterm-speak-window emacspeak-eterm-focus-window))
-       ((and (= last-input-event 127)
+       ((and (or (eq last-command-event 127) ; xterm/console sends 127
+                 (eq last-command-event 'backspace)) ; X sends 'backspace
              (= new-row emacspeak-eterm-row )
              (= -1 (- new-column emacspeak-eterm-column ))
              current-char)              ;you backspaced?
@@ -1130,7 +1157,7 @@ See command emacspeak-toggle-eterm-autospeak bound to
         (dtk-tone 500 50))
        ((and (= new-row emacspeak-eterm-row )
              (= 1 (- new-column emacspeak-eterm-column ))) ;you inserted a character:
-        (if (= 32 last-input-event )
+        (if (eq 32 last-command-event )
             (save-excursion
               (backward-char 2)
               (emacspeak-speak-word nil))
@@ -1148,21 +1175,13 @@ See command emacspeak-toggle-eterm-autospeak bound to
                  emacspeak-eterm-pointer)
         (emacspeak-eterm-pointer-to-cursor)))))
 
-(defun emacspeak-eterm-toggle-pointer-mode (flag)
-  "Toggle emacspeak eterm pointer mode.
+(ems-generate-switcher 'emacspeak-eterm-toggle-pointer-mode
+                       'emacspeak-eterm-pointer-mode
+                       "Toggle emacspeak eterm pointer mode.
 With optional interactive prefix  arg, turn it on.
 When emacspeak eterm is in pointer mode, the eterm read pointer
 stays where it is rather than automatically moving to the terminal cursor when
-there is terminal activity."
-  (interactive "P")
-  (declare (special emacspeak-eterm-pointer-mode ))
-  (cond
-   (flag (setq emacspeak-eterm-pointer-mode t ))
-   (t (setq emacspeak-eterm-pointer-mode
-            (not emacspeak-eterm-pointer-mode ))))
-  (message "Turned %s emacspeak eterm pointer mode"
-           (if emacspeak-eterm-pointer-mode
-               "on" "off")))
+there is terminal activity.")
 
    
 (defadvice term-dynamic-complete (around emacspeak pre act)
@@ -1174,36 +1193,15 @@ there is terminal activity."
       (emacspeak-speak-region saved-point (point)))
     ad-return-value )
   )
-
-(defadvice put-text-property (after eterm pre act) 
-  "Used by emacspeak to highlight successfully in eterm. "
-  (let ((start (ad-get-arg 0))
-        (end (ad-get-arg 1 ))
-        (prop (ad-get-arg 2))
-        (value (ad-get-arg 3 )))
-    (if (eq prop 'face) 
-        (save-match-data
-          (cond
-           ((eq value 'bold)
-            (put-text-property start end
-                               'personality emacspeak-eterm-bold-personality))
-           ((eq value 'highlight)
-            (put-text-property start end
-                               'personality emacspeak-eterm-highlight-personality ))
-           ((eq value 'term-underline-face )
-            (put-text-property start end
-                               'personality emacspeak-eterm-underline-personality))
-           (t  nil )))))
-  )
-
+(voice-setup-add-map
+ '(
+   (term-underline voice-brighten-medium)
+   ))
 (defadvice term-line-mode (after emacspeak pre act)
   "Announce that you entered line mode. "
-  (declare (special eterm-char-mode  eterm-line-mode))
   (make-local-variable 'eterm-line-mode)
-  (or (assq 'eterm-line-mode minor-mode-alist)
-      (setq minor-mode-alist
-            (append minor-mode-alist
-                    '((eterm-line-mode " Line")))))
+  (setq mode-line-process
+        '("line"))
   (setq eterm-char-mode nil 
         eterm-line-mode t )
   (when (interactive-p)
@@ -1211,12 +1209,8 @@ there is terminal activity."
 
 (defadvice term-char-mode (after emacspeak pre act)
   "Announce you entered character mode. "
-  (declare (special eterm-char-mode  eterm-line-mode))
-  (make-local-variable'term-char-mode)
-  (or (assq 'eterm-char-mode minor-mode-alist)
-      (setq minor-mode-alist
-            (append minor-mode-alist
-                    '((eterm-char-mode " Character")))))
+  (setq mode-line-process
+        '("char"))
   (setq eterm-char-mode t
         eterm-line-mode nil )
   (emacspeak-eterm-setup-raw-keys)
@@ -1297,7 +1291,7 @@ there is terminal activity."
     (let ((pmark (process-mark (get-buffer-process (current-buffer)))))
       (when  (> (point) (marker-position pmark))
         (emacspeak-auditory-icon 'delete-object )
-	(emacspeak-speak-region  pmark (point))))))
+        (emacspeak-speak-region  pmark (point))))))
 
 (defadvice term-dynamic-list-filename-completions (after emacspeak pre act )
   "Provide auditory feedback"
@@ -1307,6 +1301,7 @@ completions for filename at point")))
 
 ;;}}}
 ;;{{{  Launch remote terminals
+;;;###autoload
 (defvar emacspeak-eterm-remote-hosts-table
   (make-vector 127 0)
   "obarray used for completing hostnames when prompting for a remote
@@ -1340,7 +1335,7 @@ emacspeak-eterm-remote-hostnames")
 
 (eval-when (load)
   (emacspeak-eterm-load-remote-hosts-cache))
-
+;;;###autoload
 (defun emacspeak-eterm-cache-remote-host (host)
   "Add this hostname to cache of remote hostnames"
   (declare (special emacspeak-eterm-remote-hosts-table
@@ -1353,7 +1348,7 @@ emacspeak-eterm-remote-hostnames")
       (insert (format "%s\n" host))
       (save-buffer))
     (intern host emacspeak-eterm-remote-hosts-table)))
-
+;;;###autoload
 (defun emacspeak-eterm-remote-term (host )
   "Start a terminal-emulator in a new buffer."
   (interactive
