@@ -1,6 +1,6 @@
 ;;; emacspeak-filtertext.el --- Utilities to filter text
-;;; $Id: emacspeak-filtertext.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-filtertext.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:   Implement text filters 
 ;;; Keywords: Emacspeak, Audio Desktop
 ;;{{{  LCD Archive entry:
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2002, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,12 +40,7 @@
 
 ;;{{{ required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
-(require 'derived)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
 
@@ -70,8 +65,8 @@
 (defstruct (emacspeak-filtertext
             (:constructor
              emacspeak-filtertext-constructor))
-  text					;original text
-  filters				;chain of filters applied 
+  text                                  ;original text
+  filters                               ;chain of filters applied 
   )
 
 ;;}}}
@@ -93,7 +88,7 @@
 
 ;;}}}
 ;;{{{ Interactive commands 
-
+;;;###autoload
 (defun emacspeak-filtertext(start end)
   "Copy over text in region to special filtertext buffer in
 preparation for interactively filtering text. "
@@ -116,6 +111,7 @@ preparation for interactively filtering text. "
     (switch-to-buffer buffer)
     (emacspeak-speak-mode-line)))
 
+;;;###autoload
 (defun emacspeak-filtertext-revert ()
   "Revert to original text."
   (interactive)
@@ -134,7 +130,7 @@ preparation for interactively filtering text. "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
