@@ -1,6 +1,6 @@
 ;;; emacspeak-fix-interactive.el --- Tools to make  Emacs' builtin prompts   speak
-;;; $Id: emacspeak-fix-interactive.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-fix-interactive.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Fixes functions that use interactive to prompt for args.
 ;;; Approach suggested by hans@cs.buffalo.edu
 ;;; Keywords: Emacspeak, Advice, Automatic advice, Interactive
@@ -9,14 +9,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -39,7 +39,7 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(eval-when-compile (require 'cl))
+(require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'advice)
 (require 'dtk-speak)
@@ -62,35 +62,22 @@
 ;;; The exception to this appear to be the code letters for
 ;;; reading characters and key sequences 
 ;;; i.e. "c" and "k"
-;;; This module has been updated to auto-advice
-;;; only those interactive commands that use "c" or "k"
-;;; when running XEmacs.
-;;; The Search for emacspeak-xemacs-p to see the test used.
 
 ;;}}}
-;;{{{  functions that are  fixed. 
-
-(defvar emacspeak-last-command-needs-minibuffer-spoken nil 
-  "Used to signal to minibuffer that the contents need to be spoken.")
-
-(defvar emacspeak-commands-that-are-fixed 
-  nil
-  "Functions that have been auto-advised.
-These functions have been  adviced  to make their
-interactive prompts speak. ")
-
+;;{{{  functions that are  fixed.
+;;;###autoload
 (defvar emacspeak-commands-dont-fix-regexp 
   (concat 
    "^ad-Orig\\|^mouse\\|^scroll-bar"
    "\\|^face\\|^frame\\|^font"
    "\\|^color\\|^timer")
   "Regular expression matching function names whose interactive spec should not be fixed.")
-
+;;;###autoload
 (defsubst emacspeak-should-i-fix-interactive-p (sym)
   "Predicate to test if this function should be fixed. "
   (declare (special emacspeak-commands-dont-fix-regexp))
   (and (commandp sym)
-       (not (get  sym 'emacspeak-fixed))
+       (not (get  sym 'emacspeak-checked-interactive))
        (stringp (second (ad-interactive-form (symbol-function sym))))
        (not (string-match emacspeak-commands-dont-fix-regexp (symbol-name sym)))))
  
@@ -98,118 +85,66 @@ interactive prompts speak. ")
   "Auto advices interactive commands to speak prompts."
   (mapatoms 'emacspeak-fix-interactive-command-if-necessary ))
 
-;;{{{  Understanding aid 
-
-(defun emacspeak-show-interactive (sym)
-  "Auto-advice interactive command to speak its prompt.  Fix
-the function definition of sym to make its interactive form
-speak its prompts. "
-  (declare (special emacspeak-commands-that-are-fixed))
-  (let ((interactive-list
-         (split-string
-          (second (ad-interactive-form (symbol-function sym )))
-          "\n")))
-                                        ; advice if necessary
-    (when
-        (some
-         (function
-          (lambda (prompt)
-            (declare (special emacspeak-xemacs-p))
-            (not
-             (or
-              (string-match  "^[@*]?[depPr]" prompt )
-              (string= "*" prompt )
-              (and emacspeak-xemacs-p
-                   (not (string-match  "^\\*?[ck]" prompt )))))))
-         interactive-list )
-      (progn
-        (`
-         (defadvice (, sym) (before  emacspeak-auto activate  )
-           "Automatically defined advice to speak interactive prompts. "
-           (interactive
-            (nconc  
-             (,@
-              (mapcar
-               (function 
-                (lambda (prompt)
-                  (` (let
-                         ((dtk-stop-immediately nil)
-                          (emacspeak-last-command-needs-minibuffer-spoken t)
-                          (emacspeak-speak-messages nil))
-                       (tts-with-punctuations "all"
-                                              (dtk-speak
-                                               (,
-                                                (format " %s "
-                                                        (or
-                                                         (if (= ?* (aref  prompt 0))
-                                                             (substring prompt 2 )
-                                                           (substring prompt 1 ))
-                                                         "")))))
-                       (call-interactively
-                        '(lambda (&rest args)
-                           (interactive (, prompt))
-                           args) nil)))))
-               interactive-list))))))))))
-
 ;;}}}
 
+(defsubst ems-prompt-without-minibuffer-p (prompt)
+  "Check if this interactive prompt uses the minibuffer."
+  (string-match  "^\*?[ckK]" prompt ))
+(defvar emacspeak-fix-interactive-problematic-functions nil
+  "Functions whose interactive prompt we will need to fix by hand
+because auto-advising was not possible.")
+
+;;;###autoload
 (defun emacspeak-fix-interactive (sym)
   "Auto-advice interactive command to speak its prompt.  
 Fix the function definition of sym to make its interactive form
-speak its prompts. "
-  (declare (special emacspeak-commands-that-are-fixed))
-  (let ((interactive-list
-         (split-string
-          (second (ad-interactive-form (symbol-function sym )))
-          "\n")))
-					;memoize call
-    (put sym 'emacspeak-fixed t)
+speak its prompts. This function needs to do very little work as
+of Emacs 21 since all interactive forms except `c' and `k' now
+use the minibuffer."
+  (declare (special emacspeak-fix-interactive-problematic-functions))
+  (let* ((prompts
+          (split-string
+           (second (ad-interactive-form (symbol-function sym )))
+           "\n"))
+         (count (count-if 'ems-prompt-without-minibuffer-p  prompts )))
+                                        ;memoize call
+    (put sym 'emacspeak-checked-interactive t)
                                         ; advice if necessary
-    (when
-        (some
-         (function
-          (lambda (prompt)
-            (declare (special emacspeak-xemacs-p))
-            (not
-             (or
-              (string-match  "^[@*]?[depPr]" prompt )
-              (string= "*" prompt )
-              (and emacspeak-xemacs-p
-                   (not (string-match  "^\\*?[ck]" prompt )))))))
-         interactive-list )
+    (cond
+     ((zerop count) t)                  ;do nothing
+     ((= 1 count)
+                                        ; generate auto advice
       (eval
        (`
-        (defadvice (, sym) (before  emacspeak-auto activate
-                                    protect compile)
+        (defadvice (, sym)
+          (before  emacspeak-auto pre act  protect compile)
           "Automatically defined advice to speak interactive prompts. "
           (interactive
            (nconc  
             (,@
              (mapcar
               #'(lambda (prompt)
-                  (` (let
-                         ((dtk-stop-immediately nil)
-                          (emacspeak-last-command-needs-minibuffer-spoken t)
-                          (emacspeak-speak-messages nil))
-                       (tts-with-punctuations "all"
+                  (`
+                   (let ((dtk-stop-immediately nil)
+                         (emacspeak-speak-messages nil))
+                     (when (ems-prompt-without-minibuffer-p (, prompt))
+                       (emacspeak-auditory-icon 'open-object)
+                       (tts-with-punctuations 'all
                                               (dtk-speak
-                                               (,
-                                                (format " %s "
-                                                        (or
-                                                         (if (= ?* (aref  prompt 0))
-                                                             (substring prompt 2 )
-                                                           (substring prompt 1 ))
-                                                         "")))))
-                       (call-interactively
-                        #'(lambda (&rest args)
-                            (interactive (, prompt))
-                            args) nil))))
-              interactive-list)))))))
-      (push sym  emacspeak-commands-that-are-fixed )))
+                                               (or (substring (, prompt) 1 ) ""))))
+                     (call-interactively
+                      #'(lambda (&rest args)
+                          (interactive (, prompt))
+                          args) nil))))
+              prompts))))))))
+     (t
+      ;; cannot handle automatically -- tell developer
+      (push sym emacspeak-fix-interactive-problematic-functions)
+      (message "Not auto-advicing %s" sym))))
   t)
 
 ;;; inline function for use from other modules:
-
+;;;###autoload
 (defsubst  emacspeak-fix-interactive-command-if-necessary
   (command)
   "Fix command if necessary."
@@ -232,8 +167,8 @@ speak its prompts. "
   (dolist (item
            (rest (assoc module load-history)))
     (and (symbolp item)
-	 (commandp item)
-	 (emacspeak-fix-interactive-command-if-necessary item)))
+         (commandp item)
+         (emacspeak-fix-interactive-command-if-necessary item)))
   (when (interactive-p)
     (message "Fixed interactive commands defined in module %s" module)))
 
@@ -255,7 +190,7 @@ Memoizes call in emacspeak-load-history-pointer to memoize this call. "
       (while (and lh
                   (not (eq lh
                            emacspeak-load-history-pointer)))
-      ;;; fix commands in this module
+;;; fix commands in this module
         (dolist (item (rest (first lh)))
           (and (symbolp item)
                (commandp item)
