@@ -1,6 +1,6 @@
 ;;; emacspeak-ispell.el --- Speech enable Ispell -- Emacs' interactive spell checker
-;;; $Id: emacspeak-flyspell.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-flyspell.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable flyspell
 ;;; Keywords: Emacspeak, Ispell, Spoken Output, fly spell checking
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -38,18 +38,16 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(require 'advice)
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
 ;;{{{  Introduction:
 
 ;;; Commentary:
 
 ;;; This module speech enables flyspell.
 
+;;}}}
+;;{{{ Requires
+(require 'emacspeak-preamble)
+
 ;;}}}
 ;;{{{  define personalities
 
@@ -59,10 +57,10 @@
   :group 'flyspell
   :prefix "emacspeak-flyspell-")
 
-(defcustom emacspeak-flyspell-highlight-personality 'harry
-  "Voice used to highlight spelling errors. "
-  :type 'symbol
-  :group 'emacspeak-flyspell)
+(voice-setup-add-map
+ '(
+   (flyspell-incorrect-face voice-bolden)
+   ))
 
 ;;}}}
 ;;{{{ advice
@@ -80,15 +78,14 @@
   ad-return-value)
 
 (defadvice flyspell-unhighlight-at (before debug pre act comp)
-
   (let ((overlay-list (overlays-at pos))
-	(o nil))
+        (o nil))
     (while overlay-list 
       (setq o (car overlay-list))
       (when (flyspell-overlay-p o)
-	(put-text-property (overlay-start o)
-			   (overlay-end o)
-			   'personality  nil))
+        (put-text-property (overlay-start o)
+                           (overlay-end o)
+                           'personality  nil))
       (setq overlay-list (cdr overlay-list)))))
 
 ;;}}}
@@ -96,11 +93,11 @@
 
 (defun emacspeak-flyspell-highlight-incorrect-word (beg end ignore)
   "Put property personality with value
-`emacspeak-flyspell-highlight-personality' from beg to end"
-  (declare (special emacspeak-flyspell-highlight-personality))
+`voice-animate' from beg to end"
+  (declare (special voice-animate))
   (ems-modify-buffer-safely
    (put-text-property beg end 'personality
-                      emacspeak-flyspell-highlight-personality))
+                      voice-animate))
   (emacspeak-speak-region beg end)
   nil)
 
