@@ -1,6 +1,6 @@
-;;; emacspeak-gridtext.el --- gridtext
-;;; $Id: emacspeak-gridtext.el,v 17.0 2002/11/23 01:28:59 raman Exp $
-;;; $Author: raman $
+;;; emacspeak-gridtext.el --- Overlay Grids To filter columnar text
+;;; $Id: emacspeak-gridtext.el 4150 2006-08-30 00:25:40Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for laying grids on text
 ;;; Keywords: Emacspeak, gridtext
 ;;{{{  LCD Archive entry:
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:28:59 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2006-08-29 17:25:40 -0700 (Tue, 29 Aug 2006) $ |
+;;;  $Revision: 4150 $ |
 ;;; Location undetermined
 ;;;
 
@@ -38,19 +38,6 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{ required modules
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'thingatpt)
-(require 'emacspeak-speak)
-(require 'voice-lock)
-(require 'emacspeak-sounds)
-(require 'emacspeak-table)
-(require 'emacspeak-table-ui)
-
-;;}}}
 ;;{{{  Introduction:
 
 ;;; Commentary:
@@ -70,7 +57,15 @@
 ;;; future if necessary. This module is useful for browsing
 ;;; structured text files and the output from programs that
 ;;; tabulate their output.
+;;; It's also useful for handling multicolumn text.
+;;; Code:
 
+;;}}}
+;;{{{ required modules
+
+(require 'emacspeak-preamble)
+(require 'emacspeak-table)
+(require 'emacspeak-table-ui)
 ;;}}}
 ;;{{{  variables
 
@@ -82,6 +77,7 @@ buffer.")
 
 ;;}}}
 ;;{{{  helpers
+
 (defun emacspeak-gridtext-generate-key ()
   "Generates a key for current context.
 The key is used when persisting out the grid setting for
@@ -95,6 +91,7 @@ future  use."
 end   as specified by grid."
   (let ((result-grid (make-vector (count-lines start end) nil))
         (this-line nil)
+        (this-length 0)
         (this-row nil)
         (num-rows (count-lines start end ))
         (num-columns(1+  (length grid))))
@@ -102,25 +99,31 @@ end   as specified by grid."
       (save-restriction
         (narrow-to-region start end)
         (if (< start end )
-	    (goto-char start)
-	  (goto-char end ))
+            (goto-char start)
+          (goto-char end ))
         (loop for i from 0 to (1- num-rows)
               do
               (beginning-of-line)
-              (setq this-line (thing-at-point 'line))
+              (setq this-line
+                    (buffer-substring (line-beginning-position) (line-end-position)))
+              (setq this-length (length this-line))
               (setq this-row (make-vector num-columns ""))
               (loop for j from 0 to (1- (length grid))
-                    do 
-                    (aset  this-row j
-                           (substring
-                            this-line
-                            (if (= j 0 ) 
-                                0
-			      (nth  (1- j) grid))
-                            (1- (nth j grid )))))
+                    do
+                    (when (< (1- (nth j grid )) this-length)
+;;; within bounds 
+                      (aset  this-row j
+                             (substring
+                              this-line
+                              (if (= j 0 ) 
+                                  0
+                                (nth  (1- j) grid))
+                              (1- (nth j grid ))))))
               (aset this-row (length grid)
-                    (substring this-line
-                               (nth (1- (length grid)) grid)))
+                    (if (< (nth (1- (length grid)) grid) this-length)
+                        (substring this-line
+                                   (nth (1- (length grid)) grid))
+                      ""))
               (aset result-grid i this-row)
               (forward-line 1))
         result-grid))))
@@ -141,7 +144,7 @@ end   as specified by grid."
   "Lookup key and return corresponding grid. "
   (declare (special emacspeak-gridtext-table))
   (gethash key emacspeak-gridtext-table))
-
+;;;###autoload
 (defun emacspeak-gridtext-load (file)
   "Load saved grid settings."
   (interactive
@@ -151,11 +154,11 @@ end   as specified by grid."
                     ".gridtext")))
   (condition-case nil
       (progn
-	(load
-	 (expand-file-name  file emacspeak-resource-directory)))
+        (load
+         (expand-file-name  file emacspeak-resource-directory)))
     (error (message "Error loading resources from %s "
-		    file))))
-
+                    file))))
+;;;###autoload
 (defun emacspeak-gridtext-save (file)
   "Save out grid settings."
   (interactive
@@ -179,14 +182,14 @@ end   as specified by grid."
  (gethash %s emacspeak-gridtext-table)
  (quote %s))"
               (prin1-to-string key)
-	      (prin1-to-string (emacspeak-gridtext-get
-				key)))))
+              (prin1-to-string (emacspeak-gridtext-get
+                                key)))))
       (basic-save-buffer)
       (kill-buffer buffer))))
 
 ;;}}}
 ;;{{{ interactive commands
-
+;;;###autoload
 (defun emacspeak-gridtext-apply (start end grid )
   "Apply grid to region."
   (interactive
@@ -194,7 +197,7 @@ end   as specified by grid."
     (point)
     (mark)
     (read-minibuffer "Specify grid as a list: "
-		     (format "%s" (emacspeak-gridtext-get (emacspeak-gridtext-generate-key))))))
+                     (format "%s" (emacspeak-gridtext-get (emacspeak-gridtext-generate-key))))))
   (let ((grid-table (emacspeak-table-make-table
                      (emacspeak-gridtext-vector-region start
                                                        end
@@ -211,6 +214,7 @@ end   as specified by grid."
 ;;{{{  keymaps 
 (defvar emacspeak-gridtext-keymap nil
   "Prefix keymap used by gridtext.")
+
 (define-prefix-command  'emacspeak-gridtext 'emacspeak-gridtext-keymap)
 (define-key emacspeak-gridtext-keymap "a" 'emacspeak-gridtext-apply)
 (define-key emacspeak-gridtext-keymap "l"
