@@ -1,6 +1,6 @@
 ;;; emacspeak-imenu.el --- Speech enable Imenu -- produce buffer-specific table of contents
-;;; $Id: emacspeak-imenu.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-imenu.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface buffer indices
 ;;; Keywords: Emacspeak, Speak, Spoken Output, indices
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2002, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,15 +40,7 @@
 
 ;;{{{  Required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-
-(eval-when (compile)
-  (require 'imenu))
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
-(require 'emacspeak-keymap)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction
 
@@ -69,21 +61,23 @@
   ;; If optional CONCAT-NAMES is non-nil, then a nested index has its
   ;; name and a space concatenated to the names of the children.
   ;; Third argument PREFIX is for internal use only.
+
+  (declare (special imenu-level-separator))
   (mapcan
    (function
     (lambda (item)
       (let* ((name (car item))
-	     (pos (cdr item))
-	     (new-prefix (and concat-names
-			      (if prefix
-				  (concat prefix imenu-level-separator name)
-				name))))
-	(cond
-	 ((or (markerp pos) (numberp pos)
-	      (overlayp pos))
-	  (list (cons new-prefix pos)))
-	 (t
-	  (emacspeak-imenu-flatten-index-alist pos
+             (pos (cdr item))
+             (new-prefix (and concat-names
+                              (if prefix
+                                  (concat prefix imenu-level-separator name)
+                                name))))
+        (cond
+         ((or (markerp pos) (numberp pos)
+              (overlayp pos))
+          (list (cons new-prefix pos)))
+         (t
+          (emacspeak-imenu-flatten-index-alist pos
                                                new-prefix))))))
    index-alist))
 
@@ -101,7 +95,7 @@
   "Provide auditory feedback"
   (when (interactive-p)
     (ems-set-personality-temporarily (point) (1+ (point))
-                                     'paul-animated
+                                     voice-animate
                                      (emacspeak-speak-line))))
 
 (defadvice imenu-go-find-at-position (around emacspeak pre act comp)
@@ -112,7 +106,7 @@
     ad-do-it
     (emacspeak-auditory-icon 'large-movement)
     (ems-set-personality-temporarily (point) (1+ (point))
-                                     'paul-animated
+                                     voice-animate
                                      (emacspeak-speak-line)))
    (t ad-do-it))
   ad-return-value)
@@ -122,16 +116,21 @@
   (when (interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (ems-set-personality-temporarily (point) (1+ (point))
-                                     'paul-animated
+                                     voice-animate
                                      (emacspeak-speak-line))))
 
 ;;}}}
 ;;{{{  Navigation
+(defcustom emacspeak-imenu-autospeak nil
+  "Speak contents of sections automatically if set."
+  :type 'boolean
+  :group 'emacspeak-imenu)
 
 (defun emacspeak-imenu-goto-next-index-position ()
   "Goto the next index position in current buffer"
   (interactive)
   (declare (special emacspeak-imenu-flattened-index-alist
+                    emacspeak-imenu-autospeak
                     imenu--index-alist))
   (let ((position (point))
         (guess 0)
@@ -153,13 +152,19 @@
             (if (< guess target)
                 (setq target guess))))
     (goto-char target)
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-speak-line)))
+    (when (interactive-p)
+      (emacspeak-auditory-icon 'large-movement)
+      (if emacspeak-imenu-autospeak
+          (emacspeak-imenu-speak-this-section)
+        (emacspeak-speak-line))
+      (when (overlays-at (point))
+        (goto-char (overlay-end (car (overlays-at (point)))))))))
 
 (defun emacspeak-imenu-goto-previous-index-position ()
   "Goto the previous index position in current buffer"
   (interactive)
   (declare (special emacspeak-imenu-flattened-index-alist
+                    emacspeak-imenu-autospeak
                     imenu--index-alist))
   (let ((position (point))
         (guess 0)
@@ -173,16 +178,19 @@
           (setq guess
                 (cond
                  ((overlayp (cdr item))
-		  (overlay-start (cdr item )))
+                  (overlay-start (cdr item )))
                  ((markerp (cdr item))
-		  (marker-position (cdr item )))
-		 (t (cdr item))))
+                  (marker-position (cdr item )))
+                 (t (cdr item))))
           (when (> position guess)
             (if (> guess target)
                 (setq target guess))))
     (goto-char target)
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-speak-line)))
+    (when (interactive-p)
+      (emacspeak-auditory-icon 'large-movement)
+      (if emacspeak-imenu-autospeak
+          (emacspeak-imenu-speak-this-section)
+        (emacspeak-speak-line)))))
 
 ;;}}}
 ;;{{{  speaking logical sections
