@@ -1,6 +1,6 @@
 ;;; emacspeak-info.el --- Speech enable Info -- Emacs' online documentation viewer
-;;; $Id: emacspeak-info.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-info.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description:  Module for customizing Emacs info
 ;;; Keywords:emacspeak, audio interface to emacs
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -36,20 +36,14 @@
 ;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ;;}}}
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(eval-when (compile)
-  (require 'info)
-  (require 'dtk-speak))
-(require 'emacspeak-sounds)
-(require 'emacspeak-speak)
-(require 'voice-lock)
-(require 'dtk-voices)
-(require 'emacspeak-keymap)
 ;;{{{ Introduction:
 
 ;;; This module extends and customizes the Emacs info reader.
 
+;;}}}
+;;{{{ requires
+(require 'emacspeak-preamble)
+
 ;;}}}
 ;;{{{  Variables:
 
@@ -61,92 +55,34 @@
 
 ;;}}}
 ;;{{{  Voices 
-
-(defvar Info-title-personality-alist
-  '((?* bold)
-    (?= bold-italic)
-    (?-  underline))
-  "*Alist of personality or list of personalities to use for pseudo-underlined titles.
-The alist key is the character the title is underlined with (?*, ?= or ?-).")
-  
-(defvar emacspeak-info-node   'harry
-  "Personality to indicate the node name.")
-
-(defvar emacspeak-info-xref
-  'ursula
-  "Personality to indicate  cross-references.")
-
-(defvar emacspeak-info-menu-5
-  'betty
-  "Personality for menu items.")
-
-;;}}}
-;;{{{  Voiceify a node 
-
-;;; Cloned from info.el Info-fontify-node 
-(defun Info-voiceify-node ()
-  "Voiceify node."
-  (declare (special Info-title-personality-alist Info-current-node))
-  (save-excursion
-    (let ((buffer-read-only nil))
-      (goto-char (point-min))
-      (setq voice-lock-mode t)
-      (if (looking-at "^File: [^,: \t]+,?[ \t]+")
-	  (progn
-	    (goto-char (match-end 0))
-	    (while
-		(looking-at "[ \t]*[^:, \t\n]+:[ \t]+\\([^:,\t\n]+\\),?")
-	      (goto-char (match-end 0))
-	      (put-text-property (match-beginning 1) (match-end 1)
-				 'personality emacspeak-info-xref))))
-      (goto-char (point-min))
-      (while (re-search-forward "\n\\([^ \t\n].+\\)\n\\(\\*+\\|=+\\|-+\\)$"
-                                nil t)
-	(put-text-property (match-beginning 1) (match-end 1)
-			   'personality
-			   (cdr (assq (preceding-char) Info-title-personality-alist))))
-      (goto-char (point-min))
-      (while (re-search-forward "\\*Note[ \n\t]+\\([^:]*\\):" nil t)
-	(if (= (char-after (1- (match-beginning 0))) ?\") ; hack
-	    nil
-	  (put-text-property (match-beginning 1) (match-end 1)
-			     'personality emacspeak-info-xref)))
-      (goto-char (point-min))
-      (if (and (search-forward "\n* Menu:" nil t)
-               Info-current-node
-	       (not (string-match "\\<Index\\>" Info-current-node))
-	       ;; Don't take time to annotate huge menus
-	       (< (- (point-max) (point)) Info-voiceify-maximum-menu-size))
-	  (let ((n 0))
-	    (while (re-search-forward "^\\* \\([^:\t\n]*\\):" nil t)
-	      (setq n (1+ n))
-	      (if (memq n '(5 9))  ; visual aids to help with 1-9 keys
-		  (put-text-property (match-beginning 0)
-				     (1+ (match-beginning 0))
-				     'personality emacspeak-info-menu-5))
-	      (put-text-property (match-beginning 1) (match-end 1)
-				 'personality emacspeak-info-node))))
-      (set-buffer-modified-p nil))))
+(voice-setup-add-map
+ '(
+   (info-title-1 voice-bolden-extra)
+   (info-title-2 voice-bolden-medium)
+   (info-title-3 voice-bolden)
+   (info-title-4 voice-lighten)
+   (info-header-node voice-smoothen)
+   (info-header-xref voice-brighten)
+   (info-menu-5 voice-lighten)
+   (info-menu-header voice-bolden-medium)
+   (info-node voice-monotone)
+   (info-xref voice-animate-extra)
+   (info-menu-star voice-brighten)
+   (info-xref-visited voice-animate-medium)
+   ))
 
 ;;}}}
 ;;{{{ advice
 
-;;; Advice Info mode to voice lock 
-
-(defadvice Info-mode (after emacspeak pre act)
-  "Set up voice locking if requested. 
-See variable `Info-voiceify`"
-  (Info-voiceify-node))
-
-(defcustom  emacspeak-info-select-node-speak-chunk 'screenfull 
+(defcustom  emacspeak-info-select-node-speak-chunk 'screenfull
   "*Specifies how much of the selected node gets spoken.
 Possible values are:
 screenfull  -- speak the displayed screen
 node -- speak the entire node."
   :type '(menu-choice
-	  (const screenful)
-	  (const node))
-  :group 'emacspeak)
+          (const :tag "First screenfull" screenfull)
+          (const :tag "Entire node" node))
+  :group 'emacspeak-info)
 
 (defsubst emacspeak-info-speak-current-window ()
   "Speak current window in info buffer."
@@ -156,14 +92,11 @@ node -- speak the entire node."
       (forward-line (window-height window))
       (emacspeak-speak-region start (point )))))
 
-(defadvice Info-select-node (after emacspeak pre act)
-  "Voiceify the Info node if requested. 
-Speak the selected node based on setting of
-emacspeak-info-select-node-speak-chunk"
+(defun emacspeak-info-visit-node()
+  "Apply requested action upon visiting a node."
   (declare (special emacspeak-info-select-node-speak-chunk))
   (let ((dtk-stop-immediately t ))
     (emacspeak-auditory-icon 'select-object)
-    (and Info-voiceify (Info-voiceify-node))
     (cond
      ((eq emacspeak-info-select-node-speak-chunk
           'screenfull)
@@ -172,6 +105,12 @@ emacspeak-info-select-node-speak-chunk"
       (emacspeak-speak-buffer ))
      (t (emacspeak-speak-line)))))
 
+(defadvice Info-select-node (after emacspeak pre act)
+  "Voiceify the Info node if requested. 
+Speak the selected node based on setting of
+emacspeak-info-select-node-speak-chunk"
+  (emacspeak-info-visit-node))
+
 (defadvice info (after emacspeak pre act)
   "Cue user that info is up."
   (when (interactive-p)
@@ -223,16 +162,16 @@ and then cue the next selected buffer."
   "Speak info header line."
   (interactive)
   (declare (special Info-use-header-line
-		    Info-header-line))
+                    Info-header-line))
   (let ((voice-lock-mode t))
     (cond
      ((and (boundp 'Info-use-header-line)
-	   (boundp 'Info-header-line)
-	   Info-header-line)
+           (boundp 'Info-header-line)
+           Info-header-line)
       (dtk-speak Info-header-line))
      (t (save-excursion
-	  (beginning-of-buffer)
-	  (emacspeak-speak-line))))))
+          (beginning-of-buffer)
+          (emacspeak-speak-line))))))
 
 ;;}}}
 ;;{{{  Emacs 21 
@@ -249,6 +188,21 @@ and then cue the next selected buffer."
 (declaim (special Info-mode-map))
 (define-key Info-mode-map "T" 'emacspeak-info-speak-header)
 (define-key Info-mode-map "'" 'emacspeak-speak-rest-of-buffer)
+;;}}}
+;;{{{ info wizard
+;;;###autoload
+(defun emacspeak-info-wizard (node-spec )
+  "Read a node spec from the minibuffer and launch
+Info-goto-node.
+See documentation for command `Info-goto-node' for details on
+node-spec."
+  (interactive
+   (list
+    (read-from-minibuffer "Node: "
+                          "(")))
+  (Info-goto-node node-spec)
+  (emacspeak-info-visit-node))
+
 ;;}}}
 (provide  'emacspeak-info)
 ;;{{{  emacs local variables 
