@@ -1,6 +1,6 @@
 ;;; emacspeak-jde.el --- Speech enable JDE -- An integrated Java Development Environment
-;;; $Id: emacspeak-jde.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-jde.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to JDE
 ;;; Keywords: Emacspeak, Speak, Spoken Output, Java
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2002, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -39,14 +39,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Required modules
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-speak)
-(require 'emacspeak-keymap)
-(require 'emacspeak-sounds)
-(require 'voice-lock)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction
 
@@ -54,6 +47,27 @@
 ;;; The Java IDE --JDE-- can be found at 
 ;;;http://sunsite.auc.dk/jde/
 
+;;}}}
+;;{{{ voice lock 
+
+(voice-setup-add-map
+ '(
+   (jde-java-font-lock-number-face voice-lighten)
+   (jde-java-font-lock-operator-face voice-animate)
+   (jde-java-font-lock-constant-face voice-lighten)
+   (jde-java-font-lock-api-face voice-animate)
+   (jde-java-font-lock-package-face voice-monotone)
+   (jde-java-font-lock-italic-face voice-animate)
+   (jde-java-font-lock-underline-face voice-brighten-medium)
+   (jde-java-font-lock-bold-face voice-bolden)
+   (jde-java-font-lock-pre-face voice-monotone)
+   (jde-java-font-lock-code-face voice-monotone)
+   ))
+
+                                        ;jde-java-font-lock-link-face
+                                        ;jde-java-font-lock-doc-tag-face
+                                        ;jde-java-font-lock-modifier-face
+                                        
 ;;}}}
 ;;{{{ Advice interactive commands:
 (defadvice jde-open-class-source (after emacspeak pre act comp)
@@ -112,23 +126,6 @@
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
-;;}}}
-;;{{{ voice lock 
-
-(declaim (special voice-lock-defaults-alist))
-(if (not (assq 'jde-mode voice-lock-defaults-alist))
-    (setq voice-lock-defaults-alist
-          (cons
-           (cons 'jde-mode
-
-                 ;; jde-mode-defaults
-                 '((java-voice-lock-keywords java-voice-lock-keywords-1
-                                             java-voice-lock-keywords-2 java-voice-lock-keywords-3)
-                   nil nil ((?_ . "w") (?$ . "w")) nil
-                   (voice-lock-mark-block-function . mark-defun)))
-
-           voice-lock-defaults-alist)))
-
 ;;}}}
 ;;{{{ jdebug 
 
@@ -234,9 +231,9 @@
       '(
         jde-debug-step-into
         jde-debug-step-out
-	jde-debug-step-over
-	jde-debug-up
-	jde-debug-down)
+        jde-debug-step-over
+        jde-debug-up
+        jde-debug-down)
       do
       (eval
        (`
@@ -279,6 +276,40 @@
     (message "Cleared all break points.")))
 
     
+;;}}}
+;;{{{ advice jde-xref
+(defadvice jde-xref-first-caller(after emacspeak pre act comp)
+  "Speak line we jumped to."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-speak-line)))
+
+(defadvice jde-xref-next-caller(around emacspeak pre act comp)
+  "Speak line we jumped to.
+If we are on the last call, do nothing."
+  (cond
+   ( (and (interactive-p)
+          (car jde-xref-stack))
+     ad-do-it
+     (emacspeak-auditory-icon 'large-movement)
+     (emacspeak-speak-line))
+   (t ad-do-it))
+  ad-return-value)
+  
+   
+  
+
+;;}}}
+;;{{{ Advice EFC widgets:
+
+(defadvice efc-option-dialog (after emacspeak pre act comp)
+  "Announce dialog box we just opened."
+  (emacspeak-auditory-icon 'open-object)
+  (dtk-speak
+   (ad-get-arg 0)))
+            
+            
+
 ;;}}}
 (provide 'emacspeak-jde )
 ;;{{{ end of file 
