@@ -1,6 +1,6 @@
 ;;; emacspeak-ocr.el --- ocr Front-end for emacspeak desktop
-;;; $Id: emacspeak-ocr.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-ocr.el 4448 2007-04-11 03:23:39Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for OCR
 ;;; Keywords: Emacspeak, ocr
 ;;{{{  LCD Archive entry:
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-04-10 20:23:39 -0700 (Tue, 10 Apr 2007) $ |
+;;;  $Revision: 4448 $ |
 ;;; Location undetermined
 ;;;
 
@@ -54,25 +54,14 @@
 ;;; working ocr executable 
 ;;; by default this module assumes that the OCR executable
 ;;; is named "ocr"
-;;;
-
-;;}}}
-;;{{{ required modules
 
 ;;; Code:
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(require 'emacspeak-speak)
-(require 'voice-lock)
-(require 'emacspeak-sounds)
-
-(require 'derived)
-(eval-when-compile (require 'emacspeak-keymap))
+;;}}}
+;;{{{ required modules
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Customization variables
-
 (defgroup emacspeak-ocr nil
   "Emacspeak front end for scanning and OCR.
 Pre-requisites:
@@ -94,7 +83,9 @@ OCR engine for optical character recognition."
 
 (defcustom emacspeak-ocr-compress-image "tiffcp"
   "Command used to compress the scanned tiff file."
-  :type 'string
+  :type '(choice
+          (const :tag "None" nil)
+          (string :tag "Command"))
   :group 'emacspeak-ocr)
 
 (defcustom emacspeak-ocr-image-extension ".tiff"
@@ -115,7 +106,8 @@ OCR engine for optical character recognition."
 
 (defcustom emacspeak-ocr-engine-options nil
   "Command line options to pass to OCR engine."
-  :type'string
+  :type'(repeat
+         (string :tag "Option"))
   :group 'emacspeak-ocr)
 
 (defcustom emacspeak-ocr-working-directory
@@ -177,8 +169,9 @@ will be placed."
 
 (defsubst emacspeak-ocr-get-buffer ()
   "Return OCR working buffer."
-  (declare (special emacspeak-ocr-buffer-name))
-  (get-buffer-create emacspeak-ocr-buffer-name))
+  (get-buffer-create
+   (format  "*%s-ocr*"
+            (emacspeak-ocr-default-name))))
 
 (defsubst emacspeak-ocr-get-text-name ()
   "Return name of current text document."
@@ -189,16 +182,16 @@ will be placed."
   "Return name of current image."
   (declare (special emacspeak-ocr-document-name
                     emacspeak-ocr-last-page-number))
-  (format "%s-%s%s"
+  (format "%s-p%s%s"
           emacspeak-ocr-document-name
           (1+ emacspeak-ocr-last-page-number)
-	  extension))
+          extension))
 
 (defsubst emacspeak-ocr-get-page-name ()
   "Return name of current page."
   (declare (special emacspeak-ocr-document-name
                     emacspeak-ocr-current-page-number))
-  (format "%s-%s.txt"
+  (format "%s-p%s.txt"
           emacspeak-ocr-document-name
           emacspeak-ocr-current-page-number))
 
@@ -285,9 +278,10 @@ emacspeak-ocr-name-document bound to
 \\[emacspeak-ocr-name-document].  The document name is used
 in constructing the name of the image and text files.
 
-Here is a list of all emacspeak OCR commands along with their key-bindings:
+Key Bindings: 
 
-\\{emacspeak-ocr-mode-map}"
+See \\{emacspeak-ocr-mode-map}.
+"
   (progn
     (setq emacspeak-ocr-current-page-number 0
           emacspeak-ocr-last-page-number 0
@@ -324,7 +318,7 @@ Here is a list of all emacspeak OCR commands along with their key-bindings:
 
 ;;}}}
 ;;{{{ interactive commands
-
+;;;###autoload
 (defun emacspeak-ocr-customize ()
   "Customize OCR settings."
   (interactive)
@@ -332,6 +326,11 @@ Here is a list of all emacspeak OCR commands along with their key-bindings:
   (emacspeak-auditory-icon 'open-object)
   (emacspeak-speak-mode-line))
 
+(defun emacspeak-ocr-default-name ()
+  "Return a default name for OCR document."
+  (format-time-string "%m-%d-%y"))
+
+;;;###autoload
 (defun emacspeak-ocr ()
   "An OCR front-end for the Emacspeak desktop.  
 
@@ -343,9 +342,9 @@ suitable for browsing the results.
 For detailed help, invoke command emacspeak-ocr bound to
 \\[emacspeak-ocr] to launch emacspeak-ocr-mode, and press
 `?' to display mode-specific help for emacspeak-ocr-mode."
-
   (interactive)
   (declare (special emacspeak-ocr-working-directory
+                    emacspeak-ocr-document-name
                     buffer-read-only))
   (let  ((buffer (emacspeak-ocr-get-buffer )))
     (save-excursion
@@ -355,8 +354,8 @@ For detailed help, invoke command emacspeak-ocr bound to
         (cd emacspeak-ocr-working-directory))
       (switch-to-buffer buffer)
       (setq buffer-read-only t)
-      (emacspeak-ocr-name-document "untitled")
       (emacspeak-auditory-icon 'open-object)
+      (setq emacspeak-ocr-document-name (emacspeak-ocr-default-name))
       (emacspeak-speak-mode-line))))
 
 (defvar emacspeak-ocr-document-name nil
@@ -365,7 +364,7 @@ This name will be used as the prefix for naming image and
 text files produced in this scan.")
 
 (make-variable-buffer-local 'emacspeak-ocr-document-name)
-
+;;;###autoload
 (defun emacspeak-ocr-name-document (name)
   "Name document being scanned in the current OCR buffer.
 Pick a short but meaningful name."
@@ -381,11 +380,12 @@ Pick a short but meaningful name."
   (emacspeak-ocr-update-mode-line)
   (emacspeak-auditory-icon 'select-object)
   (emacspeak-speak-mode-line))
-
+;;;###autoload
 (defun emacspeak-ocr-scan-image ()
   "Acquire page image."
   (interactive)
   (declare (special emacspeak-speak-messages
+                    emacspeak-ocr-last-page-number
                     emacspeak-ocr-image-extension
                     emacspeak-ocr-keep-uncompressed-image
                     emacspeak-ocr-scan-image
@@ -398,22 +398,29 @@ Pick a short but meaningful name."
     (let ((emacspeak-speak-messages nil))
       (shell-command
        (concat
-        (format "%s %s > temp%s;\n"
-                emacspeak-ocr-scan-image
-                emacspeak-ocr-scan-image-options 
-                emacspeak-ocr-image-extension)
-        (format "%s %s  temp%s %s ;\n"
-                emacspeak-ocr-compress-image
-                emacspeak-ocr-compress-image-options
-                emacspeak-ocr-image-extension
-                image-name)
-        (if emacspeak-ocr-keep-uncompressed-image
-            (format "echo \'Uncompressed image not removed.'")
+        (format
+         "%s %s > %s;\n"
+         emacspeak-ocr-scan-image
+         emacspeak-ocr-scan-image-options 
+         (cond
+          ((not emacspeak-ocr-compress-image) image-name)
+          (t (format "temp%s" emacspeak-ocr-image-extension))))
+        (when emacspeak-ocr-compress-image
+          (format "%s %s  temp%s %s ;\n"
+                  emacspeak-ocr-compress-image
+                  emacspeak-ocr-compress-image-options
+                  emacspeak-ocr-image-extension
+                  image-name))
+        (when emacspeak-ocr-keep-uncompressed-image
           (format "rm -f temp%s"
-                  emacspeak-ocr-image-extension)))))
-    (message "Acquired  image to file %s"
-             image-name)))
+                  emacspeak-ocr-image-extension))))
+      (when (interactive-p)
+        (setq emacspeak-ocr-last-page-number
+              (1+ emacspeak-ocr-last-page-number)))
+      (message "Acquired  image to file %s"
+               image-name))))
 
+;;;###autoload
 (defun emacspeak-ocr-scan-photo (&optional metadata)
   "Scan in a photograph.
 The scanned image is converted to JPEG."
@@ -449,7 +456,7 @@ The scanned image is converted to JPEG."
             (read-from-minibuffer "Enter picture description: "))
       (let ((tempfile (format "temp%s.jpg" (gensym))))
         (shell-command
-         (format  "mv %s %s; wrjpgcom -c '%s' %s > %s; rm -f %s"
+         (format  "mv %s %s; %s -c '%s' %s > %s; rm -f %s"
                   jpg  tempfile
                   emacspeak-ocr-jpeg-metadata-writer metadata 
                   tempfile jpg
@@ -460,7 +467,7 @@ The scanned image is converted to JPEG."
 
 (defvar emacspeak-ocr-process nil
   "Handle to OCR process.")
-
+;;;###autoload
 (defun emacspeak-ocr-write-document ()
   "Writes out recognized text from all pages in current document."
   (interactive)
@@ -472,7 +479,7 @@ The scanned image is converted to JPEG."
        (point-max)
        (emacspeak-ocr-get-text-name))
       (emacspeak-auditory-icon 'save-object))))
-
+;;;###autoload
 (defun emacspeak-ocr-save-current-page ()
   "Writes out recognized text from current page
 to an appropriately named file."
@@ -506,7 +513,7 @@ to an appropriately named file."
   (emacspeak-ocr-save-current-page)
   (emacspeak-ocr-update-mode-line)
   (emacspeak-speak-line))
-
+;;;###autoload
 (defun emacspeak-ocr-recognize-image ()
   "Run OCR engine on current image.
 Prompts for image file if file corresponding to the expected
@@ -525,6 +532,7 @@ Prompts for image file if file corresponding to the expected
            (expand-file-name 
             (read-file-name "Image file to recognize: ")))))
     (goto-char (point-max))
+    (emacspeak-auditory-icon 'select-object)
     (setq emacspeak-ocr-last-page-number
           (1+ emacspeak-ocr-last-page-number))
     (aset emacspeak-ocr-page-positions
@@ -533,46 +541,37 @@ Prompts for image file if file corresponding to the expected
     (insert
      (format "\n%c\nPage %s\n" 12
              emacspeak-ocr-last-page-number))
-    (message "%s %s"
-             emacspeak-ocr-engine
-             image-name)
     (setq emacspeak-ocr-process
-          (start-process 
-           "ocr"
-           (current-buffer)
-           emacspeak-ocr-engine
-           image-name))
+          (apply 'start-process 
+                 "ocr"
+                 (current-buffer)
+                 emacspeak-ocr-engine
+                 image-name
+                 emacspeak-ocr-engine-options))
     (set-process-sentinel emacspeak-ocr-process
                           'emacspeak-ocr-process-sentinel)
     (message "Launched OCR engine.")))
 
+;;;###autoload
 (defun emacspeak-ocr-scan-and-recognize ()
   "Scan in a page and run OCR engine on it.
 Use this command once you've verified that the separate
 steps of acquiring an image and running the OCR engine work
-corectly by themselves."
+correctly by themselves."
   (interactive)
   (emacspeak-ocr-scan-image)
   (emacspeak-ocr-recognize-image))
 
-(defun emacspeak-ocr-toggle-read-only ()
-  "Toggle read-only state of OCR buffer."
-  (interactive)
-  (declare (special buffer-read-only))
-  (setq buffer-read-only
-        (not buffer-read-only))
-  (emacspeak-auditory-icon 'button)
-  (emacspeak-speak-mode-line))
-
+;;;###autoload
 (defun emacspeak-ocr-open-working-directory ()
-  "Launch dired on OCR workng directory."
+  "Launch dired on OCR working directory."
   (interactive)
   (declare (special emacspeak-ocr-working-directory))
   (switch-to-buffer
    (dired-noselect emacspeak-ocr-working-directory))
   (emacspeak-auditory-icon 'open-object)
   (emacspeak-speak-mode-line))
-
+;;;###autoload
 (defun emacspeak-ocr-forward-page (&optional count-ignored)
   "Like forward page, but tracks page number of current document."
   (interactive "p")
@@ -595,7 +594,7 @@ corectly by themselves."
       (emacspeak-ocr-update-mode-line)
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'large-movement))))
-
+;;;###autoload
 (defun emacspeak-ocr-backward-page (&optional count-ignored)
   "Like backward page, but tracks page number of current document."
   (interactive "p")
@@ -628,7 +627,7 @@ corectly by themselves."
   (emacspeak-auditory-icon 'large-movement)
   (emacspeak-speak-line)
   )
-
+;;;###autoload
 (defun emacspeak-ocr-page ()
   "Move to specified page."
   (interactive )
@@ -648,7 +647,7 @@ corectly by themselves."
       (message "Not that many pages in document."))
      (t 
       (emacspeak-ocr-goto-page page)))))
-
+;;;###autoload
 (defun emacspeak-ocr-read-current-page ()
   "Speaks current page."
   (interactive)
@@ -668,6 +667,7 @@ corectly by themselves."
        (aref emacspeak-ocr-page-positions
              (1+ emacspeak-ocr-current-page-number))))))
 
+;;;###autoload
 (defun emacspeak-ocr-set-scan-image-options  (setting)
   "Interactively update scan image options.
 Prompts with current setting in the minibuffer.
@@ -680,6 +680,7 @@ Setting persists for current Emacs session."
   (declare (special emacspeak-ocr-scan-image-options))
   (setq emacspeak-ocr-scan-image-options setting))
 
+;;;###autoload
 (defun emacspeak-ocr-set-compress-image-options  (setting)
   "Interactively update  image compression options.
 Prompts with current setting in the minibuffer.
