@@ -1,6 +1,6 @@
 ;;; emacspeak-pcl-cvs.el --- Speech enabled CVS access 
-;;; $Id: emacspeak-pcl-cvs.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-pcl-cvs.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech-enable CVS
 ;;; access 
 ;;; Keywords: Emacspeak, CVS, Audio Desktop
@@ -9,15 +9,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2002, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -39,15 +39,6 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{ required modules
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
-(require 'voice-lock)
-
-;;}}}
 ;;{{{  Introduction:
 
 ;;; Commentary:
@@ -57,8 +48,35 @@
 ;;; Code:
 
 ;;}}}
-;;{{{  speech enable interactive commands 
+;;{{{ required modules
 
+(require 'emacspeak-preamble)
+;;}}}
+;;{{{  define voices 
+
+(voice-setup-add-map
+ '(
+   (cvs-filename-face voice-bolden)
+
+   (cvs-handled-face voice-monotone-medium)
+
+   (cvs-header-face voice-bolden)
+
+   (cvs-marked-face voice-brighten-medium)
+
+   (cvs-msg-face voice-monotone-medium)
+
+   (cvs-need-action-face voice-brighten)
+   ))
+
+;;}}}
+
+;;{{{  speech enable interactive commands 
+(defadvice cvs-mode-add (after emacspeak pre act comp)
+  "Provide spoken feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-speak-line)))
 (defadvice cvs-mode-kill-buffers (after emacspeak pre act
                                         comp)
   "Produce an auditory icon."
