@@ -1,6 +1,6 @@
 ;;; emacspeak-pronounce.el --- Implements Emacspeak pronunciation dictionaries
-;;; $Id: emacspeak-pronounce.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-pronounce.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description: Emacspeak pronunciation dictionaries
 ;;; Keywords:emacspeak, audio interface to emacs customized pronunciation
 ;;{{{  LCD Archive entry:
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman 
 ;;; All Rights Reserved.
 ;;;
@@ -61,11 +61,13 @@
 ;;; Code:
 ;;{{{ required packages
 
-(eval-when-compile (require 'cl))
+(require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'custom)
 (eval-when-compile (require 'wid-edit)
-		   (require 'voice-lock))
+                   (require 'calendar)
+                   (require 'emacspeak-personality))
+(require 'voice-setup)
 (require 'thingatpt)
 (eval-when (compile)
                                         ;avoid recursive include during compile
@@ -95,11 +97,11 @@ Values are alists containing string.pronunciation pairs.")
   (setf  (gethash key emacspeak-pronounce-dictionaries) pr-alist ))
 
 (defsubst emacspeak-pronounce-get-dictionary (key)
-  (declare (special emacspeak-pronounce-dictionaries))
+  (declare (special emacspeak-pronounce-dictionaries
+                    minibuffer-history))
   (when (stringp key)
     (setq key (intern key )))
   (gethash key emacspeak-pronounce-dictionaries))
-
 (defun emacspeak-pronounce-add-dictionary-entry  (key string pronunciation)
   "Add dictionary entry.
 This adds pronunciation pair
@@ -115,7 +117,14 @@ Argument KEY specifies a dictionary key e.g. directory, mode etc."
      (t (emacspeak-pronounce-set-dictionary key
                                             (list (cons string
                                                         pronunciation)))))))
+(defun emacspeak-pronounce-remove-buffer-local-dictionary-entry (string)
+  "Remove pronunciation entry."
+  (when (and (boundp 'emacspeak-pronounce-pronunciation-table)
+             emacspeak-pronounce-pronunciation-table)
+    (remhash    string
+                emacspeak-pronounce-pronunciation-table)))
 
+  
 (defun emacspeak-pronounce-add-buffer-local-dictionary-entry  (string pronunciation)
   "Add specified pronunciation for current buffer.
 Arguments STRING and PRONUNCIATION specify what is being defined."
@@ -130,9 +139,11 @@ Arguments STRING and PRONUNCIATION specify what is being defined."
    (t                                   ;turn it on
     (setq emacspeak-pronounce-pronunciation-table
           (emacspeak-pronounce-compose-pronunciation-table))))
-  (setf (gethash  (intern string) emacspeak-pronounce-pronunciation-table) pronunciation)
-  (message "Added  local pronunciation in buffer %s"
-           (buffer-name)))
+  (puthash    string pronunciation
+              emacspeak-pronounce-pronunciation-table)
+  (when (interactive-p)
+    (message "Added  local pronunciation in buffer %s"
+             (buffer-name))))
 
 ;;}}}
 ;;{{{ setting up inheritance relations
@@ -141,7 +152,6 @@ Arguments STRING and PRONUNCIATION specify what is being defined."
 ;;; parent stored as a property on child symbol.
 ;;; when dictionary composed for a buffer, inherited dictionaries are
 ;;; also looked up.
-
 (defun emacspeak-pronounce-add-super  (parent child)
   "Make CHILD inherit PARENT's pronunciations."
   (let ((orig (get child 'emacspeak-pronounce-supers)))
@@ -164,48 +174,32 @@ Arguments STRING and PRONUNCIATION specify what is being defined."
 buffer. Handles inheritance of pronunciation dictionaries between
 modes."
   (setq buffer (or buffer (current-buffer )))
-  (let* ((table (make-hash-table))
+  (let* ((table (make-hash-table :test #'equal))
          (filename (buffer-file-name buffer))
-         (directory (and filename
-                         (file-name-directory  filename)))
+         (directory (and filename (file-name-directory  filename)))
          (mode  (save-excursion
                   (set-buffer buffer)
                   major-mode))
          (mode-supers (emacspeak-pronounce-get-supers mode))
-         (file-alist (and filename
-                          (emacspeak-pronounce-get-dictionary filename)))
-         (dir-alist (and directory
-                         (emacspeak-pronounce-get-dictionary directory)))
+         (file-alist (and filename (emacspeak-pronounce-get-dictionary filename)))
+         (dir-alist (and directory (emacspeak-pronounce-get-dictionary directory)))
          (mode-alist (emacspeak-pronounce-get-dictionary mode))
          (super-alist nil))
     (loop for super in mode-supers
           do
-          (setq super-alist
-                (emacspeak-pronounce-get-dictionary super))
+          (setq super-alist (emacspeak-pronounce-get-dictionary super))
           (loop for element in super-alist
                 do
-                (setf (gethash
-                       (intern (car element))
-                       table)
-                      (cdr element ))))
+                (puthash (car element) (cdr element ) table)))
     (loop for element in mode-alist
           do
-          (setf (gethash
-                 (intern (car element))
-                 table)
-                (cdr element )))
+          (puthash (car element) (cdr element ) table))
     (loop for element in dir-alist
           do
-          (setf (gethash
-                 (intern (car element))
-                 table)
-                (cdr element )))
+          (puthash (car element) (cdr element ) table))
     (loop for element in file-alist
           do
-          (setf (gethash
-                 (intern (car element))
-                 table)
-                (cdr element )))
+          (puthash (car element) (cdr element ) table))
     table))
 
 ;;}}}
@@ -227,7 +221,8 @@ modes."
 (emacspeak-pronounce-add-super 'text-mode 'latex-mode)
 (emacspeak-pronounce-add-super 'text-mode 'latex2e-mode)
 (emacspeak-pronounce-add-super 'text-mode 'plain-tex-mode)
-
+;;;xsl inherits from xml
+(emacspeak-pronounce-add-super 'xml-mode 'xsl-mode)
 ;;}}}
 ;;{{{  Composing and applying dictionaries:
 
@@ -252,24 +247,7 @@ Argument CHILD  specifies the mode whose supers are being requested."
 This is the personality used when speaking  things that have a pronunciation
 applied."
   :group 'emacspeak-pronounce
-  :type 'symbol)
-
-(defsubst emacspeak-pronounce-apply-pronunciations (pronunciation-table )
-  "Applies pronunciations specified in pronunciation table to current buffer.
-Modifies text and point in buffer."
-  (loop for  key  being the hash-keys  of pronunciation-table
-        do
-        (let ((word (symbol-name key))
-              (pronunciation (gethash  key pronunciation-table )))
-          (goto-char (point-min))
-          (while (search-forward  word nil t)
-            (replace-match  pronunciation t t  )
-            (and emacspeak-pronounce-pronunciation-personality
-                 (put-text-property
-                  (match-beginning 0)
-                  (+ (match-beginning 0) (length pronunciation))
-                  'personality
-                  emacspeak-pronounce-pronunciation-personality))))))
+  :type (voice-setup-custom-menu))
 
 ;;}}}
 ;;{{{  loading, clearing  and saving dictionaries
@@ -287,19 +265,22 @@ Modifies text and point in buffer."
   "Says if user dictionaries loaded on  emacspeak startup."
   :type 'boolean
   :group 'emacspeak-pronounce)
-
+;;;###autoload
 (defun emacspeak-pronounce-save-dictionaries  ()
   "Writes out the persistent emacspeak pronunciation dictionaries."
   (interactive)
-  (declare (special emacspeak-pronounce-dictionaries ))
-  (let ((filename (read-file-name
-                   "Save pronunciation dictionaries to file: "
-                   emacspeak-resource-directory
-                   emacspeak-pronounce-dictionaries-file ))
-        (buffer nil ))
+  (declare (special emacspeak-pronounce-dictionaries))
+  (let* (
+         (filename (read-file-name
+                    "Save pronunciation dictionaries to file: "
+                    emacspeak-resource-directory
+                    nil nil 
+                    (file-name-nondirectory emacspeak-pronounce-dictionaries-file )))
+         (buffer nil ))
     (setq buffer (find-file-noselect filename))
     (save-excursion
       (set-buffer buffer)
+      (auto-fill-mode nil)
       (erase-buffer)
       (loop for key being the hash-keys  of emacspeak-pronounce-dictionaries
             do
@@ -307,13 +288,11 @@ Modifies text and point in buffer."
              (format "(emacspeak-pronounce-set-dictionary '%S\n '%S )\n"
                      key
                      (emacspeak-pronounce-get-dictionary key ))))
-      (goto-char (point-min))
-      (while (search-forward ")" nil t)
-        (replace-match ")\n" nil t))
       (save-buffer))))
+
 (defvar emacspeak-pronounce-dictionaries-loaded nil
   "Indicates if dictionaries already loaded.")
-
+;;;###autoload
 (defun emacspeak-pronounce-load-dictionaries  (&optional filename)
   "Load pronunciation dictionaries.
 Optional argument FILENAME specifies the dictionary file."
@@ -326,7 +305,7 @@ Optional argument FILENAME specifies the dictionary file."
   (when (file-exists-p filename)
     (load-file filename)
     (setq emacspeak-pronounce-dictionaries-loaded t)))
-
+;;;###autoload
 (defun emacspeak-pronounce-clear-dictionaries ()
   "Clear all current pronunciation dictionaries."
   (interactive)
@@ -354,6 +333,7 @@ Optional argument FILENAME specifies the dictionary file."
   "Point where we left off reading from the buffer containing the term being defined.")
 
 (make-variable-buffer-local ' emacspeak-pronounce-yank-word-point)
+;;;###autoload
 (defsubst emacspeak-pronounce-yank-word ()
   "Yank word at point into minibuffer."
   (interactive)
@@ -370,6 +350,11 @@ Optional argument FILENAME specifies the dictionary file."
     (insert string)
     (dtk-speak string)))
 
+(defsubst emacspeak-pronounce-read-pattern (key)
+  (declare (special emacspeak-pronounce-yank-word-point
+                    emacspeak-pronounce-current-buffer))
+  (eval (read-minibuffer "Pattern")))
+
 (defsubst emacspeak-pronounce-read-term (key)
   (declare (special emacspeak-pronounce-yank-word-point
                     emacspeak-pronounce-current-buffer))
@@ -388,8 +373,9 @@ Optional argument FILENAME specifies the dictionary file."
          (define-key now-map  "\C-w"'emacspeak-pronounce-yank-word))
        now-map))))
 
+;;;###autoload
 (defun emacspeak-pronounce-define-local-pronunciation (word  pronunciation )
-  "Define buffer local pronounciation.
+  "Define buffer local pronunciation.
 Argument WORD specifies the word which should be pronounced as specified by PRONUNCIATION."
   (interactive
    (list
@@ -399,26 +385,27 @@ Argument WORD specifies the word which should be pronounced as specified by PRON
   (emacspeak-pronounce-add-buffer-local-dictionary-entry
    word pronunciation))
 
-(defun emacspeak-pronounce-define-pronunciation ()
-  "Interactively define entries in the pronunciation dictionaries.
-Default term to define is delimited by region.
-First loads any persistent dictionaries if not already loaded."
-  (interactive)
-  (declare (special emacspeak-pronounce-dictionaries-loaded))
+(defsubst emacspeak-pronounce-get-key ()
+  "Collect key from user.
+Returns a pair of the form (key-type . key)."
+  (declare (special emacspeak-pronounce-pronunciation-keys))
   (let ((key nil)
-        (word nil)
-        (pronunciation nil)
-        (key-type (completing-read  "Define pronunciation that is specific to: "
-                                    emacspeak-pronounce-pronunciation-keys nil t )))
+        (key-type
+         (read
+          (completing-read
+           "Define pronunciation that is specific to: "
+           emacspeak-pronounce-pronunciation-keys nil t ) )))
+    (when (interactive-p)               ;cleanup minibuffer history
+      (pop minibuffer-history))
     (cond
-     ((string= key-type "buffer")
+     ((eq key-type 'buffer)
       (setq key (buffer-name )))        ;handled differently
-     ((string= key-type "file")
+     ((eq key-type 'file)
       (setq key (buffer-file-name))
       (or key
           (error "Current buffer is not associated with a file"))
       (setq key (intern key)))
-     ((string= key-type "directory")
+     ((eq key-type 'directory)
       (setq key
             (or
              (condition-case nil
@@ -427,36 +414,73 @@ First loads any persistent dictionaries if not already loaded."
              default-directory))
       (or key (error "No directory associated with current buffer"))
       (setq key (intern key)))
-     ((string= key-type "mode")
+     ((eq key-type 'mode)
       (setq key
             major-mode)
       (or key (error "No major mode found for current buffer")))
      (t (error "Cannot define pronunciations with key type %s" key-type)))
-    (setq word (emacspeak-pronounce-read-term key))
+    (cons key-type key)))
+
+;;;###autoload
+(defun emacspeak-pronounce-define-template-pronunciation ()
+  "Interactively define template entries in the pronunciation dictionaries.
+Default term to define is delimited by region.
+First loads any persistent dictionaries if not already loaded."
+  (interactive)
+  (declare (special emacspeak-pronounce-dictionaries-loaded))
+  (let ((word nil)
+        (pronunciation nil)
+        (key-pair (emacspeak-pronounce-get-key)))
+    (setq word (emacspeak-pronounce-read-pattern (cdr key-pair)))
+    (setq pronunciation
+          (cons
+           (read-minibuffer
+            (format "Matcher for  %s: " word))
+           (read-minibuffer
+            (format "Pronouncer for  %s: " word))))
+    (when (and (not emacspeak-pronounce-dictionaries-loaded)
+               (y-or-n-p "Load pre existing  pronunciation dictionaries first? "))
+      (emacspeak-pronounce-load-dictionaries))
+    (unless  (eq (car key-pair)  'buffer)
+      (emacspeak-pronounce-add-dictionary-entry (cdr key-pair) word pronunciation)
+      (emacspeak-pronounce-refresh-pronunciations))
+    (when (eq (car key-pair)  'buffer)
+      (emacspeak-pronounce-add-buffer-local-dictionary-entry word pronunciation))))
+
+;;;###autoload
+(defun emacspeak-pronounce-define-pronunciation ()
+  "Interactively define entries in the pronunciation dictionaries.
+Default term to define is delimited by region.
+First loads any persistent dictionaries if not already loaded."
+  (interactive)
+  (declare (special emacspeak-pronounce-dictionaries-loaded))
+  (let ((word nil)
+        (pronunciation nil)
+        (key-pair(emacspeak-pronounce-get-key)))
+    (setq word (emacspeak-pronounce-read-term (cdr key-pair)))
     (setq pronunciation
           (read-from-minibuffer
            (format "Pronounce %s as: " word)))
     (when (and (not emacspeak-pronounce-dictionaries-loaded)
                (y-or-n-p "Load pre existing  pronunciation dictionaries first? "))
       (emacspeak-pronounce-load-dictionaries))
-    (unless  (string= key-type  "buffer")
-      (emacspeak-pronounce-add-dictionary-entry key word pronunciation)
+    (unless  (eq (car key-pair)  'buffer)
+      (emacspeak-pronounce-add-dictionary-entry (cdr key-pair) word pronunciation)
       (emacspeak-pronounce-refresh-pronunciations))
-    (when (string= key-type  "buffer")
+    (when (eq (car key-pair)  'buffer)
       (emacspeak-pronounce-add-buffer-local-dictionary-entry  word pronunciation))))
 
 ;;}}}
 ;;{{{ Turning dictionaries on and off on a per buffer basis
-
 (defvar emacspeak-pronounce-pronunciation-table nil
   "Variable holding association list of pronunciations for a buffer.
 Becomes automatically buffer local.")
 (make-variable-buffer-local 'emacspeak-pronounce-pronunciation-table)
 (setq-default emacspeak-pronounce-pronunciation-table nil)
-
+;;;###autoload
 (defun emacspeak-pronounce-toggle-use-of-dictionaries (&optional state)
   "Toggle use of pronunciation dictionaries in current buffer.
-Pronunciations can be dfined on a per file, per directory and/or per
+Pronunciations can be defined on a per file, per directory and/or per
 mode basis.
 Pronunciations are activated on a per buffer basis.
 Turning on the use of pronunciation dictionaries results in emacspeak
@@ -466,7 +490,7 @@ After this, the pronunciations will be applied whenever text in the
 buffer is spoken.
 Optional argument state can be used from Lisp programs to
 explicitly turn pronunciations on or off."
-  (interactive)
+  (interactive "P")
   (declare (special emacspeak-pronounce-pronunciation-table))
   (cond
    ((or (eq state 'on)
@@ -489,7 +513,7 @@ explicitly turn pronunciations on or off."
     (message
      "Emacspeak pronunciations have been re-activated in this buffer")
     (emacspeak-auditory-icon 'on))))
-
+;;;###autoload
 (defun emacspeak-pronounce-refresh-pronunciations ()
   "Refresh pronunciation table for current buffer.
 Activates pronunciation dictionaries if not already active."
@@ -498,12 +522,10 @@ Activates pronunciation dictionaries if not already active."
   (cond
    ((not (boundp 'emacspeak-pronounce-pronunciation-table)) ;first time
     (set (make-local-variable 'emacspeak-pronounce-pronunciation-table)
-         (emacspeak-pronounce-compose-pronunciation-table))
-    )
+         (emacspeak-pronounce-compose-pronunciation-table)))
    ( emacspeak-pronounce-pronunciation-table ;already on --refresh it
      (setq emacspeak-pronounce-pronunciation-table
-           (emacspeak-pronounce-compose-pronunciation-table))
-     )
+           (emacspeak-pronounce-compose-pronunciation-table)))
    (t                                   ;turn it on
     (setq emacspeak-pronounce-pronunciation-table
           (emacspeak-pronounce-compose-pronunciation-table))))
@@ -529,11 +551,11 @@ Activates pronunciation dictionaries if not already active."
 modes.
 See http://oz.uc.edu/~solkode/smileys.html for a full list."
   :link '(url-link :tag "Smileys Dictionary "
-		   "http://oz.uc.edu/~solkode/smileys.html")
+                   "http://oz.uc.edu/~solkode/smileys.html")
   :type '(repeat
-	  (cons :tag "Dictionary Entry"
-		(string :tag "String")
-		(string :tag "Pronunciation")))
+          (cons :tag "Dictionary Entry"
+                (string :tag "String")
+                (string :tag "Pronunciation")))
   :group 'emacspeak-pronounce )
 
 ;;}}}
@@ -541,10 +563,18 @@ See http://oz.uc.edu/~solkode/smileys.html for a full list."
 
 (defcustom emacspeak-pronounce-common-xml-namespace-uri-pronunciations 
   '(
+    ("http://schemas.google.com/g/2005" . " gd ")
+    ("http://www.w3.org/2005/Atom" . " atom ")
+    ("http://www.w3.org/1999/02/22-rdf-syntax-ns#" . "RDF Syntax")
     ("http://www.w3.org/2002/06/xhtml2" . " xhtml2 ")
+    ("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"
+     . "XUL" )
+    ("http://www.mozilla.org/xbl" . " xbl ")
+    ("http://www.w3.org/2003/XInclude" . "xinclude")
     ("http://www.w3.org/1999/XSL/Transform" . " XSLT ")
-    ("http://www.w3.org/2002/xforms/cr" . " XForms ")
-    ("http://www.w3.org/2002/xml-events" . " XEvents ")
+    ("http://www.w3.org/2002/xforms" . " XForms ")
+    ("http://www.w3.org/2001/xml-events" . " XEvents ")
+    ("http://www.w3.org/2001/vxml" . " vxml ")
     ("http://www.w3.org/2001/XMLSchema-instance". " XSchema Instance ")
     ("http://www.w3.org/2001/XMLSchema". " XSchema ")
     ("http://www.w3.org/1999/xhtml" . " xhtml ")
@@ -554,14 +584,13 @@ See http://oz.uc.edu/~solkode/smileys.html for a full list."
     )
   "Pronunciations for well known namespace URIs."
   :type '(repeat
-	  (cons :tag "Dictionary Entry"
-		(string :tag "Namespace URI")
-		(string :tag "Pronunciation")))
+          (cons :tag "Dictionary Entry"
+                (string :tag "Namespace URI")
+                (string :tag "Pronunciation")))
   :group 'emacspeak-pronounce )
 
 ;;}}}
 ;;{{{ adding predefined dictionaries to a mode:
-
 (defun emacspeak-pronounce-augment-pronunciations (mode dictionary)
   "Pushes pronunciations in specified dictionary on to the dictionary
 for the specified mode."
@@ -570,7 +599,7 @@ for the specified mode."
           do
           (unless (assoc (car e)
                          mode-alist)
-	    (push e mode-alist)))
+            (push e mode-alist)))
     (emacspeak-pronounce-set-dictionary mode mode-alist)))
 
 ;;}}}
@@ -602,7 +631,11 @@ pronunciation dictionary for the specified key."
                      :notify notify
                      '(cons :tag "Dictionary Entry"
                             (string :tag "Phrase")
-                            (string :tag "Pronounce as")))
+                            (choice  :tag "Pronunciation"
+                                     (string :tag "Pronounce as")
+                                     (cons :tag "Pronouncer"
+                                           (symbol :tag "Matcher")
+                                           (symbol :tag "Pronouncer")))))
       (widget-insert "\n")
       (widget-create 'push-button
                      :tag "Save Dictionary"
@@ -627,26 +660,27 @@ pronunciation dictionary for the specified key."
          emacspeak-pronounce-dictionaries)
         value)))))
 
+;;;###autoload
 (defun emacspeak-pronounce-edit-pronunciations (key)
   "Prompt for and launch a pronunciation editor on the
 specified pronunciation dictionary key."
   (interactive
    (list
     (let ((keys
-	   (loop for k being the hash-keys of
-		 emacspeak-pronounce-dictionaries
-		 collect
-		 (symbol-name k))))
+           (loop for k being the hash-keys of
+                 emacspeak-pronounce-dictionaries
+                 collect
+                 (symbol-name k))))
       (completing-read "Edit dictionary: "
-		       (mapcar
-			#'(lambda (k)
-			    (cons k k ))
-			keys)
-		       nil
-		       'REQUIRE-MATCH 
-		       nil
-		       'keys
-		       (car keys))))) 
+                       (mapcar
+                        #'(lambda (k)
+                            (cons k k ))
+                        keys)
+                       nil
+                       'REQUIRE-MATCH 
+                       nil
+                       'keys
+                       (car keys))))) 
   (declare (special emacspeak-pronounce-dictionaries))
   (emacspeak-pronounce-edit-generate-pronunciation-editor
    (intern key)))
@@ -658,6 +692,7 @@ specified pronunciation dictionary key."
   "Dictionary:  Clear Define Edit Load Refresh Save Toggle"
   "Help message listing emacspeak commands.")
 
+;;;###autoload
 (defun emacspeak-pronounce-dispatch ()
   "Provides the user interface front-end to Emacspeak's pronunciation dictionaries."
   (interactive)
@@ -668,6 +703,7 @@ specified pronunciation dictionary key."
       (?c (call-interactively 'emacspeak-pronounce-clear-dictionaries))
       (?d (call-interactively
            'emacspeak-pronounce-define-pronunciation t))
+      (?D (call-interactively 'emacspeak-pronounce-define-template-pronunciation t))
       (?e (call-interactively
            'emacspeak-pronounce-edit-pronunciations t))
       (?l (call-interactively 'emacspeak-pronounce-load-dictionaries))
@@ -678,12 +714,68 @@ specified pronunciation dictionary key."
     (emacspeak-auditory-icon 'close-object)))
 
 ;;}}}
+;;{{{ Helpers: pronouncers
+
+;;{{{ dates
+
+(defvar emacspeak-pronounce-date-mm-dd-yyyy-pattern
+  "[0-9]\\{2\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\([0-9]\\{2\\}\\)?"
+  "Pattern that matches dates of the form mm-dd-[cc]yy.")
+
+(defun emacspeak-pronounce-mm-dd-yyyy-date (string)
+  "Return pronunciation for mm-dd-yyyy dates."
+  (save-match-data
+    (let ((fields (mapcar #'read (split-string string "-"))))
+      (propertize
+       (calendar-date-string
+        (list (second fields)
+              (first fields)
+              (cond
+               ((< (third fields) 50)
+                (+ 2000 (third fields)))
+               ((< (third fields) 100)
+                (+ 1900 (third fields)))
+               (t (third fields)))))
+       'personality voice-punctuations-some))))
+                   
+;;}}}
+;;{{{ phone numbers
+
+(defvar emacspeak-pronounce-us-phone-number-pattern "1?-?[0-9]\\{3\\}-[0-9]\\{3\\}-[0-9]\\{4\\}"
+  "Pattern that matches US phone numbers.")
+
+(defun emacspeak-pronounce-us-phone-number (phone)
+  "Return pronunciation for US phone number."
+  (when (= 14 (length phone))
+    (setq phone (substring phone 2)))
+  (let ((area-code (substring  phone 0 3))
+        (prefix-code  (substring  phone 4 7))
+        (suffix-code  (substring  phone 8 12)))
+    (unless (string-equal "800" area-code)
+      (setq area-code
+            (replace-regexp-in-string
+             "[0-9]" " \\&" area-code)))
+    (setq prefix-code
+          (replace-regexp-in-string
+           "[0-9]" " \\&" prefix-code))
+    (setq suffix-code
+          (replace-regexp-in-string
+           "[0-9]\\{2\\}" " \\&"  suffix-code))
+    (propertize 
+     (format "%s %s, %s. "
+             area-code prefix-code suffix-code)
+     'personality voice-punctuations-some)))
+
+;;}}}
+
+;;}}}
+
 (provide  'emacspeak-pronounce)
 ;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
