@@ -1,6 +1,6 @@
 ;;; emacspeak-sgml-mode.el --- Speech enable psgml package
-;;; $Id: emacspeak-psgml.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-psgml.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak extension for psgml
 ;;; Keywords:emacspeak, audio interface to emacs psgml
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -163,7 +163,7 @@ window")))
       (emacspeak-speak-line))))
 
 (defadvice sgml-up-element (after emacspeak pre act
-				  comp)
+                                  comp)
   "Speak line we moved to"
   (when (interactive-p)
     (let ((emacspeak-show-point t))
@@ -290,12 +290,12 @@ window")))
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice sgml-edit-attrib-field-end (after emacspeak pre
-					     act comp)
+                                             act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'select-object)))
 (defadvice sgml-edit-attrib-next (after emacspeak pre
-					act comp)
+                                        act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'large-movement)
@@ -309,7 +309,7 @@ window")))
     (emacspeak-speak-line)))
 
 (defadvice sgml-edit-attrib-default  (after emacspeak pre act
-					    comp)
+                                            comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'deselect-object)
@@ -349,25 +349,25 @@ window")))
 
 (defvar emacspeak-sgml-markup-voices
   (list 
-   (cons 'start-tag 	  voice-bolden)
-   (cons 'end-tag 	  voice-bolden)
-   (cons 'comment 	  voice-monotone)
-   (cons 'pi 	   voice-animate)
-   (cons 'sgml 	  voice-animate)
-   (cons 'doctype 	  voice-lock-italic-personality)
-   (cons 'entity 	  voice-lock-italic-personality)
+   (cons 'start-tag       voice-bolden)
+   (cons 'end-tag         voice-bolden)
+   (cons 'comment         voice-monotone)
+   (cons 'pi       voice-animate)
+   (cons 'sgml    voice-animate)
+   (cons 'doctype         voice-animate)
+   (cons 'entity          voice-animate)
    (cons 'shortref     voice-bolden))
   "*List of markup to personality mappings.
 Element are of the form (MARKUP-TYPE . personality).
 Possible values for MARKUP-TYPE is:
-comment	- comment declaration
-doctype	- doctype declaration
+comment - comment declaration
+doctype - doctype declaration
 end-tag 
-ignored	- ignored marked section
-ms-end	- marked section start, if not ignored 
+ignored - ignored marked section
+ms-end  - marked section start, if not ignored 
 ms-start- marked section end, if not ignored
-pi	- processing instruction
-sgml	- SGML declaration
+pi      - processing instruction
+sgml    - SGML declaration
 start-tag
 entity  - general entity reference
 shortref- short reference")
