@@ -1,6 +1,6 @@
 ;;; emacspeak-python.el --- Speech enable Python development environment
-;;; $Id: emacspeak-python.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-python.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to python mode
 ;;; Keywords: Emacspeak, Speak, Spoken Output, python
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2002, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -38,29 +38,22 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  Required modules
+;;{{{ Introduction
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(eval-when (compile)
-  (require 'emacspeak-speak)
-  (require 'voice-lock)
-  (require 'emacspeak-keymap)
-  (require 'emacspeak-sounds))
+;;; Commentary:
 
-(eval-when (compile)
-  (require 'emacspeak-fix-interactive))
+;;; This speech-enables python-mode available on sourceforge
+
+;;; Code:
 
 ;;}}}
-;;{{{  Introduction
+;;{{{  Required modules
 
-;;;Speech enable python mode.
-;;; If you have python installed
-;;; you will find python-mode.el in the Python distribution.
-;;; If you dont have python, then you dont need this either.
+(require 'emacspeak-preamble)
 
 ;;}}}
 ;;{{{ Advice interactive commands:
+
 ;;{{{  electric editing
 
 (defadvice py-electric-colon (after emacspeak pre act comp)
@@ -73,11 +66,8 @@
   (cond
    ((interactive-p )
     (dtk-tone 500 30 'force)
-    (and emacspeak-backward-delete-char-speak-deleted-char
-	 (emacspeak-speak-this-char (preceding-char )))
-    ad-do-it
-    (and emacspeak-backward-delete-char-speak-current-char
-	 (emacspeak-speak-this-char (preceding-char ))))
+    (emacspeak-speak-this-char (preceding-char ))
+    ad-do-it)
    (t ad-do-it))
   ad-return-value)
 
@@ -86,11 +76,8 @@
   (cond
    ((interactive-p )
     (dtk-tone 500 30 'force)
-    (and emacspeak-backward-delete-char-speak-deleted-char
-	 (emacspeak-speak-this-char (preceding-char )))
-    ad-do-it
-    (and emacspeak-backward-delete-char-speak-current-char
-	 (emacspeak-speak-this-char (preceding-char ))))
+    (emacspeak-speak-this-char (preceding-char ))
+    ad-do-it)
    (t ad-do-it))
   ad-return-value)
 
@@ -100,8 +87,8 @@
 (defadvice py-shell (after emacspeak pre act comp)
   "Provide auditory feedback"
   (when (interactive-p)
-    (emacspeak-auditory-icon 'task-done)
-    (message "Launched Python interpreter")))
+    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-speak-mode-line)))
 
 (defadvice py-clear-queue (after emacspeak pre act comp)
   "Provide auditory feedback"
@@ -138,11 +125,21 @@
 
 ;;}}}
 ;;{{{  whitespace management and indentation
+(loop for f in
+      (list 'py-fill-paragraph
+            'py-fill-comment
+            'py-fill-string)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+          "Provide auditory feedback."
+          (when (interactive-p)
+            (emacspeak-auditory-icon 'fill-object)))))
 
 (defadvice py-newline-and-indent(after emacspeak pre act comp)
   "Speak line so we know current indentation"
   (when (interactive-p)
-    (dtk-speak-using-voice 'annotation-voice
+    (dtk-speak-using-voice voice-annotate
                            (format
                             "indent %s"
                             (current-column)))
@@ -199,6 +196,13 @@
   (when (interactive-p)
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
+
+(defadvice py-beginning-of-def-or-class (after emacspeak pre act comp)
+  "Speak current statement after moving"
+  (when (interactive-p)
+    (emacspeak-speak-line)
+    (emacspeak-auditory-icon 'large-movement)))
+
 (defadvice beginning-of-python-def-or-class (after emacspeak pre act comp)
   "Speak current statement after moving"
   (when (interactive-p)
@@ -211,6 +215,12 @@
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
+(defadvice py-end-of-def-or-class (after emacspeak pre act comp)
+  "Speak current statement after moving"
+  (when (interactive-p)
+    (emacspeak-speak-line)
+    (emacspeak-auditory-icon 'large-movement)))
+
 (defadvice py-mark-block (after emacspeak pre act comp)
   "Speak number of lines marked"
   (when (interactive-p)
@@ -219,7 +229,17 @@
              (count-lines (region-beginning)
                           (region-end))))
     (emacspeak-auditory-icon 'mark-object)))
-
+(defadvice py-narrow-to-defun (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (message "%s %s lines"
+             (save-excursion
+               (goto-char (point-min))
+               (buffer-substring (line-beginning-position)
+                                 (line-end-position)))
+             (count-lines (point-min)
+                          (point-max)))))
+    
 (defadvice py-mark-def-or-class (after emacspeak pre act comp)
   "Speak number of lines marked"
   (when (interactive-p)
@@ -258,6 +278,7 @@
     ad-return-value))
 
 ;;}}}
+
 ;;}}}
 ;;{{{ Additional navigation
 (defun emacspeak-py-previous-block()
@@ -281,52 +302,6 @@ If already at the beginning then move to previous block."
   (emacspeak-speak-line)
   (emacspeak-auditory-icon 'large-movement))
 
-;;}}}
-;;{{{  hooks
-
-(defun emacspeak-python-mode-hook ()
-  "Hook added by Emacspeak to python mode"
-  (unless emacspeak-audio-indentation
-    (emacspeak-toggle-audio-indentation)))
-
-(add-hook 'py-mode-hook
-          'emacspeak-python-mode-hook)
-
-;;}}}
-;;{{{  voice locking 
-
-(defvar python-voice-lock-keywords
-  (let ((kw1 (mapconcat 'identity
-			'("and"      "assert"   "break"   "class"
-			  "continue" "def"      "del"     "elif"
-			  "else"     "except"   "exec"    "for"
-			  "from"     "global"   "if"      "import"
-			  "in"       "is"       "lambda"  "not"
-			  "or"       "pass"     "print"   "raise"
-			  "return"   "while"
-			  )
-			"\\|"))
-	(kw2 (mapconcat 'identity
-			'("else:" "except:" "finally:" "try:")
-			"\\|"))
-	)
-    (list
-     ;; keywords
-     (cons (concat "\\b\\(" kw1 "\\)\\b[ \n\t(]") 1)
-     ;; block introducing keywords with immediately following colons.
-     ;; Yes "except" is in both lists.
-     (cons (concat "\\b\\(" kw2 "\\)[ \n\t(]") 1)
-     ;; classes
-     '("\\bclass[ \t]+\\([a-zA-Z_]+[a-zA-Z0-9_]*\\)"
-       1 voice-lock-type-personality)
-     ;; functions
-     '("\\bdef[ \t]+\\([a-zA-Z_]+[a-zA-Z0-9_]*\\)"
-       1 voice-lock-function-name-personality)
-     ))
-  "Additional expressions to voiceify in Python mode.")
-(voice-lock-set-major-mode-keywords 'python-mode
-				    'python-voice-lock-keywords)
-
 ;;}}}
 ;;{{{ keybindings
 
@@ -340,7 +315,8 @@ If already at the beginning then move to previous block."
   (define-key py-mode-map "\C-\M-n" 'emacspeak-py-next-block)
   (define-key py-mode-map "\C-\M-p" 'emacspeak-py-previous-block)
   )
-
+(add-hook 'python-mode-hook
+          'emacspeak-setup-programming-mode)
 ;;}}}
 (provide 'emacspeak-python )
 ;;{{{ end of file 
