@@ -1,6 +1,6 @@
 ;;; emacspeak-reftex.el --- speech enable reftex
-;;; $Id: emacspeak-reftex.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-reftex.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enable
 ;;; reftex 
 ;;; Keywords: Emacspeak, reftex
@@ -9,15 +9,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2002, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -41,15 +41,7 @@
 
 ;;{{{ required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'emacspeak-speak)
-(require 'thingatpt)
-(require 'voice-lock)
-(require 'emacspeak-fix-interactive)
-(require 'emacspeak-sounds)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
 
@@ -278,6 +270,22 @@
     (emacspeak-speak-mode-line)))
 
 ;;}}}
+;;{{{ highlighting 
+(defadvice reftex-highlight (after emacspeak pre act comp)
+  "Add  voice properties."
+  (let ((beg (ad-get-arg 1))
+        (end (ad-get-arg 2)))
+    (ems-modify-buffer-safely
+     (put-text-property beg end
+                        'personality voice-bolden))
+    (emacspeak-speak-line)
+    (sit-for 2)))
+
+;;}}}
+;;{{{  indexing 
+
+;;}}}
+
 (provide 'emacspeak-reftex)
 ;;{{{ end of file
 
