@@ -1,6 +1,6 @@
 ;;; emacspeak-sgml-mode.el --- Speech enable SGML mode
-;;; $Id: emacspeak-sgml-mode.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-sgml-mode.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak extension for sgml mode
 ;;; Keywords:emacspeak, audio interface to emacs sgml 
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -38,16 +38,14 @@
 
 ;;}}}
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-sounds)
-(require 'emacspeak-speak)
-(require 'emacspeak-fix-interactive)
-(require 'voice-lock)
 ;;{{{  Introduction
 
 ;;; emacspeak extensions to sgml mode
 
+;;}}}
+;;{{{ requires
+(require 'emacspeak-preamble)
+
 ;;}}}
 ;;{{{ advice interactive commands 
 
@@ -90,23 +88,6 @@
     (emacspeak-auditory-icon 'button)
     (dtk-speak  "Toggled display of tags")))
 
-;;}}}
-;;{{{ simple voice locking 
-
-(voice-lock-set-major-mode-keywords 'sgml-mode
-				    'sgml-voice-lock-keywords)
-
-(defconst sgml-voice-lock-keywords-1
-  '(("<\\([!?][a-z][-.a-z0-9]*\\)" 1 voice-lock-keyword-personality)
-    ("<\\(/?[a-z][-.a-z0-9]*\\)" 1 voice-lock-function-name-personality)
-    ("[&%][a-z][-.a-z0-9]*;?" . voice-lock-variable-name-personality)
-    ("<! *--.*-- *>" . voice-lock-comment-personality)))
-
-;; for voice-lock, but must be defvar'ed after
-;; sgml-voice-lock-keywords-1  above
-(defvar sgml-voice-lock-keywords sgml-voice-lock-keywords-1
-  "*Rules for highlighting SGML code.  ")
-
 ;;}}}
 (provide  'emacspeak-sgml-mode)
 ;;{{{  emacs local variables 
