@@ -1,6 +1,6 @@
 ;;; emacspeak-solitaire.el --- Speech enable Solitaire game
-;;; $Id: emacspeak-solitaire.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-solitaire.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to solitaire
 ;;; Keywords: Emacspeak, Speak, Spoken Output, solitaire
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2002, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,14 +40,8 @@
 
 ;;{{{  Required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(eval-when-compile (require 'dtk-speak)
-		   (require 'emacspeak-speak)
-		   (require 'emacspeak-sounds)
-		   (and (locate-library "solitaire")
-			(require 'solitaire)))
-
+(require 'emacspeak-preamble)
+(require 'solitaire)
 ;;}}}
 ;;{{{  Introduction 
 
@@ -59,9 +53,9 @@
 (defsubst emacspeak-solitaire-current-row ()
   (declare (special solitaire-start-y))
   (+ 1 (/ 
-	(- (solitaire-current-line)
-	   solitaire-start-y)
-	2)))
+        (- (solitaire-current-line)
+           solitaire-start-y)
+        2)))
 
 (defsubst emacspeak-solitaire-current-column()
   (declare (special solitaire-start-x))
@@ -94,15 +88,15 @@
     (let ((row (emacspeak-solitaire-current-row))
           (count 1))
       (while (not (eolp))
-	(case (char-after (point))
-	  (?o (emacspeak-solitaire-stone))
-	  (?. (emacspeak-solitaire-hole)))
-	(incf count)
-	(when (and (>= row 3)
-		   (<= row 5)
-		   (= 0 (% count 3)))
-	  (dtk-silence 1))
-	(forward-char 1))
+        (case (char-after (point))
+          (?o (emacspeak-solitaire-stone))
+          (?. (emacspeak-solitaire-hole)))
+        (incf count)
+        (when (and (>= row 3)
+                   (<= row 5)
+                   (= 0 (% count 3)))
+          (dtk-silence 1))
+        (forward-char 1))
       (skip-syntax-forward " "))
     (dtk-force)))
 
@@ -116,8 +110,8 @@
             do
             (solitaire-up))
       (case (char-after (point))
-	(?o (emacspeak-solitaire-stone))
-	(?. (emacspeak-solitaire-hole)))
+        (?o (emacspeak-solitaire-stone))
+        (?. (emacspeak-solitaire-hole)))
       (cond
        ((and (>= column 3)
              (<= column 5))
@@ -130,11 +124,11 @@
                 (?o (emacspeak-solitaire-stone))
                 (?. (emacspeak-solitaire-hole)))))
        (t (loop for count from 2 to 3
-		do
-		(solitaire-down)
-		(case (char-after (point))
-		  (?o (emacspeak-solitaire-stone))
-		  (?. (emacspeak-solitaire-hole)))))))
+                do
+                (solitaire-down)
+                (case (char-after (point))
+                  (?o (emacspeak-solitaire-stone))
+                  (?. (emacspeak-solitaire-hole)))))))
     (dtk-force)))
 
 ;;}}}
