@@ -1,6 +1,6 @@
 ;;; emacspeak-sounds.el --- Defines Emacspeak auditory icons
-;;; $Id: emacspeak-sounds.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-sounds.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Module for adding sound cues to emacspeak
 ;;; Keywords:emacspeak, audio interface to emacs, auditory icons
 ;;{{{  LCD Archive entry:
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -63,12 +63,11 @@
 ;;{{{ required modules
 
 ;;; Code:
-(eval-when-compile (require 'cl))
+(require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'custom)
 (eval-when (compile)
   (require 'dtk-speak)
-  (require 'emacspeak-load-path)
   (require 'emacspeak-aumix))
 
 ;;}}}
@@ -84,12 +83,12 @@ use `emacspeak-toggle-auditory-icons' bound to
 
 ;;}}}
 ;;{{{ Record if using midi 
-
+;;;###autoload
 (defsubst emacspeak-using-midi-p ()
   "Predicate to test if we are using midi."
   (declare (special emacspeak-auditory-icon-function))
   (or (eq emacspeak-auditory-icon-function
-          'emacspeak-midi-icon)
+          'emacspeak-play-midi-icon)
       (eq emacspeak-auditory-icon-function 'emacspeak-queue-midi-icon)))
 
 ;;}}}
@@ -149,18 +148,16 @@ If we add new icons we should declare them here. ")
   (declare (special emacspeak-sounds-icon-list))
   emacspeak-sounds-icon-list)
 
-(defvar emacspeak-default-sound ""
+(defvar emacspeak-default-sound
+  (expand-file-name
+   "default-8k/button.au"
+   emacspeak-sounds-directory)
   "Default sound to play if requested icon not found.")
 
-;;; forward declaration. Actual value is in emacspeak-setup.el
-(defvar emacspeak-sounds-directory 
-  (expand-file-name  "sounds/" emacspeak-directory)
-  "Location of auditory icons.")
-
 (defvar emacspeak-sounds-themes-table
   (make-hash-table)
   "Maps valid sound themes to the file name extension used by that theme.")
-
+;;;###autoload
 (defun emacspeak-sounds-define-theme (theme-name file-ext)
   "Define a sounds theme for auditory icons. "
   (declare (special emacspeak-sounds-themes-table))
@@ -168,12 +165,30 @@ If we add new icons we should declare them here. ")
   (setf (gethash  theme-name emacspeak-sounds-themes-table)
         file-ext ))
 
+(defgroup emacspeak-sounds nil
+  "Emacspeak auditory icons."
+  :group 'emacspeak)
+
+;;;###autoload
 (defcustom emacspeak-sounds-default-theme
   (expand-file-name "default-8k/"
                     emacspeak-sounds-directory)
   "Default theme for auditory icons. "
   :type '(directory :tag "Sound Theme Directory")
-  :group 'emacspeak)
+  :group 'emacspeak-sounds)
+;;;###autoload
+(defcustom emacspeak-play-program
+  (cond
+   ((getenv "EMACSPEAK_PLAY_PROGRAM")
+    (getenv "EMACSPEAK_PLAY_PROGRAM"))
+   ((file-exists-p "/usr/bin/aplay") "/usr/bin/aplay")
+   ((file-exists-p "/usr/bin/play") "/usr/bin/play")
+   ((file-exists-p "/usr/bin/audioplay") "/usr/bin/audioplay")
+   ((file-exists-p "/usr/demo/SOUND/play") "/usr/demo/SOUND/play")
+   (t (expand-file-name emacspeak-etc-directory "play")))
+  "Name of executable that plays sound files. "
+  :group 'emacspeak-sounds
+  :type 'string)
 
 (defvar emacspeak-sounds-current-theme 
   emacspeak-sounds-default-theme
@@ -204,14 +219,14 @@ Do not set this by hand;
   "Predicate to test if theme is available."
   (file-exists-p
    (expand-file-name theme emacspeak-sounds-directory)))
-
+;;;###autoload
 (defun emacspeak-sounds-select-theme  (theme)
   "Select theme for auditory icons."
   (interactive
    (list
     (expand-file-name
-     (read-file-name "Theme: "
-                     emacspeak-sounds-directory))))
+     (read-directory-name "Theme: "
+                          emacspeak-sounds-directory))))
   (declare (special emacspeak-sounds-current-theme
                     emacspeak-sounds-themes-table))
   (setq theme (expand-file-name theme emacspeak-sounds-directory))
@@ -227,7 +242,7 @@ Do not set this by hand;
 
                
                       
-
+;;;###autoload
 (defsubst emacspeak-get-sound-filename (sound-name)
   "Retrieve name of sound file that produces  auditory icon SOUND-NAME."
   (declare (special emacspeak-sounds-themes-table
@@ -242,13 +257,10 @@ Do not set this by hand;
         f
       emacspeak-default-sound)))  
 
-;;}}}
-;;{{{  define themes 
-
 ;;}}}
 ;;{{{  queue an auditory icon
-
-(defsubst emacspeak-queue-auditory-icon (sound-name)
+;;;###autoload
+(defun emacspeak-queue-auditory-icon (sound-name)
   "Queue auditory icon SOUND-NAME."
   (declare (special dtk-speaker-process))
   (process-send-string dtk-speaker-process
@@ -258,17 +270,21 @@ Do not set this by hand;
 ;;}}}
 ;;{{{  native player (emacs 21)
 
-(defsubst emacspeak-native-auditory-icon (sound-name)
+;;;###autoload
+(defun emacspeak-native-auditory-icon (sound-name)
   "Play auditory icon using native Emacs player."
-  (play-sound
-   (list 'sound :file
-	 (format "%s"
-		 (emacspeak-get-sound-filename sound-name )))))
+  (declare (special emacspeak-use-auditory-icons))
+  (when emacspeak-use-auditory-icons
+    (play-sound
+     (list 'sound :file
+           (format "%s"
+                   (emacspeak-get-sound-filename sound-name ))))))
 
 ;;}}}
 ;;{{{  serve an auditory icon
 
-(defsubst emacspeak-serve-auditory-icon (sound-name)
+;;;###autoload
+(defun emacspeak-serve-auditory-icon (sound-name)
   "Serve auditory icon SOUND-NAME.
 Sound is served only if `emacspeak-use-auditory-icons' is true.
 See command `emacspeak-toggle-auditory-icons' bound to \\[emacspeak-toggle-auditory-icons ]."
@@ -289,32 +305,32 @@ you attempt to play sound when /dev/audio is busy.
 It's imperative that you use the -i flag to play on
 sparc20's."
   :type 'string
-  :group 'emacspeak)
+  :group 'emacspeak-sounds)
 
-(defsubst emacspeak-play-auditory-icon (sound-name)
+(defun emacspeak-play-auditory-icon (sound-name)
   "Produce auditory icon SOUND-NAME.
 Sound is produced only if `emacspeak-use-auditory-icons' is true.
 See command `emacspeak-toggle-auditory-icons' bound to \\[emacspeak-toggle-auditory-icons ]."
-  (declare (special  emacspeak-use-auditory-icons
-                     emacspeak-play-args emacspeak-play-program))
+  (declare (special  emacspeak-use-auditory-icons emacspeak-play-program))
   (and emacspeak-use-auditory-icons
        (let ((process-connection-type nil))
-         (start-process
-          "play" nil emacspeak-play-program
-                                        ;emacspeak-play-args ;breaks sox
-          (emacspeak-get-sound-filename sound-name )))))
+         (condition-case err
+             (start-process
+              "play" nil emacspeak-play-program
+              (emacspeak-get-sound-filename sound-name))
+           (error
+            (message (error-message-string err)))))))
 
 ;;}}}
 ;;{{{  queue a midi icon
 
-(defsubst emacspeak-queue-midi-icon (midi-name)
+(defun emacspeak-queue-midi-icon (midi-name)
   "Queue midi icon midi-NAME."
   (apply 'dtk-queue-note
          (emacspeak-get-midi-note midi-name)))
 
-(defalias 'emacspeak-midi-icon 'emacspeak-play-midi-icon)
-
-(defsubst emacspeak-play-midi-icon (midi-name)
+;;;###autoload
+(defun emacspeak-play-midi-icon (midi-name)
   "Play midi icon midi-NAME."
   (apply 'dtk-force-note
          (emacspeak-get-midi-note midi-name)))
@@ -324,18 +340,20 @@ See command `emacspeak-toggle-auditory-icons' bound to \\[emacspeak-toggle-audit
 
 (defcustom emacspeak-auditory-icon-function 'emacspeak-serve-auditory-icon
   "*Function that plays auditory icons."
-  :group 'emacspeak
+  :group 'emacspeak-sounds
   :type '(choice
           (const emacspeak-play-auditory-icon)
           (const emacspeak-serve-auditory-icon)
           (const emacspeak-native-auditory-icon)
-	  (const emacspeak-queue-auditory-icon)
-          (const emacspeak-midi-icon)))
-
-(defsubst emacspeak-auditory-icon (icon)
+          (const emacspeak-queue-auditory-icon)
+          (const emacspeak-play-midi-icon)))
+;;;###autoload 
+(defun emacspeak-auditory-icon (icon)
   "Play an auditory ICON."
-  (declare (special emacspeak-auditory-icon-function))
-  (funcall emacspeak-auditory-icon-function icon))
+  (declare (special emacspeak-auditory-icon-function
+                    emacspeak-use-auditory-icons))
+  (when emacspeak-use-auditory-icons
+    (funcall emacspeak-auditory-icon-function icon)))
 
 ;;}}}
 ;;{{{  Map names to midi
@@ -345,7 +363,7 @@ See command `emacspeak-toggle-auditory-icons' bound to \\[emacspeak-toggle-audit
   "Association between symbols and midi notes.
 When producing midi icons, other modules should use names defined here.")
 
-(defvar emacspeak-default-midi-note nil
+(defvar emacspeak-default-midi-note '(100 100 .1)
   "Default note to play if requested icon not found.")
 
 (defun emacspeak-define-midi (midi-name midi-note)
@@ -480,12 +498,12 @@ is a .1ms note on instrument 60."
 ;;{{{  toggle auditory icons
 
 ;;; This is the main entry point to this module:
+;;;###autoload
 (defun emacspeak-toggle-auditory-icons (&optional prefix)
   "Toggle use of auditory icons.
 Optional interactive PREFIX arg toggles global value."
   (interactive "P")
   (declare (special emacspeak-use-auditory-icons
-                    emacspeak-aumix-multichannel-capable-p
                     dtk-program emacspeak-auditory-icon-function))
   (require 'emacspeak-aumix)
   (cond
@@ -496,11 +514,6 @@ Optional interactive PREFIX arg toggles global value."
                   emacspeak-use-auditory-icons))
    (t (setq emacspeak-use-auditory-icons
             (not emacspeak-use-auditory-icons))))
-  ;; when using software tts  use midi if we cant mix channels.
-  (when (and emacspeak-use-auditory-icons
-             (string= dtk-program "outloud")
-             (not emacspeak-aumix-multichannel-capable-p))
-    (setq emacspeak-auditory-icon-function 'emacspeak-midi-icon))
   (message "Turned %s auditory icons %s"
            (if emacspeak-use-auditory-icons  "on" "off" )
            (if prefix "" "locally"))
@@ -512,10 +525,10 @@ Optional interactive PREFIX arg toggles global value."
     ("emacspeak-serve-auditory-icon" . "emacspeak-serve-auditory-icon")
     ("emacspeak-play-auditory-icon" . "emacspeak-play-auditory-icon")
     ("emacspeak-native-auditory-icon" . "emacspeak-native-auditory-icon")
-    ("emacspeak-midi-icon" . "emacspeak-midi-icon"))
+    ("emacspeak-play-midi-icon" . "emacspeak-play-midi-icon"))
   "Table of auditory icon players used  when selecting a player.")
 
-(defsubst emacspeak-select-auditory-icon-player ()
+(defun emacspeak-select-auditory-icon-player ()
   "Pick a player for producing auditory icons."
   (declare (special emacspeak-sounds-auditory-icon-players))
   (read 
@@ -523,13 +536,14 @@ Optional interactive PREFIX arg toggles global value."
                     emacspeak-sounds-auditory-icon-players
                     nil nil 
                     "emacspeak-")))
-
+;;;###autoload
 (defun  emacspeak-set-auditory-icon-player (player)
   "Select  player used for producing auditory icons.
 Recommended choices:
 
 emacspeak-serve-auditory-icon for  the wave device.
-emacspeak-midi-icon for midi device. "
+emacspeak-queue-auditory-icon when using software TTS.
+emacspeak-play-midi-icon for midi device. "
   (interactive
    (list
     (emacspeak-select-auditory-icon-player )))
@@ -537,11 +551,10 @@ emacspeak-midi-icon for midi device. "
                     emacspeak-auditory-icon-function))
   (cond
    ((and (not emacspeak-aumix-midi-available-p)
-         (memq player '(emacspeak-midi-icon
-                        emacspeak-queue-midi-icon
-                        emacspeak-play-midi-icon)))
-    (message "Cannot use midi icons in your current
-environment."))
+         (memq player
+               '(emacspeak-play-midi-icon emacspeak-queue-midi-icon)))
+    (message
+     "Cannot use midi icons in your current environment."))
    (t (setq emacspeak-auditory-icon-function player)))
   (when (interactive-p)
     (emacspeak-auditory-icon 'select-object)))
@@ -581,13 +594,31 @@ audio player."
        emacspeak-play-args "-i"
        emacspeak-auditory-icon-function 'emacspeak-play-auditory-icon)))
 
+;;}}}
+;;{{{  flush sound driver
+
+(defcustom emacspeak-sounds-reset-snd-module-command nil
+  "Command to reset sound module."
+  :type '(choice
+          :tag "Command to reset sound modules: "
+          (const nil :tag "None")
+          (string :tag "Command "))
+  :group 'emacspeak-sounds)
+;;;###autoload
+(defun emacspeak-sounds-reset-sound  ()
+  "Reload sound drivers."
+  (interactive)
+  (declare (special emacspeak-sounds-reset-snd-module-command))
+  (when emacspeak-sounds-reset-snd-module-command
+    (shell-command emacspeak-sounds-reset-snd-module-command)))
+
 ;;}}}
 (provide  'emacspeak-sounds)
 ;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
