@@ -1,23 +1,23 @@
 ;;; emacspeak-table-ui.el --- Emacspeak's current notion of an ideal table UI
-;;; $Id: emacspeak-table-ui.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-table-ui.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
-;;{{{  LCD Archive entry: 
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
-;;; Copyright (c) 1995 by T. V. Raman  
-;;; All Rights Reserved. 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 by T. V. Raman
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -37,19 +37,15 @@
 
 ;;}}}
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(require 'emacspeak-table)
-(require 'emacspeak-tabulate)
-(eval-when-compile (require 'dtk-speak)
-		   (require 'emacspeak-speak)
-		   (require 'emacspeak-sounds))
-(require 'thingatpt)
 ;;{{{  Introduction
 
 ;;; User interface to tables
 
+;;}}}
+;;{{{ requires
+(require 'emacspeak-preamble)
+(require 'emacspeak-table)
+
 ;;}}}
 ;;{{{ define personalities
 
@@ -58,12 +54,12 @@
   :group 'emacspeak
   :prefix "emacspeak-table-")
 
-(defcustom emacspeak-table-column-header-personality 'paul-smooth
+(defcustom emacspeak-table-column-header-personality voice-smoothen
   "personality for speaking column headers."
   :type 'symbol
   :group 'emacspeak-table)
 
-(defcustom emacspeak-table-row-header-personality 'harry
+(defcustom emacspeak-table-row-header-personality voice-bolden
   "Personality for speaking row headers"
   :type 'symbol
   :group 'emacspeak-table)
@@ -74,42 +70,48 @@
 (defvar emacspeak-table-keymap (make-sparse-keymap)
   "Keymap for using in table browsing mode")
 
-(progn
-  (define-key  emacspeak-table-keymap "\M-l" 'emacspeak-table-ui-filter-load)
-  (define-key  emacspeak-table-keymap "\M-s" 'emacspeak-table-ui-filter-save)
-  (define-key emacspeak-table-keymap "#"
-    'emacspeak-table-sort-on-current-column)
-  (define-key emacspeak-table-keymap "q"
-    'emacspeak-kill-buffer-quietly)
-  (define-key emacspeak-table-keymap "x" 'emacspeak-table-copy-current-element-to-register)
-  (define-key emacspeak-table-keymap "\t"
-    'emacspeak-table-next-column)
-  (define-key emacspeak-table-keymap  '[<shift> tab] 'emacspeak-table-previous-column)
-  (define-key emacspeak-table-keymap "j" 'emacspeak-table-goto)
-  (define-key emacspeak-table-keymap '[up] 'emacspeak-table-previous-row)
-  (define-key emacspeak-table-keymap '[down] 'emacspeak-table-next-row)
-  (define-key emacspeak-table-keymap '[left] 'emacspeak-table-previous-column)
-  (define-key emacspeak-table-keymap '[right] 'emacspeak-table-next-column)
-  (define-key emacspeak-table-keymap "r" 'emacspeak-table-speak-row-header-and-element )
-  (define-key emacspeak-table-keymap "c" 'emacspeak-table-speak-column-header-and-element)
-  (define-key emacspeak-table-keymap " " 'emacspeak-table-speak-current-element)
-  (define-key emacspeak-table-keymap "b"
-    'emacspeak-table-speak-both-headers-and-element)
-  (define-key emacspeak-table-keymap "." 'emacspeak-table-speak-coordinates)
-  (define-key emacspeak-table-keymap "=" 'emacspeak-table-speak-dimensions)
-  (define-key emacspeak-table-keymap "a"
-    'emacspeak-table-select-automatic-speaking-method)
-  (define-key emacspeak-table-keymap "s" 'emacspeak-table-search)
-  (define-key emacspeak-table-keymap "f" 'emacspeak-table-speak-row-filtered)
-  (define-key emacspeak-table-keymap "g" 'emacspeak-table-speak-column-filtered)
-  (define-key emacspeak-table-keymap "h"
-    'emacspeak-table-search-headers)
-  (define-key emacspeak-table-keymap "k" 'emacspeak-table-copy-to-clipboard)
-  (define-key emacspeak-table-keymap "T" 'emacspeak-table-goto-top)
-  (define-key emacspeak-table-keymap "B" 'emacspeak-table-goto-bottom)
-  (define-key emacspeak-table-keymap "L" 'emacspeak-table-goto-left)
-  (define-key emacspeak-table-keymap "R" 'emacspeak-table-goto-right)
-  )
+(loop for binding in
+      '(
+        ( "\M-l" emacspeak-table-ui-filter-load)
+        ( "\M-s" emacspeak-table-ui-filter-save)
+        ("#"
+         emacspeak-table-sort-on-current-column)
+        ("q" emacspeak-kill-buffer-quietly)
+        ("x" emacspeak-table-copy-current-element-to-register)
+        ("w" emacspeak-table-copy-current-element-to-kill-ring)
+        ("\t" emacspeak-table-next-column)
+        ( [<shift> tab] emacspeak-table-previous-column)
+        ("j" emacspeak-table-goto)
+        ([up] emacspeak-table-previous-row)
+        ("p" emacspeak-table-previous-row)
+        ("\C-p" emacspeak-table-previous-row)
+        ([down] emacspeak-table-next-row)
+        ("n" emacspeak-table-next-row)
+        ("\C-n" emacspeak-table-next-row)
+        ([left] emacspeak-table-previous-column)
+        ("\C-b" emacspeak-table-previous-column)
+        ([right] emacspeak-table-next-column)
+        ("\C-f" emacspeak-table-next-column)
+        ("r" emacspeak-table-speak-row-header-and-element )
+        ("c" emacspeak-table-speak-column-header-and-element)
+        (" " emacspeak-table-speak-current-element)
+        ("b" emacspeak-table-speak-both-headers-and-element)
+        ("." emacspeak-table-speak-coordinates)
+        ("=" emacspeak-table-speak-dimensions)
+        ("a" emacspeak-table-select-automatic-speaking-method)
+        ("s" emacspeak-table-search)
+        ("C" emacspeak-table-search-column)
+        ("R" emacspeak-table-search-row)
+        ("f" emacspeak-table-speak-row-filtered)
+        ("g" emacspeak-table-speak-column-filtered)
+        ("h" emacspeak-table-search-headers)
+        ("k" emacspeak-table-copy-to-clipboard)
+        ("T" emacspeak-table-goto-top)
+        ("B" emacspeak-table-goto-bottom)
+        ("L" emacspeak-table-goto-left)
+        ("E" emacspeak-table-goto-right))
+      do
+      (emacspeak-keymap-update emacspeak-table-keymap binding))
 
 (defun emacspeak-table-mode ()
   "Major mode for browsing tables.
@@ -194,12 +196,13 @@ specifies the filter"
    'point-entered
    'emacspeak-table-point-motion-hook)
   (not-modified)
+  (setq buffer-undo-list t)
   (setq buffer-read-only t)
   (emacspeak-auditory-icon 'select-object)
   (emacspeak-speak-mode-line))
 
 ;;}}}
-;;{{{  speaking current entry 
+;;{{{  speaking current entry
 
 (defsubst emacspeak-table-synchronize-display ()
   "Bring visual display in sync with internal representation"
@@ -209,7 +212,7 @@ specifies the filter"
                  emacspeak-table))
         (width (frame-width)))
     (goto-char
-     (or 
+     (or
       (gethash
        (intern
         (format "element:%s:%s" row column))
@@ -302,7 +305,7 @@ specifies the filter"
                             'personality
                             emacspeak-table-column-header-personality column-head)
          (dtk-speak
-          (concat row-head" "  column-head 
+          (concat row-head" "  column-head
                   (format " %s"
                           (emacspeak-table-current-element
                            emacspeak-table)))))))
@@ -319,7 +322,7 @@ specifies the filter"
              (row-head (format "%s"
                                (emacspeak-table-row-header-element
                                 emacspeak-table row))))
-         (and row-head-p 
+         (and row-head-p
               (put-text-property 0 (length row-head)
                                  'personality
                                  emacspeak-table-row-header-personality
@@ -347,6 +350,8 @@ specifies the filter"
 Optional prefix arg prompts for a new filter."
   (interactive "P")
   (declare (special emacspeak-table-speak-row-filter
+                    voice-animate
+                    voice-smoothen
                     emacspeak-table))
   (unless (and  emacspeak-table-speak-row-filter
                 (listp emacspeak-table-speak-row-filter)
@@ -358,35 +363,34 @@ Optional prefix arg prompts for a new filter."
                                         (emacspeak-table-ui-generate-key))
                                        "("))))
     (emacspeak-table-ui-filter-set
-     (emacspeak-table-ui-generate-key
-      )emacspeak-table-speak-row-filter))
+     (emacspeak-table-ui-generate-key)
+     emacspeak-table-speak-row-filter))
   (let ((voice-lock-mode t))
     (dtk-speak
      (mapconcat
-      (function
-       (lambda (token)
-         (let ((value nil))
-           (cond
-            ((stringp token) token)
-            ((numberp token)
-             (setq value 
-                   (emacspeak-table-get-entry-with-headers
-                    (emacspeak-table-current-row emacspeak-table)
-                    token))
-             (put-text-property 0 (length value)
-                                'personality 'paul-smooth value)
-             value)
-            ((and (listp token)
-                  (numberp (first token))
-                  (numberp (second token )))
-             (setq value 
-                   (emacspeak-table-get-entry-with-headers
-                    (first token)
-                    (second token)))
-             (put-text-property 0 (length value)
-                                'personality 'paul-smooth value)
-             value)
-            (t  (format "%s" token))))))
+      #'(lambda (token)
+          (let ((value nil))
+            (cond
+             ((stringp token) token)
+             ((numberp token)
+              (setq value
+                    (emacspeak-table-get-entry-with-headers
+                     (emacspeak-table-current-row emacspeak-table)
+                     token))
+              (put-text-property 0 (length value)
+                                 'personality voice-smoothen  value)
+              value)
+             ((and (listp token)
+                   (numberp (first token))
+                   (numberp (second token )))
+              (setq value
+                    (emacspeak-table-get-entry-with-headers
+                     (first token)
+                     (second token)))
+              (put-text-property 0 (length value)
+                                 'personality voice-smoothen value)
+              value)
+             (t  (format "%s" token)))))
       emacspeak-table-speak-row-filter
       " "))))
 
@@ -408,22 +412,21 @@ Optional prefix arg prompts for a new filter."
           (read-minibuffer "Specify column filter as a list: " "(")))
   (dtk-speak
    (mapconcat
-    (function
-     (lambda (token)
-       (cond
-        ((stringp token) token)
-        ((numberp token)
-         (emacspeak-table-get-entry-with-headers
-          token
-          (emacspeak-table-current-column emacspeak-table)))
-        ((and (listp token)
-              (numberp (first token))
-              (numberp (second token )))
-         (emacspeak-table-get-entry-with-headers
-          (first token)
-          (second token)))
-        (t  (format "%s" token)))))
-    emacspeak-table-speak-column-filter 
+    #'(lambda (token)
+        (cond
+         ((stringp token) token)
+         ((numberp token)
+          (emacspeak-table-get-entry-with-headers
+           token
+           (emacspeak-table-current-column emacspeak-table)))
+         ((and (listp token)
+               (numberp (first token))
+               (numberp (second token )))
+          (emacspeak-table-get-entry-with-headers
+           (first token)
+           (second token)))
+         (t  (format "%s" token))))
+    emacspeak-table-speak-column-filter
     " ")))
 
 ;;}}}
@@ -442,10 +445,27 @@ Optional prefix arg prompts for a new filter."
 ;;}}}
 ;;{{{  opening a file of table data
 
+;;{{{ csv helpers:
+
+(defsubst ems-csv-forward-field ()
+  "Skip forward over one field."
+  (if (eq (following-char) ?\")
+      (forward-sexp)
+    (skip-chars-forward "^,\n")))
+
+(defsubst ems-csv-backward-field ()
+  "Skip backward over one field."
+  (if (eq (preceding-char) ?\")
+      (backward-sexp)
+    (skip-chars-backward "^,\n")))
+
+;;}}}
+
+
 (defsubst emacspeak-table-prepare-table-buffer (table buffer
                                                       &optional filename)
   "Prepare tabular data."
-  (declare (special positions ))
+  (declare (special emacspeak-table positions ))
   (save-excursion
     (set-buffer buffer)
     (let ((i 0)
@@ -455,6 +475,7 @@ Optional prefix arg prompts for a new filter."
           (column-start 1)
           (inhibit-read-only t))
       (setq truncate-lines t)
+      (setq buffer-undo-list t)
       (erase-buffer)
       (set (make-local-variable 'emacspeak-table) table)
       (set (make-local-variable 'positions)
@@ -464,7 +485,7 @@ Optional prefix arg prompts for a new filter."
       (loop for row across (emacspeak-table-elements table)
             do
             (loop for element across row
-                  do 
+                  do
                   (setf
                    (gethash
                     (intern (format "element:%s:%s" i j ))
@@ -484,12 +505,13 @@ Optional prefix arg prompts for a new filter."
             (put-text-property row-start (point) 'row i)
             (setq row-start (point))
             (incf i))
-      (emacspeak-table-mode)
-      (goto-char (point-min))))
+      (emacspeak-table-mode)))
   (switch-to-buffer buffer)
+  (emacspeak-table-goto-cell emacspeak-table 0 0)
   (setq truncate-lines t)
   (message "Use Emacspeak Table UI to browse this table."))
 
+;;;###autoload
 (defun emacspeak-table-find-file (filename)
   "Open a file containing table data and display it in table mode.
 emacspeak table mode is designed to let you browse tabular data using
@@ -510,45 +532,65 @@ the documentation on the table browser."
     (kill-buffer data )
     (emacspeak-table-prepare-table-buffer table buffer filename )))
 
+(defsubst ems-csv-get-fields ()
+  "Return list of fields on this line."
+  (let ((fields nil)
+        (this-field nil)
+        (start (line-beginning-position)))
+    (save-excursion
+      (goto-char start)
+      (while (not (eolp))
+        (ems-csv-forward-field)
+        (setq this-field
+              (cond
+               ((= (preceding-char) ?\")
+                (buffer-substring-no-properties (1+ start)
+                                                (1- (point))))
+               (t (buffer-substring-no-properties start  (point)))))
+        (push this-field fields)
+        (when (= (char-after) ?,)
+          (forward-char 1))
+        (setq start (point))))
+    (nreverse fields)))
+        
+;;;###autoload
 (defun emacspeak-table-find-csv-file (filename)
-  "Process a csv (comma separated values) file. 
+  "Process a csv (comma separated values) file.
 The processed  data and presented using emacspeak table navigation. "
   (interactive "FFind CSV file: ")
   (let ((scratch (get-buffer-create "*csv-scratch*"))
         (table nil)
         (elements nil)
         (this-row nil)
-        (this-line nil)
         (fields nil)
         (buffer (get-buffer-create
                  (format "*%s-table*"
                          (file-name-nondirectory filename)))))
     (save-excursion
       (set-buffer scratch)
+      (fundamental-mode)
+      (setq buffer-undo-list t)
       (erase-buffer)
-      (insert-file filename)
+      (insert-file-contents filename)
+      (flush-lines "^ *$")
       (goto-char (point-min))
-      (setq elements (make-vector (count-lines (point-min)
-                                               (point-max)) nil))
+      (setq elements
+            (make-vector (count-lines (point-min) (point-max))
+                         nil))
       (loop for i from 0 to (1- (length elements))
             do
-            (setq this-line (thing-at-point 'line))
-            (setq fields (split-string this-line ","))
-            (setq this-row (make-vector (length fields) nil))
-            (loop for j from 0 to (1- (length  fields))
-                  do
-                  (aset this-row j (nth j fields)))
-            (forward-line 1)
-            (aset elements i this-row))
+            (setq fields (ems-csv-get-fields))
+            (aset elements i (apply 'vector fields))
+            (forward-line 1))
       (setq table (emacspeak-table-make-table elements)))
     (kill-buffer scratch)
-    (emacspeak-table-prepare-table-buffer table buffer
-                                          filename )))    
+    (emacspeak-table-prepare-table-buffer table buffer filename )
+    (emacspeak-table-speak-current-element)))
 
+;;;###autoload
 (defun emacspeak-table-view-csv-buffer (&optional buffer-name)
-  "Process a csv (comma separated values) data. 
-The processed  data and presented using emacspeak table
-navigation. "
+  "Process a csv (comma separated values) data.
+The processed  data and presented using emacspeak table navigation. "
   (interactive)
   (or buffer-name
       (setq buffer-name (current-buffer)))
@@ -558,6 +600,7 @@ navigation. "
                  (format "*%s-table*" buffer-name))))
     (save-excursion
       (set-buffer scratch)
+      (setq buffer-undo-list t)
       (erase-buffer)
       (insert-buffer buffer-name)
       (goto-char (point-min))
@@ -586,6 +629,7 @@ navigation. "
 
 ;;}}}
 ;;{{{ Processing a region of tabular data
+;;;###autoload
 (defun emacspeak-table-display-table-in-region (start end)
   "Recognize tabular data in current region and display it in table
 browsing mode in a a separate buffer.
@@ -597,10 +641,11 @@ CalTrain schedules.  Execute command `describe-mode' bound to
 \\[describe-mode] in a buffer that is in emacspeak table mode to read
 the documentation on the table browser."
   (interactive "r")
-  (declare (special positions))
-  (let ((workspace (get-buffer-create " table workspace  "))
+  (declare (special emacspeak-table positions))
+  (let ((buffer-undo-list t)
+        (workspace (get-buffer-create " table workspace  "))
         (buffer (get-buffer-create
-                 (format  "*table-%s*"
+                 (format  "table-%s"
                           (or (buffer-name)
                               "scratch"))))
         (table nil)
@@ -612,15 +657,17 @@ the documentation on the table browser."
         (column-start 1)
         (text (buffer-substring start end)))
     (save-excursion
+      (when (= 10 (string-to-char (substring text -1)))
+        (setq text (substring text 0 -1)))
       (set-buffer workspace)
       (erase-buffer)
       (insert text)
       (goto-char (point-min))
       (flush-lines "^ *$")
       (setq table (emacspeak-table-make-table
-		   (ems-tabulate-parse-region
-		    (point-min)
-		    (point-max)))))
+                   (ems-tabulate-parse-region
+                    (point-min)
+                    (point-max)))))
     (kill-buffer workspace)
     (save-excursion
       (set-buffer buffer)
@@ -632,7 +679,7 @@ the documentation on the table browser."
         (loop for row across (emacspeak-table-elements table)
               do
               (loop for element across row
-                    do 
+                    do
                     (setf
                      (gethash
                       (intern (format "element:%s:%s" i j ))
@@ -654,7 +701,12 @@ the documentation on the table browser."
               (incf i))
         (emacspeak-table-mode)
         (goto-char (point-min))))
-    (switch-to-buffer buffer)))
+    (switch-to-buffer buffer)
+    (rename-buffer
+     (format "%sX%s-%s"
+             (emacspeak-table-num-rows emacspeak-table)
+             (emacspeak-table-num-columns emacspeak-table)
+             (buffer-name buffer) ))))
 
 ;;}}}
 ;;{{{ select default speaking action
@@ -671,7 +723,7 @@ browsing table elements"
   (declare (special emacspeak-table-speak-element))
   (message emacspeak-table-select-automatic-speaking-method-prompt)
   (let ((key (read-char)))
-    (setq emacspeak-table-speak-element 
+    (setq emacspeak-table-speak-element
           (case  key
             (?b 'emacspeak-table-speak-both-headers-and-element)
             (?c 'emacspeak-table-speak-column-header-and-element)
@@ -796,7 +848,7 @@ browsing table elements"
   (declare (special emacspeak-table))
   (unless (boundp 'emacspeak-table)
     (error "Cannot find table associated with this buffer"))
-  (emacspeak-table-goto-cell emacspeak-table 
+  (emacspeak-table-goto-cell emacspeak-table
                              (emacspeak-table-current-row emacspeak-table)
                              (1- (emacspeak-table-num-columns
                                   emacspeak-table)))
@@ -807,11 +859,12 @@ browsing table elements"
 ;;}}}
 ;;{{{ searching and finding:
 
-(defun emacspeak-table-search ()
+(defun emacspeak-table-search (&optional what)
   "Search the table for matching elements.  Interactively prompts for
 row or column to search and pattern to look for.    If there is a match, makes
-the matching cell current."
-  (interactive )
+the matching cell current. When called from a program, `what' can
+  be either `row' or `column'."
+  (interactive "P")
   (declare (special emacspeak-table))
   (unless (boundp 'emacspeak-table)
     (error "Cannot find table associated with this buffer"))
@@ -819,11 +872,12 @@ the matching cell current."
   (let* ((row (emacspeak-table-current-row emacspeak-table))
          (column (emacspeak-table-current-column emacspeak-table))
          (found nil)
-         (slice 
-          (case (read-char)
-            (?r 'row)
-            (?c 'column)
-            (otherwise (error "Can only search in either row or column"))))
+         (slice
+          (or what
+              (case (read-char)
+                (?r 'row)
+                (?c 'column)
+                (otherwise (error "Can only search in either row or column")))))
          (pattern (read-string
                    (format "Search in current  %s for: " slice ))))
     (cond
@@ -845,6 +899,15 @@ the matching cell current."
       (emacspeak-auditory-icon 'search-hit))
      (t (emacspeak-auditory-icon 'search-miss)))
     (funcall emacspeak-table-speak-element)))
+(defun emacspeak-table-search-row ()
+  "Search in current table row."
+  (interactive)
+  (emacspeak-table-search 'row))
+
+(defun emacspeak-table-search-column ()
+  "Search in current table column."
+  (interactive)
+  (emacspeak-table-search 'column))
 
 (defun emacspeak-table-search-headers ()
   "Search the table row or column headers.  Interactively prompts for
@@ -858,7 +921,7 @@ match, makes the matching row or column current."
   (let* ((row (emacspeak-table-current-row emacspeak-table))
          (column (emacspeak-table-current-column emacspeak-table))
          (found nil)
-         (slice 
+         (slice
           (case (read-char)
             (?r 'row)
             (?c 'column)
@@ -883,26 +946,40 @@ match, makes the matching row or column current."
       (emacspeak-table-synchronize-display)
       (emacspeak-auditory-icon 'search-hit))
      (t (emacspeak-auditory-icon 'search-miss)))
-    (funcall emacspeak-table-speak-element)))
+    (emacspeak-table-speak-both-headers-and-element)))
 
 ;;}}}
 ;;{{{ cutting and pasting tables:
 
+(defun emacspeak-table-copy-current-element-to-kill-ring ()
+  "Copy current table element to kill ring."
+  (interactive)
+  (declare (special emacspeak-table ))
+  (when (boundp 'emacspeak-table)
+    (kill-new  (emacspeak-table-current-element emacspeak-table))
+    (when (interactive-p)
+      (emacspeak-auditory-icon 'delete-object)
+      (message "Copied element to kill ring"))))
+
 (defun emacspeak-table-copy-current-element-to-register (register)
-  "Speak current table element"
+  "Copy current table element to specified register."
   (interactive "cCopy to register: ")
   (declare (special emacspeak-table ))
-  (and (boundp 'emacspeak-table)
-       (set-register register 
-                     (emacspeak-table-current-element emacspeak-table))))
+  (when  (boundp 'emacspeak-table)
+    (set-register register (emacspeak-table-current-element
+                            emacspeak-table))
+    (when (interactive-p)
+      (emacspeak-auditory-icon 'select-object)
+      (message "Copied element to register %c" register))))
+
 ;;; Implementing table editing and table clipboard.
-;;{{{ variables 
+;;{{{ variables
 
 (defvar emacspeak-table-clipboard nil
   "Variable to hold table copied to the clipboard.")
 
 ;;}}}
-;;{{{  define table markup structure and accessors 
+;;{{{  define table markup structure and accessors
 
 (defstruct (emacspeak-table-markup
             (:constructor
@@ -930,29 +1007,22 @@ table markup.")
 
 ;;}}}
 ;;{{{  define table markup for the various modes of interest
-
-(emacspeak-table-markup-set-table 'xml-mode
-                                  (emacspeak-table-make-markup
-                                   :table-start "<TABLE>\n"
-                                   :table-end "</TABLE>\n"
-                                   :row-start "<TR>\n"
-                                   :row-end "</TR>\n"
-                                   :col-start "<TD>\n"
-                                   :col-end "</TD>\n"
-                                   :col-separator ""))
-(emacspeak-table-markup-set-table 'html-helper-mode
-                                  (emacspeak-table-make-markup
-                                   :table-start "<TABLE>\n"
-                                   :table-end "</TABLE>\n"
-                                   :row-start "<TR>\n"
-                                   :row-end "</TR>\n"
-                                   :col-start "<TD>\n"
-                                   :col-end "</TD>\n"
-                                   :col-separator ""))
+(let ((html-table
+       (emacspeak-table-make-markup
+        :table-start "<TABLE>\n"
+        :table-end "</TABLE>\n"
+        :row-start "<TR>\n"
+        :row-end "</TR>\n"
+        :col-start "<TD>\n"
+        :col-end "</TD>\n"
+        :col-separator "")))
+  (emacspeak-table-markup-set-table 'xml-mode html-table)
+  (emacspeak-table-markup-set-table 'nxml-mode html-table)
+  (emacspeak-table-markup-set-table 'html-helper-mode html-table))
 
 (emacspeak-table-markup-set-table 'latex2e-mode
                                   (emacspeak-table-make-markup
-                                   :table-start "\\begin{tabular}\n"
+                                   :table-start "\\begin{tabular}{}\n"
                                    :table-end "\\end{tabular}\n"
                                    :row-start ""
                                    :row-end "\\\\\n"
@@ -995,8 +1065,8 @@ table markup.")
                                    :col-separator "\t"))
 
 ;;}}}
-;;{{{ copy and paste tables 
-
+;;{{{ copy and paste tables
+;;;###autoload
 (defun emacspeak-table-copy-to-clipboard ()
   "Copy table in current buffer to the table clipboard.
 Current buffer must be in emacspeak-table mode."
@@ -1018,8 +1088,7 @@ emacspeak-table-mode. "))
 Use the major  mode of this buffer to  decide what kind of table
 markup to use."
   (interactive)
-  (declare (special emacspeak-table-clipboard
-                    emacspeak-table))
+  (declare (special emacspeak-table-clipboard emacspeak-table))
   (let ((mode  major-mode)
         (markup nil)
         (table (emacspeak-table-elements emacspeak-table-clipboard))
@@ -1046,12 +1115,15 @@ markup to use."
         (loop for row across table
               do
               (insert (format "%s" row-start))
-              (loop for column across row
-                    do
-                    (insert (format "%s %s %s"
-                                    col-start column col-end  ))
-                    (insert (format "%s" col-separator)))
-              (insert (format "%s" row-end)))
+              (let ((current 0)
+                    (final (length row)))
+                (loop for column across row
+                      do
+                      (insert (format "%s %s %s"
+                                      col-start column col-end  ))
+                      (incf current)
+                      (unless (= current final)
+                        (insert (format "%s" col-separator)))))              (insert (format "%s" row-end)))
         (insert (format "%s" table-end))))))
 
 ;;}}}
@@ -1062,11 +1134,12 @@ markup to use."
 (defun emacspeak-table-sort-on-current-column ()
   "Sort table on current column. "
   (interactive )
-  (declare (special major-mode
-                    emacspeak-table))
+  (declare (special major-mode emacspeak-table
+                    emacspeak-table-speak-row-filter))
   (unless (eq major-mode  'emacspeak-table-mode )
     (error "This command should be used in emacspeak table mode."))
   (let* ((column  (emacspeak-table-current-column emacspeak-table))
+         (row-filter emacspeak-table-speak-row-filter)
          (elements
           (loop for e across (emacspeak-table-elements emacspeak-table)
                 collect e))
@@ -1075,20 +1148,20 @@ markup to use."
          (buffer(get-buffer-create  (format "sorted-on-%d" column ))))
     (setq sorted-list
           (sort
-           elements 
-           (function
-            (lambda (x y)
-              (cond
-               ((and (stringp  (aref x column))
-                     (stringp (aref y column)))
-                (string-lessp (aref x column)
-                              (aref y column)))
-               ((and (numberp (aref x column))
-                     (numberp (aref y column)))
-                (< (aref x column) (aref y column)))
-               (t (string-lessp
-                   (format "%s" (aref x column))
-                   (format "%s" (aref y column)))))))))
+           elements
+           #'(lambda (x y)
+               (cond
+                ((and (numberp (read (aref x column)))
+                      (numberp (read (aref y column))))
+                 (< (read (aref x column))
+                    (read (aref y column))))
+                ((and (stringp  (aref x column))
+                      (stringp (aref y column)))
+                 (string-lessp (aref x column)
+                               (aref y column)))
+                (t (string-lessp
+                    (format "%s" (aref x column))
+                    (format "%s" (aref y column))))))))
     (setq sorted-table (make-vector (length sorted-list) nil))
     (loop for i from 0 to (1- (length sorted-list))
           do
@@ -1096,10 +1169,13 @@ markup to use."
     (emacspeak-table-prepare-table-buffer
      (emacspeak-table-make-table  sorted-table)
      buffer)
+    (save-excursion
+      (set-buffer buffer)
+      (setq emacspeak-table-speak-row-filter row-filter))
     (emacspeak-speak-mode-line)))
 
 ;;}}}
-;;{{{  persistent store 
+;;{{{  persistent store
 
 (defun emacspeak-table-ui-generate-key ()
   "Generates a key for current context.
@@ -1166,11 +1242,11 @@ future  use."
 
 ;;}}}
 (provide  'emacspeak-table-ui)
-;;{{{  emacs local variables 
+;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;;; byte-compile-dynamic: nil
+;;; end:
 
 ;;}}}
