@@ -1,6 +1,6 @@
 ;;; emacspeak-table.el --- Implements data model for table browsing
-;;; $Id: emacspeak-table.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-table.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -37,14 +37,15 @@
 
 ;;}}}
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'thingatpt)
 ;;{{{  Introduction
 
 ;;; Implements a module that provides a high level interface to
 ;;; tabulated information.
 
+;;}}}
+;;{{{ requires
+(require 'emacspeak-preamble)
+
 ;;}}}
 ;;{{{  Define table data structure:
 
@@ -59,11 +60,11 @@
             (:constructor cons-emacspeak-table))
   row-header                            ;pointer to column  0
   column-header                         ;pointer to row 0
-  current-row				;row containing point 
-  current-column			;column containing point 
+  current-row                           ;row containing point 
+  current-column                        ;column containing point 
   elements                              ;  vector of  elements 
   )
-
+;;;###autoload
 (defun emacspeak-table-make-table (elements)
   "Construct a table object from elements."
   (assert (vectorp elements) t
@@ -94,8 +95,8 @@
 
 (defsubst emacspeak-table-current-element (table)
   (emacspeak-table-this-element table 
-				(emacspeak-table-current-row table )
-				(emacspeak-table-current-column table)))
+                                (emacspeak-table-current-row table )
+                                (emacspeak-table-current-column table)))
 
 (defsubst emacspeak-table-this-row (table index)
   (aref  (emacspeak-table-elements table) index))
@@ -195,7 +196,7 @@ Calls callback once per column."
       (setf (emacspeak-table-current-row table) row)
       (setf (emacspeak-table-current-column table) column))
      (t (error "Current table has %s rows and %s columns"
-	       row-count column-count )))))
+               row-count column-count )))))
         
 
 (defun emacspeak-table-move-up (table &optional count)
@@ -251,7 +252,7 @@ Calls callback once per column."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
