@@ -1,6 +1,6 @@
 ;;; emacspeak-tcl.el --- Speech enable TCL development environment
-;;; $Id: emacspeak-tcl.el,v 17.0 2002/11/23 01:29:00 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-tcl.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for tcl-mode
 ;;; Keywords:emacspeak, audio interface to emacs tcl
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -37,20 +37,17 @@
 
 ;;}}}
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
-(require 'voice-lock)
 ;;{{{  Introduction:
 
 ;;; Provide additional advice to tcl-mode 
 
+;;}}}
+;;{{{ requires
+(require 'emacspeak-preamble)
+
 ;;}}}
 ;;{{{ voice locking:
 
-(defvar tcl-voice-lock-keywords nil
-  "Keywords to highlight in tcl mode")
 ;;;  Snarfed from tcl.el /usr/local/lib/emacs/site-lisp/tcl.el
 
 (defvar tcl-proc-list
@@ -120,32 +117,6 @@ This means that the \"loop\" command has three arguments.  The first
 argument is ignored (for indentation purposes).  The second argument
 is a Tcl expression, and the last argument is Tcl commands.")
 
-(setq tcl-voice-lock-keywords
-      (list
-       ;; Names of functions (and other "defining things").
-       (list (concat tcl-proc-regexp "\\([^ \t\n]+\\)")
-	     2 'voice-lock-function-name-personality)
-
-       ;; Names of type-defining things.
-       (list (concat "\\(\\s-\\|^\\)\\("
-		     ;; FIXME Use 'regexp-quote?
-		     (mapconcat 'identity tcl-typeword-list "\\|")
-		     "\\)\\(\\s-\\|$\\)")
-	     2 'voice-lock-type-personality)
-
-       ;; Keywords.  Only recognized if surrounded by whitespace.
-       ;; FIXME consider using "not word or symbol", not
-       ;; "whitespace".
-       (cons (concat "\\(\\s-\\|^\\)\\("
-		     ;; FIXME Use regexp-quote? 
-		     (mapconcat 'identity tcl-keyword-list "\\|")
-		     "\\)\\(\\s-\\|$\\)")
-	     2)
-       )
-      )
-
-(voice-lock-set-major-mode-keywords 'tcl-mode 	    'tcl-voice-lock-keywords)
-
 ;;}}}
 ;;{{{  Advice electric insertion to talk:
 
@@ -182,11 +153,11 @@ is a Tcl expression, and the last argument is Tcl commands.")
   (when (interactive-p)
     (let* ((start nil)
            (proc-line
-	    (save-excursion
-	      (tcl-beginning-of-defun)
-	      (setq start (point))
-	      (end-of-line)
-	      (buffer-substring start (point)))))
+            (save-excursion
+              (tcl-beginning-of-defun)
+              (setq start (point))
+              (end-of-line)
+              (buffer-substring start (point)))))
       (message "Evaluated  %s" proc-line ))))
 
 (defadvice tcl-help-on-word (after emacspeak pre act comp)
