@@ -1,6 +1,6 @@
 ;;; emacspeak-tetris.el --- Speech enable game of Tetris
-;;; $Id: emacspeak-tetris.el,v 17.0 2002/11/23 01:29:01 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-tetris.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to tetris
 ;;; Keywords: Emacspeak, Speak, Spoken Output, tetris
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:01 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2002, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,15 +40,10 @@
 
 ;;{{{  Required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(eval-when-compile (require 'dtk-speak)
-                   (require 'emacspeak-speak)
-                   (require 'emacspeak-sounds)
-                   (condition-case nil
-                       (require 'tetris)
-                     (error nil)))
-
+(require 'emacspeak-preamble)
+(condition-case nil
+    (require 'tetris)            ;FC2 Emacs doesn't contain tetris.el?
+  )
 ;;}}}
 ;;{{{  Introduction 
 
@@ -63,21 +58,24 @@
 (defun emacspeak-tetris-define-pronunciations ()
   "Define speech display for tetris"
   (declare (special emacspeak-tetris-pronunciations-defined
-                    emacspeak-pronounce-dictionaries-loaded))
+                    emacspeak-pronounce-pronunciation-table emacspeak-pronounce-dictionaries-loaded))
   (require 'emacspeak-pronounce)
   (unless emacspeak-tetris-pronunciations-defined
     (setq emacspeak-tetris-pronunciations-defined t)
-    (emacspeak-pronounce-set-dictionary 'tetris-mode
-                                        '(("" . " 1 ")
-                                          ("" . " 6 ")
-                                          ("" . " 7 ")
-                                          ("" . " 5 ")
-                                          ("" . " 4 ")
-                                          ("" . " 3 ")
-                                          ("" . " 2 ")
-                                          (" " . "-")
-                                          ("" . "") ;border char
-                                          ("." . ""))))
+    (mapcar
+     #'(lambda (entry)
+         (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
+                                                   (car entry) (cdr entry)))
+     '(("" . " 1 ")
+       ("" . " 6 ")
+       ("" . " 7 ")
+       ("" . " 5 ")
+       ("" . " 4 ")
+       ("" . " 3 ")
+       ("" . " 2 ")
+       (" " . "-")
+       ("" . "")                      ;border char
+       ("." . ""))))
   (when (or (not (boundp 'emacspeak-pronounce-pronunciation-table))
             (not emacspeak-pronounce-pronunciation-table))
     (emacspeak-pronounce-toggle-use-of-dictionaries)))
@@ -94,7 +92,7 @@
 (aset emacspeak-tetris-shape-name-table 4 " z ")
 (aset emacspeak-tetris-shape-name-table 5 " s ")
 (aset emacspeak-tetris-shape-name-table 6 " inverted t ")
-(aset emacspeak-tetris-shape-name-table 7 " edge ")
+(aset emacspeak-tetris-shape-name-table 7 " line ")
 (defsubst emacspeak-tetris-blank-row ()
   (declare (special tetris-width))
   (make-string tetris-width  0))
@@ -150,12 +148,18 @@
   "Speak current shape"
   (interactive)
   (declare (special tetris-shape tetris-rot
-                    tetris-next-shape))
+                    tetris-next-shape
+                    tetris-n-rows emacspeak-tetris-filled-a-row))
   (dtk-speak
-   (format "%s at rotation  %s next is %s"
+   (format "%s %s at rotation  %s next is %s"
+           (if emacspeak-tetris-filled-a-row 
+               tetris-n-rows
+             " ")
            (emacspeak-tetris-shape-name (1+ tetris-shape))
            tetris-rot
-           (emacspeak-tetris-shape-name (1+ tetris-next-shape)))))
+           (emacspeak-tetris-shape-name (1+ tetris-next-shape))))
+  (if emacspeak-tetris-filled-a-row
+      (setq  emacspeak-tetris-filled-a-row nil)))
 
 (defsubst emacspeak-tetris-speak-next-shape ()
   "Speak next shape"
@@ -172,7 +176,7 @@
                      tetris-shape tetris-rot))
   (message "%s at %s %s  at rotation %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
-	   tetris-pos-x
+           tetris-pos-x
            tetris-pos-y
            tetris-rot))
 
@@ -326,6 +330,7 @@ concentration and the game is a good mental challenge. "
     (setq tetris-width emacspeak-tetris-width)
     (setq emacspeak-tetris-blank-row (emacspeak-tetris-blank-row))
     ad-do-it
+    (dtk-set-punctuations 'all)
     (emacspeak-tetris-define-pronunciations)
     (emacspeak-tetris-define-keys)
     (emacspeak-tetris-speak-current-shape)
@@ -390,10 +395,13 @@ concentration and the game is a good mental challenge. "
   "Provide auditory feedback as the tile falls"
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)))
+(defvar emacspeak-tetris-filled-a-row nil
+  "Temporary flag indicating if we just filled a row.")
 
 (defadvice tetris-full-row (after emacspeak pre act comp)
   "Signal full rows"
   (when ad-return-value
+    (setq emacspeak-tetris-filled-a-row t)
     (emacspeak-auditory-icon 'item)))
 
 (defadvice tetris-draw-score (around emacspeak pre act comp)
@@ -413,10 +421,10 @@ concentration and the game is a good mental challenge. "
   (define-key tetris-mode-map "N" 'tetris-start-game)
   (define-key  tetris-mode-map "c" 'emacspeak-tetris-speak-row)
   (loop for i from 0 to 9
-	do
-	(define-key tetris-mode-map
-	  (format "%s" i)
-	  'tetris-move-to-x-pos))
+        do
+        (define-key tetris-mode-map
+          (format "%s" i)
+          'tetris-move-to-x-pos))
   (define-key tetris-mode-map "a" 'tetris-move-left-edge)
   (define-key tetris-mode-map "e" 'tetris-move-right-edge)
   (define-key tetris-mode-map "l" 'tetris-move-right)
@@ -461,6 +469,7 @@ concentration and the game is a good mental challenge. "
 (defun tetris-move-left-edge ()
   "Moves the shape to the left edge  of the playing area"
   (interactive)
+  (declare (special tetris-pos-x tetris-width))
   (let ((hit nil))
     (tetris-erase-shape)
     (while(and (> tetris-pos-x 0)
@@ -468,21 +477,24 @@ concentration and the game is a good mental challenge. "
       (setq tetris-pos-x (1- tetris-pos-x))
       (setq hit (tetris-test-shape)))
     (tetris-draw-shape)))
-(defun tetris-move-right-edge ()
-  "Moves the shape to the right edge  of the playing area"
-  (interactive)
-  (let ((hit nil)
-        (max(- tetris-width (tetris-shape-width))))
-    (tetris-erase-shape)
-    (while(and (< tetris-pos-x max)
-               (not hit))
-      (setq tetris-pos-x (1+ tetris-pos-x))
-      (setq hit (tetris-test-shape)))
-    (tetris-draw-shape)))
+
+a(defun tetris-move-right-edge ()
+   "Moves the shape to the right edge  of the playing area"
+   (interactive)
+   (declare (special tetris-pos-x tetris-width))
+   (let ((hit nil)
+         (max(- tetris-width (tetris-shape-width))))
+     (tetris-erase-shape)
+     (while(and (< tetris-pos-x max)
+                (not hit))
+       (setq tetris-pos-x (1+ tetris-pos-x))
+       (setq hit (tetris-test-shape)))
+     (tetris-draw-shape)))
 
 (defun tetris-move-to-x-pos ()
   "Moves the shape to a specified x position if possible"
   (interactive)
+  (declare (special tetris-pos-x tetris-width))
   (let ((hit nil)
         (x
          (condition-case nil
@@ -521,7 +533,7 @@ concentration and the game is a good mental challenge. "
     (setq result
           (loop for y from tetris-top-left-y
                 to (+ tetris-height tetris-top-left-y)
-		collect (gamegrid-get-cell x y)))
+                collect (gamegrid-get-cell x y)))
     (mapconcat 'char-to-string result "")))
 
 (defun emacspeak-tetris-speak-column (&optional x)
