@@ -1,6 +1,6 @@
 ;;; emacspeak-texinfo.el --- Speech enable texinfo mode
-;;; $Id: emacspeak-texinfo.el,v 17.0 2002/11/23 01:29:01 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-texinfo.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable
 ;;; texinfo mode
 ;;; Keywords: Emacspeak, texinfo
@@ -9,14 +9,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:01 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -40,16 +40,9 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Required modules 
-
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(eval-when-compile (require 'dtk-speak)
-                   (require 'emacspeak-speak)
-                   (require 'emacspeak-sounds)
-                   (require 'voice-lock))
-
-;;}}};;{{{  Introduction:
+(require 'emacspeak-preamble)
+;;}}}
+;;{{{  Introduction:
 
 ;;; Commentary:
 
@@ -59,29 +52,14 @@
 
 ;;}}}
 ;;{{{ voice locking
-(defvar texinfo-voice-lock-keywords
-  '(
-    ("^\\(@c\\|@comment\\)\\>.*" . voice-lock-comment-personality) ;comments
-    ("@\\([a-zA-Z]+\\|[^ \t\n]\\)" 1 voice-lock-keyword-personality) ;commands
-    ("^\\*\\(.*\\)[\t ]*$" 1 voice-lock-function-name-personality t) ;menu items
-    ("@\\(emph\\|strong\\|b\\|i\\){\\([^}]+\\)" 2 voice-lock-comment-personality)
-    ("@\\(file\\|kbd\\|key\\|url\\|email\\){\\([^}]+\\)" 2 voice-lock-string-personality)
-    ("@\\(samp\\|code\\|var\\|math\\){\\([^}]+\\)"
-     2 voice-lock-variable-name-personality)
-    ("@\\(cite\\|xref\\|pxref\\){\\([^}]+\\)" 2 voice-lock-constant-personality)
-    ("@\\(end\\|itemx?\\) +\\(.+\\)" 2 voice-lock-function-name-personality keep)
-    )
-  "Additional expressions to highlight in TeXinfo mode.")
 
 (defun emacspeak-texinfo-mode-hook ()
   "Setup Emacspeak extensions"
-  (declare (special texinfo-voice-lock-keywords
-                    dtk-split-caps
-                    voice-lock-defaults))
-  (make-local-variable 'voice-lock-defaults)
-  (setq voice-lock-defaults '(texinfo-voice-lock-keywords t))
+  (declare (special dtk-split-caps))
+  
+  
   (voice-lock-mode 1)
-  (dtk-set-punctuations "all")
+  (dtk-set-punctuations 'all)
   (or dtk-split-caps
       (dtk-toggle-split-caps))
   (or emacspeak-audio-indentation
@@ -101,21 +79,21 @@
     (emacspeak-speak-line)))
 
 (defadvice TeXinfo-insert-environment (after emacspeak pre act
-					     comp)
+                                             comp)
   "Provide auditory feedback"
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice texinfo-insert-@item (after emacspeak pre act
-				       comp)
+                                       comp)
   "Provide auditory feedback"
   (when (interactive-p)
     (emacspeak-auditory-icon 'item)
     (emacspeak-speak-line)))
 
 (defadvice texinfo-insert-@node (after emacspeak pre act
-				       comp)
+                                       comp)
   "Provide auditory feedback"
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)
