@@ -1,6 +1,6 @@
 ;;; emacspeak-tnt.el --- Instant Messenger 
-;;; $Id: emacspeak-tnt.el,v 17.0 2002/11/23 01:29:01 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-tnt.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Speech-enable AOL Instant Messenger Client TNT
 ;;; Keywords: Emacspeak, Instant Messaging 
 ;;{{{  LCD Archive entry:
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:01 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2002, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,15 +40,7 @@
 
 ;;{{{ required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'emacspeak-speak)
-(require 'emacspeak-pronounce)
-(require 'voice-lock)
-(require 'emacspeak-fix-interactive)
-(require 'emacspeak-sounds)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
 
@@ -66,8 +58,9 @@
   "Provide additional auditory feedback"
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)))
+(declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
 (emacspeak-pronounce-augment-pronunciations 'tnt-im-mode
-					    emacspeak-pronounce-internet-smileys-pronunciations)
+                                            emacspeak-pronounce-internet-smileys-pronunciations)
 (emacspeak-pronounce-augment-pronunciations 'tnt-chat-mode
                                             emacspeak-pronounce-internet-smileys-pronunciations)
 
@@ -228,7 +221,7 @@ automatically."
     (setq emacspeak-tnt-autospeak (default-value 'emacspeak-tnt-autospeak )))
    (t (make-local-variable 'emacspeak-tnt-autospeak)
       (setq emacspeak-tnt-autospeak
-	    (not emacspeak-tnt-autospeak ))))
+            (not emacspeak-tnt-autospeak ))))
   (when (interactive-p)
     (emacspeak-auditory-icon
      (if emacspeak-tnt-autospeak 'on 'off))
@@ -247,14 +240,36 @@ automatically."
 
 ;;}}}
 ;;{{{ set up face to voice mapping
-
-(voice-setup-set-voice-for-face 'tnt-my-name-face 'paul-smooth)
-
+(voice-setup-add-map
+ '(
+   (tnt-my-name-face voice-smoothen)
+   (tnt-buddy-list-active-face voice-animate)
+   (tnt-buddy-list-inactive-face voice-monotone-medium)
+   (tnt-buddy-list-idle-face voice-smoothen-medium)
+   (tnt-buddy-list-away-face voice-monotone)
+   (tnt-buddy-list-pounce-face (quote ursula))
+   ))
 ;;}}}
 ;;{{{  Activate pronunciations 
 (add-hook 'tnt-buddy-list-mode-hook
           'emacspeak-pronounce-refresh-pronunciations)
 
+;;}}}
+;;{{{ avoid chatter
+(defadvice tnt-handle-closed(around emacspeak pre act comp)
+  "Silence messages."
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it))
+
+(defadvice tnt-handle-opened(around emacspeak pre act comp)
+  "Silence messages."
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it))
+(defadvice tnt-handle-sign-on(around emacspeak pre act comp)
+  "Silence messages."
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it))
+
 ;;}}}
 (provide 'emacspeak-tnt)
 ;;{{{ end of file
