@@ -1,6 +1,6 @@
 ;;; emacspeak-view.el --- Speech enable View mode -- Efficient browsing of read-only content
-;;; $Id: emacspeak-view.el,v 17.0 2002/11/23 01:29:01 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-view.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for view
 ;;; Keywords:emacspeak, audio interface to emacs, view-mode
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:01 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1996 by T. V. Raman 
 ;;; All Rights Reserved. 
 ;;;
@@ -37,15 +37,14 @@
 
 ;;}}}
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'dtk-voices)
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
 ;;{{{  Introduction:
 
 ;;; Provide additional advice to view-mode
 
+;;}}}
+;;{{{ requires
+(require 'emacspeak-preamble)
+
 ;;}}}
 ;;{{{  Setup view mode to work with emacspeak
 
@@ -54,7 +53,7 @@
 (add-hook 'view-mode-hook
           (function (lambda ()
                       (local-unset-key emacspeak-prefix )
-		      (emacspeak-view-setup-keys))))
+                      (emacspeak-view-setup-keys))))
 ;;; Generate automatic advise:
 
 ;;}}}
@@ -71,14 +70,20 @@
 ;;{{{ Advise additional interactive commands:
 (defadvice view-file (after emacspeak pre act comp)
   "Load directory specific settings"
-  (emacspeak-speak-load-directory-settings))
+  (emacspeak-speak-load-directory-settings)
+  (outline-minor-mode 1))
+
 (defadvice view-mode (after emacspeak pre act comp)
   "Announce what happened"
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)
-    (message "Entered view mode Press %s to exit"
-	     (key-description
-	      (where-is-internal 'View-exit view-mode-map 'firstonly)))))
+    (emacspeak-speak-load-directory-settings)
+    (outline-minor-mode 1)
+    (if view-mode
+        (message "Entered view mode Press %s to exit"
+                 (key-description
+                  (where-is-internal 'View-exit view-mode-map 'firstonly)))
+      (message "Exited view mode"))))
 
 (defadvice View-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
@@ -236,11 +241,11 @@
                    (ad-get-arg 0 )))
           (voice-lock-mode t))
       (put-text-property 0 (length line-number)
-                         'personality 'annotation-voice line-number)
+                         'personality voice-annotate line-number)
       (emacspeak-auditory-icon 'large-movement)
       (dtk-speak
        (concat line-number
-	       (thing-at-point 'line))))))
+               (thing-at-point 'line))))))
 (defadvice View-scroll-to-buffer-end (after emacspeak pre act comp)
   "Provide auditory feedback"
   (when (interactive-p)
