@@ -1,24 +1,24 @@
 ;;; emacspeak-vm.el --- Speech enable VM -- A powerful mail agent (and the one I use)
-;;; $Id: emacspeak-vm.el,v 17.0 2002/11/23 01:29:01 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-vm.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enhance vm
 ;;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
-;;{{{  LCD Archive entry: 
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:01 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved. 
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -37,23 +37,19 @@
 ;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ;;}}}
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(require 'dtk-voices)
-(require 'voice-lock)
-(require 'emacspeak-keymap)
-(require 'dtk-speak)
-(require 'emacspeak-sounds)
-(require 'emacspeak-speak)
+
 ;;{{{  Introduction:
 ;;; This module extends the mail reader vm.
 ;;; Uses voice locking for message headers and cited messages
 
+;;}}}
+;;{{{ requires
+(require 'emacspeak-preamble)
+
 ;;}}}
 ;;{{{ voice locking:
 
-(defgroup  emacspeak-vm nil
+(defgroup emacspeak-vm nil
   "VM mail reader on the Emacspeak Desktop."
   :group 'emacspeak
   :group 'vm
@@ -65,65 +61,19 @@ Note that some badly formed mime messages  cause trouble."
   :type 'boolean
   :group 'emacspeak-vm)
 
-(defvar vm-voice-lock-keywords nil
-  "Keywords to highlight in vm")
-
-(defvar vm-summary-voice-lock-keywords
-  "Additional expressions to highlight in vm  Summary mode.")
-
-;;;  Set vm-voice-lock-keywords
-
-(setq vm-voice-lock-keywords
-      (append vm-voice-lock-keywords
-              '(("^From: \\(.*\\)$" 1  emacspeak-vm-from-voice )
-                ("^To: \\(.*\\)$" 1 emacspeak-vm-to-voice)
-                ("^Subject: \\(.*\\)$" 1 emacspeak-vm-subject-voice)
-                ("^|?[a-zA-Z]*>+\\(.*\\)$" 1 emacspeak-vm-cite-voice )
-                )))
-
-(voice-lock-set-major-mode-keywords 'vm-mode      'vm-voice-lock-keywords)
-
-(voice-lock-set-major-mode-keywords 'vm-summary-mode
-                                    'vm-summary-voice-lock-keywords)
-
 (add-hook 'vm-mode-hook
           'emacspeak-vm-mode-setup)
 
 (defun emacspeak-vm-mode-setup ()
   "Setup function placed on vm-mode-hook by Emacspeak."
-  (declare (special  dtk-punctuation-mode
-                     dtk-allcaps-beep
-                     emacspeak-vm-voice-lock-messages))
-  (setq dtk-punctuation-mode "some")
+  (declare (special  dtk-punctuation-mode emacspeak-vm-voice-lock-messages
+                     dtk-allcaps-beep))
+  (setq dtk-punctuation-mode 'some)
   (when dtk-allcaps-beep
     (dtk-toggle-allcaps-beep))
   (emacspeak-dtk-sync)
   (when emacspeak-vm-voice-lock-messages
-    (condition-case nil
-        (voice-lock-mode 1)
-      (error nil ))))
-
-;;}}}
-;;{{{  vm voices:
-
-(defcustom emacspeak-vm-from-voice  'harry
-  "Personality for From field. "
-  :type 'symbol
-  :group 'emacspeak-vm)
-
-(defcustom emacspeak-vm-to-voice  'paul-animated
-  "Personality for To field. "
-  :type 'symbol
-  :group 'emacspeak-vm)
-(defcustom emacspeak-vm-subject-voice  'paul-smooth 
-  "Personality for Subject field. "
-  :type 'symbol
-  :group 'emacspeak-vm)
-
-(defcustom emacspeak-vm-cite-voice  'paul-smooth
-  "Personality for citation lines. "
-  :type 'symbol
-  :group 'emacspeak-vm)
+    (voice-lock-mode 1)))
 
 ;;}}}
 ;;{{{ inline helpers
@@ -169,6 +119,7 @@ Note that some badly formed mime messages  cause trouble."
 
 ;;}}}
 ;;{{{  Helper functions:
+
 (defvar emacspeak-vm-user-full-name (user-full-name)
   "Full name of user using this session")
 
@@ -182,24 +133,41 @@ Note that some badly formed mime messages  cause trouble."
    (vm-message-pointer
     (dtk-stop)
     (let*  ((message (car vm-message-pointer ))
-            (from (vm-su-from message ))
-            (subject (vm-so-sortable-subject message ))
-            (to (vm-su-to message ))
+            (from (vm-from-of message ))
+            (subject (vm-subject-of  message ))
+            (to (vm-to-of message ))
             (header nil))
       (while (not header)
-	(setq header 
-	      (case
-		  (read-char "f From s Subject t To")
-		(?s subject)
-		(?f from)
-		(?t to))))
+        (setq header
+              (case
+                  (read-char "f From s Subject t To")
+                (?s subject)
+                (?f from)
+                (?t to))))
       (kill-new header)
       (message header)))
    (t (error "No current message." ))))
+(defcustom emacspeak-vm-headers-strip-octals t
+  "Specify whether non-ascii chars should be stripped when
+  speaking email headers."
+  :type 'boolean
+  :group 'emacspeak-vm)
+
+(defun emacspeak-vm-speak-message ()
+  "Move point to the message body."
+  (interactive)
+  (goto-char (point-min))
+  (search-forward  (format "%c%c" 10 10) nil)
+  (condition-case nil
+      (emacspeak-hide-all-blocks-in-buffer)
+    (error nil))
+  (emacspeak-auditory-icon 'large-movement)
+  (emacspeak-speak-rest-of-buffer))
 
 (defun emacspeak-vm-summarize-message ()
   "Summarize the current vm message. "
   (declare (special vm-message-pointer
+                    emacspeak-vm-headers-strip-octals
                     emacspeak-vm-user-full-name emacspeak-vm-user-login-name))
   (when vm-message-pointer
     (dtk-stop)
@@ -208,28 +176,30 @@ Note that some badly formed mime messages  cause trouble."
             (number (emacspeak-vm-number-of  message))
             (from(or (vm-su-full-name message)
                      (vm-su-from message )))
-            (subject (vm-so-sortable-subject message ))
+            (subject (vm-su-subject message ))
             (to(or (vm-su-to-names message)
                    (vm-su-to message )))
             (self-p (or
                      (string-match emacspeak-vm-user-full-name to)
                      (string-match  (user-login-name) to)))
-            (lines (vm-su-line-count message)))
+            (lines (vm-su-line-count message))
+            (summary nil))
       (dtk-speak
-       (format "%s %s %s   %s %s "
-               number
-               (or from "")
-               (if subject (format "on %s" subject) "")
-               (if (and to (< (length to) 80))
-                   (format "to %s" to) "")
-               (if lines (format "%s lines" lines) "")))
-      (cond 
+       (vm-decode-mime-encoded-words-in-string
+        (format "%s %s %s   %s %s "
+                number
+                (or from "")
+                (if subject (format "on %s" subject) "")
+                (if (and to (< (length to) 80))
+                    (format "to %s" to) "")
+                (if lines (format "%s lines" lines) ""))))
+      (cond
        ((and self-p
-             (= 0 self-p)                    ) ;mail to me and others 
+             (= 0 self-p)                    ) ;mail to me and others
         (emacspeak-auditory-icon 'item))
        (self-p                          ;mail to others including me
         (emacspeak-auditory-icon 'mark-object))
-       (t			     ;got it because of a mailing list
+       (t                            ;got it because of a mailing list
         (emacspeak-auditory-icon 'select-object ))))))
 
 (defun emacspeak-vm-speak-labels ()
@@ -238,7 +208,7 @@ Note that some badly formed mime messages  cause trouble."
   (declare (special vm-message-pointer))
   (when vm-message-pointer
     (message "Labels: %s"
-             (vm-su-labels (car vm-message-pointer )))))
+             (vm-labels-of (car vm-message-pointer )))))
 
 (defun emacspeak-vm-mode-line ()
   "VM mode line information. "
@@ -259,7 +229,7 @@ Note that some badly formed mime messages  cause trouble."
        (format "Message %s of %s from virtual folder %s"
                vm-ml-message-number vm-ml-highest-message-number
                (car vm-virtual-folder-definition))))
-     (t (dtk-speak 
+     (t (dtk-speak
          (format "Message %s of %s,    %s %s %s  %s"
                  vm-ml-message-number vm-ml-highest-message-number
                  (if vm-ml-message-new "new" "")
@@ -276,15 +246,12 @@ Note that some badly formed mime messages  cause trouble."
                                     value))
                                  (t "")))))
                   (cdr vm-ml-message-attributes-alist)   " ")))))))
-    
-    
 
 ;;}}}
 ;;{{{  Moving between messages
 
 (add-hook 'vm-select-message-hook
-          (function (lambda nil 
-                      (emacspeak-vm-summarize-message))))
+          'emacspeak-vm-summarize-message)
 
 ;;}}}
 ;;{{{  Scrolling messages:
@@ -294,7 +261,7 @@ Note that some badly formed mime messages  cause trouble."
 Useful when you're reading a message
 that has been forwarded multiple times."
   (interactive)
-  (re-search-forward "^Subject:" nil t )
+  (re-search-forward "^ *Subject:" nil t )
   (emacspeak-speak-line))
 
 (defadvice vm-scroll-forward (after emacspeak pre act)
@@ -357,8 +324,8 @@ Then speak the screenful. "
 (defadvice vm-kill-subject (after emacspeak pre act)
   "Provide auditory feedback. "
   (when (interactive-p)
-    (dtk-speak "Killed this thread ")
-    (emacspeak-auditory-icon 'delete-object)))
+    (emacspeak-auditory-icon 'delete-object)
+    (call-interactively 'vm-next-message)))
 
 ;;}}}
 ;;{{{  Sending mail:
@@ -368,7 +335,6 @@ Then speak the screenful. "
   (if (interactive-p)
       (let ((dtk-stop-immediately nil))
         (message "Forwarding message")
-        (emacspeak-vm-summarize-message)
         ad-do-it
         (emacspeak-speak-line ))
     ad-do-it)
@@ -384,7 +350,7 @@ Then speak the screenful. "
   (when (interactive-p)
     (message "Folluwing up")
     (emacspeak-speak-mode-line)))
-      
+
 (defadvice vm-reply-include-text (after emacspeak pre act)
   "Provide aural feedback."
   (when (interactive-p)
@@ -442,6 +408,7 @@ Then speak the screenful. "
                    emacspeak-keymap))
 (define-key vm-mode-map "C" 'emacspeak-vm-catch-up-all-messages)
 (define-key vm-mode-map "\M-j" 'emacspeak-vm-locate-subject-line)
+(define-key vm-mode-map "," 'emacspeak-vm-speak-message)
 (define-key vm-mode-map "\M-l" 'emacspeak-vm-speak-labels)
 (define-key vm-mode-map
   (concat emacspeak-prefix "m")
@@ -496,7 +463,6 @@ Leave point at front of decoded attachment."
    ((interactive-p)
     (let ((orig (point )))
       ad-do-it
-      (emacspeak-auditory-icon 'task-done)
       (goto-char orig)
       (message "Decoded attachment")))
    (t ad-do-it))
@@ -511,36 +477,54 @@ Leave point at front of decoded attachment."
     ad-do-it))
 
 ;;}}}
-;;{{{ advice password prompt 
+;;{{{ advice password prompt
 
 (defadvice vm-read-password(before emacspeak pre act comp)
   "Speak the prompt"
   (let ((prompt (ad-get-arg 0))
         (confirm (ad-get-arg 1)))
     (emacspeak-auditory-icon 'open-object)
-    (dtk-speak 
+    (dtk-speak
      (format "%s %s"
              prompt
              (if confirm "Confirm by retyping" "")))))
 ;;}}}
 ;;{{{ setup presentation buffer correctly
+
 (add-hook 'vm-presentation-mode-hook
-          (function
-           (lambda nil
-             (emacspeak-pronounce-refresh-pronunciations))))
+          #'(lambda nil
+              (emacspeak-pronounce-refresh-pronunciations)))
+(declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
+(loop for hook in
+      (list 'mail-mode-hook
+            'vm-presentation-mode-hook)
+      do
+      (add-hook hook 'emacspeak-pronounce-refresh-pronunciations
+                'append ))
 
-(emacspeak-pronounce-augment-pronunciations 'vm-presentation-mode
-                                            emacspeak-pronounce-internet-smileys-pronunciations)
-
-(add-hook 'mail-mode-hook
-          'emacspeak-pronounce-refresh-pronunciations)
-          
-
-(emacspeak-pronounce-augment-pronunciations 'mail-mode
-                                            emacspeak-pronounce-internet-smileys-pronunciations)
+(loop for mode in
+      '(vm-presentation-mode
+        mail-mode)
+      do
+      (emacspeak-pronounce-augment-pronunciations mode
+                                                  emacspeak-pronounce-internet-smileys-pronunciations)
+      (emacspeak-pronounce-add-dictionary-entry mode
+                                                emacspeak-speak-embedded-url-pattern
+                                                (cons 're-search-forward
+                                                      #'(lambda
+                                                          (url) "
+      Link ")))
+      (emacspeak-pronounce-add-dictionary-entry mode
+                                                emacspeak-speak-rfc-3339-datetime-pattern
+                                                (cons 're-search-forward
+                                                      'emacspeak-speak-decode-rfc-3339-datetime))
+      (emacspeak-pronounce-add-dictionary-entry mode
+                                                emacspeak-speak-iso-datetime-pattern
+                                                (cons 're-search-forward
+                                                      'emacspeak-speak-decode-iso-datetime)))
 
 ;;}}}
-;;{{{ advice button motion 
+;;{{{ advice button motion
 (defadvice vm-next-button (after emacspeak pre act comp)
   "Provide auditory feedback"
   (when (interactive-p)
@@ -548,67 +532,67 @@ Leave point at front of decoded attachment."
     (emacspeak-speak-text-range  'w3-hyperlink-info)))
 
 ;;}}}
-;;{{{  misc 
+;;{{{  misc
 
 (defadvice vm-count-messages-in-file (around emacspeak-fix pre act comp)
   (ad-set-arg 1 'quiet)
   ad-do-it)
 
 ;;}}}
-;;{{{  button motion in vm 
+;;{{{  button motion in vm
 
 (defun emacspeak-vm-next-button (n)
   "Move point to N buttons forward.
 If N is negative, move backward instead."
   (interactive "p")
   (let ((function (if (< n 0) 'previous-single-property-change
-		    'next-single-property-change))
-	(inhibit-point-motion-hooks t)
-	(backward (< n 0))
-	(limit (if (< n 0) (point-min) (point-max))))
+                    'next-single-property-change))
+        (inhibit-point-motion-hooks t)
+        (backward (< n 0))
+        (limit (if (< n 0) (point-min) (point-max))))
     (setq n (abs n))
     (while (and (not (= limit (point)))
-		(> n 0))
+                (> n 0))
       ;; Skip past the current button.
       (when (get-text-property (point) 'w3-hyperlink-info)
-	(goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
+        (goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
       ;; Go to the next (or previous) button.
       (goto-char (funcall function (point) 'w3-hyperlink-info nil limit))
       ;; Put point at the start of the button.
       (when (and backward (not (get-text-property (point) 'w3-hyperlink-info)))
-	(goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
+        (goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
       ;; Skip past intangible buttons.
       (when (get-text-property (point) 'intangible)
-	(incf n))
+        (incf n))
       (decf n))
     (unless (zerop n)
       (message  "No more buttons"))
     n))
 
 ;;}}}
-;;{{{ saving mime attachment under point 
+;;{{{ saving mime attachment under point
 
 ;;}}}
-;;{{{ configure and customize vm 
+;;{{{ configure and customize vm
 
 ;;; This is how I customize VM
 
 (defcustom emacspeak-vm-use-raman-settings t
   "Should VM  use the customizations used by the author of Emacspeak."
   :type 'boolean
-  :group 'emacspeak)
+  :group 'emacspeak-vm)
 
 (defun emacspeak-vm-use-raman-settings ()
   "Customization settings for VM used by the author of
 Emacspeak."
   (declare (special
             vm-mime-charset-converter-alist
-            vm-mime-default-face-charsets 
-            vm-frame-per-folder 
-            vm-frame-per-composition 
-            vm-frame-per-edit 
-            vm-frame-per-help 
-            vm-frame-per-summary 
+            vm-mime-default-face-charsets
+            vm-frame-per-folder
+            vm-frame-per-composition
+            vm-frame-per-edit
+            vm-frame-per-help
+            vm-frame-per-summary
             vm-index-file-suffix
             vm-primary-inbox
             vm-folder-directory
@@ -622,16 +606,16 @@ Emacspeak."
             vm-move-after-deleting
             emacspeak-vm-voice-lock-messages))
   (setq vm-mime-charset-converter-alist
-	'(
-	  ("utf-8" "iso-8859-1" "iconv -f utf-8 -t iso-8859-1")
-	  )
-	)
+        '(
+          ("utf-8" "iso-8859-1" "iconv -f utf-8 -t iso-8859-1")
+          )
+        )
   (setq vm-mime-default-face-charsets t)
   (setq vm-frame-per-folder nil
-	vm-frame-per-composition nil
-	vm-frame-per-edit nil
-	vm-frame-per-help nil
-	vm-frame-per-summary nil)
+        vm-frame-per-composition nil
+        vm-frame-per-edit nil
+        vm-frame-per-help nil
+        vm-frame-per-summary nil)
 
   (setq vm-index-file-suffix ".idx"
         vm-primary-inbox "~/mbox"
@@ -644,9 +628,9 @@ Emacspeak."
         vm-url-browser 'browse-url
         vm-confirm-new-folders t
         vm-move-after-deleting nil
-        emacspeak-vm-voice-lock-messages nil)
+        emacspeak-vm-voice-lock-messages t)
   t)
-  
+
 (when emacspeak-vm-use-raman-settings
   (emacspeak-vm-use-raman-settings))
 
@@ -669,6 +653,12 @@ text using pdftotext."
 text using wvText."
   :type 'string
   :group 'emacspeak-vm)
+(defcustom emacspeak-vm-cal2text
+  (expand-file-name "cal2text" emacspeak-etc-directory)
+  "Executable that converts calendar invitations    on
+  standard input to plain text."
+  :type 'string
+  :group 'emacspeak-vm)
 
 (defcustom emacspeak-vm-xls2html
   (expand-file-name "xls2html" emacspeak-etc-directory)
@@ -692,26 +682,28 @@ text using wvText."
        #'(lambda  (i)
            (string-equal (car i) (car convertor)))
        vm-mime-type-converter-alist)
-    (push   convertor 
+    (push   convertor
             vm-mime-type-converter-alist)))
 
 (defun emacspeak-vm-customize-mime-settings ()
   "Customize VM mime settings."
-  (declare (special
-            vm-preview-lines
-            vm-infer-mime-types
-            vm-mime-decode-for-preview
-            vm-auto-decode-mime-messages
-            vm-auto-displayed-mime-content-type-exceptions
-            vm-mime-attachment-save-directory
-            vm-mime-base64-encoder-program
-            vm-mime-base64-decoder-program
-            vm-mime-attachment-auto-type-alist
-            vm-mime-type-converter-alist
-            emacspeak-vm-pdf2text
-            emacspeak-vm-ppt2html
-            emacspeak-vm-xls2html
-            emacspeak-vm-doc2text))
+  (declare (special vm-preview-lines
+                    vm-infer-mime-types
+                    vm-mime-decode-for-preview
+                    vm-auto-decode-mime-messages
+                    vm-auto-displayed-mime-content-type-exceptions
+                    vm-mime-attachment-save-directory
+                    vm-mime-base64-encoder-program
+                    vm-mime-base64-decoder-program
+                    vm-mime-attachment-auto-type-alist
+                    vm-mime-type-converter-alist
+                    emacspeak-vm-pdf2text
+                    emacspeak-vm-ppt2html
+                    emacspeak-vm-xls2html
+                    emacspeak-vm-doc2text
+                    emacspeak-vm-cal2text))
+  (emacspeak-vm-add-mime-convertor
+   (list "text/calendar" "text/plain" emacspeak-vm-cal2text))
   (emacspeak-vm-add-mime-convertor
    (list "application/pdf" "text/plain"
          emacspeak-vm-pdf2text))
@@ -731,7 +723,6 @@ text using wvText."
         vm-mime-base64-encoder-program "base64-encode"
         vm-mime-base64-decoder-program "base64-decode")
   t)
-   
 
 (when emacspeak-vm-customize-mime-settings
   (emacspeak-vm-customize-mime-settings))
@@ -743,6 +734,6 @@ text using wvText."
 ;;; local variables:
 ;;; folded-file: t
 ;;; byte-compile-dynamic: t
-;;; end: 
+;;; end:
 
 ;;}}}
