@@ -1,6 +1,6 @@
 ;;; emacspeak-widget.el --- Speech enable Emacs' native GUI widget library
-;;; $Id: emacspeak-widget.el,v 17.0 2002/11/23 01:29:01 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-widget.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak extensions to widgets
 ;;; Keywords:emacspeak, audio interface to emacs customized widgets
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:01 $ |
-;;;  $Revision: 17.0 $ | 
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -49,20 +49,15 @@
 
 ;;; Code:
 
-(eval-when-compile (require 'cl))
+(require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'custom)
-(eval-when-compile (require 'dtk-speak)
-                   (condition-case nil
-                       (progn (require 'widget)
-                              (require 'wid-edit)
-                              (message "Compiling against widget libraries %s %s"
-                                       (locate-library "widget")
-                                       (locate-library "wid-edit")))
-                     (error
-                      (message  "Widget libraries not found, widget support may not work correctly.")))
-                   (require 'emacspeak-speak)
-                   (require 'emacspeak-sounds))
+(require 'voice-setup)
+(require 'dtk-speak)
+(require 'widget)
+(require 'wid-edit)
+(require 'emacspeak-speak)
+(require 'emacspeak-sounds)
 
 ;;}}}
 ;;{{{  Customize global behavior
@@ -70,55 +65,43 @@
 (defgroup emacspeak-widget nil
   "Widgets on the Emacspeak Desktop."
   :group 'emacspeak
-  :group 'widgets
-  :prefix "emacspeak-widget-")
-(defcustom emacspeak-widget-edit-personality  'paul-smooth
-  "Personality for edit fields"
-  :group 'emacspeak-widget
-  :type 'symbol)
+  :group 'widget
+  :prefix "emacspeak-widget")
 
-(defcustom emacspeak-widget-value-personality 'paul-smooth
-  "Personality for values"
-  :group 'emacspeak-widget
-  :type 'symbol)
-
-(defcustom emacspeak-widget-button-personality 'harry
-  "Personality for buttons"
-  :group 'emacspeak-widget
-  :type 'symbol)
-
-(defcustom emacspeak-widget-documentation-personality 'paul-monotone
-  "Personality for documentation"
-  :group 'emacspeak-widget
-  :type 'symbol)
-
-(defcustom emacspeak-widget-inactive-personality  'betty
-  "Personality for inactive fields"
-  :group 'emacspeak-widget
-  :type 'symbol)
+(voice-setup-add-map
+ '(
+   (widget-field voice-smoothen)
+   (widget-single-line-field voice-smoothen)
+   (widget-button voice-bolden)
+   (widget-button-pressed voice-bolden-extra)
+   (widget-documentation voice-smoothen-extra)
+   (widget-inactive voice-lighten)
+   ))
 
 (declaim (special widget-menu-minibuffer-flag))
 (setq  widget-menu-minibuffer-flag t)
 
-(define-widget-keywords :emacspeak-help
-  :caption)
-
 ;;}}}
 ;;{{{  helpers 
 
 (defsubst emacspeak-widget-label (w)
   "Construct a label for a widget.
 Returns a string with appropriate personality."
-  (let ((type   (widget-type w))
+  (let ((inhibit-read-only t)
+        (type   (widget-type w))
         (tag (widget-get w :tag)))
-    (unless tag (setq tag (format " %s " type)))
+    (setq tag     
+          (format " %s "
+                  (or tag type)))
     (put-text-property 0 (length tag)
-                       'personality emacspeak-widget-button-personality tag)
+                       'personality 'emacspeak-widget-button-personality tag)
     tag))
 
 (defsubst emacspeak-widget-help-echo (w)
   "Return help-echo with appropriate personality."
-  (let ((h (widget-get w :help-echo))
+  (declare (special voice-animate))
+  (let ((inhibit-read-only t)
+        (h (widget-get w :help-echo))
         (help nil))
     (setq help
           (cond
@@ -130,7 +113,7 @@ Returns a string with appropriate personality."
            (t nil)))
     (when help
       (put-text-property 0 (length help)
-                         'personality 'paul-animated help)
+                         'personality voice-animate help)
       help)))
 
 ;;}}}
@@ -152,7 +135,7 @@ Returns a string with appropriate personality."
                            parent-help))
      (w (message (format " %s " type)))
      (t (message " Not on a widget. ")))))
-        
+;;;###autoload        
 (defun emacspeak-widget-summarize-parent ()
   "Summarize parent of widget at point."
   (interactive)
@@ -163,12 +146,11 @@ Returns a string with appropriate personality."
      (t (message "Widget at point has no parent")))))
 
 ;;; Find summarizer for a specific widget type and dispatch.
-
+;;;###autoload
 (defun emacspeak-widget-summarize(widget)
   "Summarize specified widget."
   (let ((emacspeak-help (widget-get widget :emacspeak-help))
-        (emacspeak-speak-messages nil)
-        (voice-lock-mode t))
+        (emacspeak-speak-messages nil))
     (cond
      ((and emacspeak-help
            (fboundp emacspeak-help))
@@ -181,10 +163,11 @@ Returns a string with appropriate personality."
 ;;{{{  widget specific summarizers  --as per Per's suggestion
 
 ;;{{{  default
-
+;;;###autoload 
 (defun emacspeak-widget-default-summarize (widget)
   "Fall back summarizer for all widgets"
-  (let* ((label (emacspeak-widget-label widget))
+  (let* ((inhibit-read-only t)
+         (label (emacspeak-widget-label widget))
          (help-echo (emacspeak-widget-help-echo widget))
          (v  (widget-value widget ))
          (value
@@ -193,7 +176,7 @@ Returns a string with appropriate personality."
            (t (prin1-to-string v 'no-escape)))))
     (when  value
       (put-text-property 0 (length value)
-                         'personality emacspeak-widget-value-personality value))
+                         'personality voice-bolden value))
     (concat label
             help-echo
             value)))
@@ -224,7 +207,7 @@ Returns a string with appropriate personality."
 ;;{{{ item 
 
 (defun emacspeak-widget-help-item (widget)
-  "Summarize a  item"
+  "Summarize an   item"
   (let* ((value  (widget-value widget))
          (label (emacspeak-widget-label widget))
          (help-echo (emacspeak-widget-help-echo widget)))
@@ -371,7 +354,7 @@ Returns a string with appropriate personality."
   (let ((value (widget-get widget :value))
         (tag (widget-get widget :tag)))
     (format "Commentary  link   %s %s"
-	    (or tag "")
+            (or tag "")
             value)))
 
 (widget-put (get 'emacs-commentary-link 'widget-type)
@@ -382,8 +365,7 @@ Returns a string with appropriate personality."
 
 (defun emacspeak-widget-help-menu-choice  (widget)
   "Summarize a pull down list"
-  (let* (
-         (help-echo (emacspeak-widget-help-echo widget))(label (emacspeak-widget-label widget))
+  (let* ((help-echo (emacspeak-widget-help-echo widget))(label (emacspeak-widget-label widget))
          (value (format " %s " (widget-get widget :value)))
          (child (car (widget-get widget :children))))
     (concat label
@@ -417,13 +399,14 @@ Returns a string with appropriate personality."
 
 (defun emacspeak-widget-help-checklist  (widget)
   "Summarize a check list"
-  (let* ((label (emacspeak-widget-label widget))
+  (let* ((inhibit-read-only t)
+         (label (emacspeak-widget-label widget))
          (value (widget-value widget))
          (selections (cond
                       (value (prin1-to-string value))
                       (t " no items  "))))
     (put-text-property 0  (length selections)
-                       'personality emacspeak-widget-value-personality selections)
+                       'personality voice-bolden selections)
     (concat label
             " has "
             selections 
@@ -494,17 +477,18 @@ Returns a string with appropriate personality."
 
 (defun emacspeak-widget-help-radio-button-choice  (widget)
   "Summarize a radio group "
-  (let* ((value (widget-value widget))
+  (let* ((inhibit-read-only t)
+         (value (widget-value widget))
          (label (emacspeak-widget-label widget))
          (choice (widget-get widget :choice))
          (selected
           (cond
            (choice (widget-get choice :tag))
            (t (if value 
-		  (prin1-to-string value)
-		" no item ")))))
+                  (prin1-to-string value)
+                " no item ")))))
     (put-text-property 0  (length selected)
-                       'personality emacspeak-widget-value-personality selected)
+                       'personality voice-bolden selected)
     (concat label
             " is "
             selected)))
@@ -517,12 +501,13 @@ Returns a string with appropriate personality."
 
 (defun emacspeak-widget-help-editable-list (widget)
   "Summarize a editable list"
-  (let ((value (prin1-to-string (widget-value widget)))
+  (let ((inhibit-read-only t)
+        (value (prin1-to-string (widget-value widget)))
         (label (emacspeak-widget-label widget))
         (help-echo (emacspeak-widget-help-echo widget)))
     (when value
       (put-text-property 0 (length value)
-                         'personality emacspeak-widget-value-personality value))
+                         'personality voice-bolden value))
     (concat label
             help-echo
             (or value ""))))
@@ -611,30 +596,6 @@ Returns a string with appropriate personality."
      (t ad-do-it))
     ad-return-value))
 
-;;}}}
-;;{{{ voice lock widget buffers:
-
-(defadvice widget-specify-field-update (after emacspeak pre act comp)
-  "Voiceify the field"
-  (put-text-property (ad-get-arg 1) (ad-get-arg 2)
-                     'personality
-                     emacspeak-widget-edit-personality))
-
-(defadvice  widget-specify-inactive(after emacspeak pre act comp)
-  "Voiceify the field"
-  (put-text-property (ad-get-arg 1) (ad-get-arg 2)
-                     'personality emacspeak-widget-inactive-personality))
-
-(defadvice widget-specify-button (after emacspeak pre act  comp)
-  "Voiceify the button"
-  (put-text-property (ad-get-arg 1) (ad-get-arg 2)
-                     'personality emacspeak-widget-button-personality))  
-
-(defadvice widget-specify-doc (after emacspeak pre act comp)
-  "Voiceify the documentation of a widget"
-  (put-text-property (ad-get-arg 1) (ad-get-arg 2)
-                     'personality emacspeak-widget-documentation-personality))
-
 ;;}}}
 ;;{{{  Interactively summarize a widget and its parents.
 
@@ -681,7 +642,8 @@ widget before summarizing."
 
 (defadvice widget-convert-text (around emacspeak pre act comp)
   "Protect value of personality if set originally"
-  (let ((start (ad-get-arg 1))
+  (let ((inhibit-read-only t)
+        (start (ad-get-arg 1))
         (end (ad-get-arg 2))
         (orig nil ))
     (setq orig (get-text-property start 'personality))
@@ -701,11 +663,11 @@ widget before summarizing."
   (loop for map in
         (list widget-keymap
               widget-field-keymap
-					;widget-text-keymap
+              widget-text-keymap
               )
         do
         (define-key map  emacspeak-prefix 'emacspeak-prefix-command)
-        (define-key map  "\C-ee" 'widget-end-of-line)
+        (define-key map  "\C-e\C-e" 'widget-end-of-line)
         (define-key map "\M-h" 'emacspeak-widget-help)
         (define-key map "\M-p" 'emacspeak-widget-summarize-parent)
         (define-key map "\M-\C-m"
@@ -740,18 +702,21 @@ widget before summarizing."
 (define-widget 'voice  'menu-choice
   :help-echo "Voice selector"
   "Widget for selecting a voice.")
-
 (define-widget 'personality 'item
   "Individual voice in a voice selector.")
+;;; We rely on dectalk-voice-table as our default voice table.
+;;; Names defined in this --- and other voice tables --- are
+;;; generic --and  not device specific.
+;;;
 
 (defun emacspeak-widget-create-voice-selector ()
   "Create a suitable voice selector widget."
-  (declare (special dtk-voice-table))
+  (declare (special dectalk-voice-table))
   (let ((w
          (widget-create 'voice
                         :tag "voices")))
     (widget-put w :args 
-                (loop for key being the hash-keys of dtk-voice-table 
+                (loop for key being the hash-keys of dectalk-voice-table 
                       collect
                       (list 'personality :value key )))
     w))
