@@ -1,6 +1,6 @@
 ;;; emacspeak-xml-shell.el --- Implements a simple XML browser
-;;; $Id: emacspeak-xml-shell.el,v 17.0 2002/11/23 01:29:01 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-xml-shell.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Contains  xml-shell
 ;;; Keywords: Emacspeak,  Audio Desktop Xml-Shell
 ;;{{{  LCD Archive entry:
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:01 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2002, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -49,22 +49,14 @@
 ;;}}}
 ;;{{{  Required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(require 'custom)
+(require 'emacspeak-preamble)
 (require 'comint)
-(require 'voice-lock)
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
-(require 'emacspeak-wizards)
-(require 'derived)
-
 ;;}}}
 ;;{{{ Customizations
-
+;;;###autoload
 (defgroup emacspeak-xml-shell nil
-  "XML browser for the Emacspeak desktop.")
+  "XML browser for the Emacspeak desktop."
+  :group 'emacspeak)
 
 (defcustom emacspeak-xml-shell-command "xmllint"
   "Executable that provides the XML browser shell.
@@ -112,9 +104,9 @@ Interactive XML browser.
                        emacspeak-xml-shell-command
                        nil
                        (append emacspeak-xml-shell-options
-			       (if (string-match ".html?$" system-id)
-				   (list "--html")
-				 nil )
+                               (if (string-match ".html?$" system-id)
+                                   (list "--html")
+                                 nil )
                                (list system-id)))))
     (save-excursion
       (set-buffer buffer)
@@ -130,7 +122,7 @@ Interactive XML browser.
   "Process sentinel for XML shell."
   (declare (special emacspeak-xml-shell-document))
   (setq emacspeak-xml-shell-document nil))
-
+;;;###autoload
 (defun emacspeak-xml-shell (system-id)
   "Start Xml-Shell on contents of system-id."
   (interactive
@@ -272,7 +264,9 @@ region of text to process."
 
 (defcustom emacspeak-xml-shell-xslt nil
   "XSL transform to apply when displaying current node."
-  :type 'string
+  :type '(choice
+          (const :tag "None" nil)
+          (string :tag "Command"))
   :group 'emacspeak-xml-shell)
 
 (defsubst emacspeak-xml-shell-setup-html-base (base)
@@ -281,7 +275,7 @@ HTML head if none found."
   (goto-char (point-min))
   (let ((head   (search-forward "<head>" nil t)))
     (or head
-	(insert "<head>\n"))
+        (insert "<head>\n"))
     (insert
      (format "<base href=\"%s\">\n" base))
     (or head (insert "</head>\n"))))
@@ -293,8 +287,13 @@ HTML head if none found."
     (emacspeak-xslt-region
      emacspeak-xml-shell-xslt
      start end))
-  (emacspeak-xml-shell-setup-html-base emacspeak-xml-shell-document)
-  (emacspeak-w3-preview-this-buffer)
+  (emacspeak-xml-shell-setup-html-base
+   emacspeak-xml-shell-document)
+  (save-excursion
+    (goto-char (point-min))
+    (while (search-forward "-------" nil t)
+      (replace-match "<br>")))
+  (browse-url-of-buffer)
   (setq emacspeak-xml-shell-display-buffer (current-buffer)))
 
 (defun emacspeak-xml-shell-browse-current ()
@@ -310,8 +309,7 @@ HTML head if none found."
   (interactive "sXPath:")
   (declare (special emacspeak-xml-shell-display-buffer))
   (emacspeak-xml-shell-process-node xpath 
-                                    'emacspeak-xml-shell-display-as-html)
-  (switch-to-buffer emacspeak-xml-shell-display-buffer))
+                                    'emacspeak-xml-shell-display-as-html))
 
 ;;}}}
 ;;{{{ keybindings
