@@ -1,6 +1,6 @@
 ;;; emacspeak-xslt-process.el --- speech-enable xslt-process 
-;;; $Id: emacspeak-xslt-process.el,v 17.0 2002/11/23 01:29:01 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-xslt-process.el 4074 2006-08-19 17:48:45Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for speech-enabling
 ;;; xslt-process mode
 ;;; Keywords: Emacspeak, xslt-process
@@ -9,8 +9,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:01 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2006-08-19 10:48:45 -0700 (Sat, 19 Aug 2006) $ |
+;;;  $Revision: 4074 $ |
 ;;; Location undetermined
 ;;;
 
@@ -41,14 +41,7 @@
 
 ;;{{{ required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'emacspeak-speak)
-(require 'voice-lock)
-(require 'voice-settings)
-(require 'emacspeak-sounds)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
 
@@ -84,16 +77,16 @@
     (emacspeak-speak-mode-line)))
 
 (defadvice xslt-process-invoke-browser-view (after emacspeak
-						   pre act
-						   comp)
+                                                   pre act
+                                                   comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'task-done)
     (emacspeak-speak-mode-line)))
 
 (defadvice xslt-process-invoke-pdf-viewer (after emacspeak
-						 pre act
-						 comp)
+                                                 pre act
+                                                 comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (emacspeak-auditory-icon 'task-done)
@@ -112,11 +105,11 @@
          (put-text-property start end
                             'auditory-icon 'mark-object)
          (put-text-property start end
-                            'personality 'paul-animated))
+                            'personality voice-animate))
         (emacspeak-speak-line)
         (emacspeak-auditory-icon 'mark-object)))))
 (defadvice xslt-process-remove-breakpoint (after emacspeak pre
-						 act comp)
+                                                 act comp)
   "Provide auditory feedback."
   (when (interactive-p)
     (save-excursion
@@ -150,28 +143,28 @@
     (emacspeak-speak-line)))
 
 (defadvice xslt-process-do-finish (after emacspeak pre act
-					 comp)
+                                         comp)
   "Provide auditory feedback."
   (when (interactive-p)
     
 
     (defadvice xslt-process-do-continue (after emacspeak pre act
-					       comp)
+                                               comp)
       "Provide auditory feedback."
       (when (interactive-p)
-	(emacspeak-auditory-icon 'select-object)))
+        (emacspeak-auditory-icon 'select-object)))
 
     (defadvice xslt-process-do-stop (after emacspeak pre act
-					   comp)
+                                           comp)
       "Provide auditory feedback."
       (when (interactive-p)
-	(emacspeak-auditory-icon 'select-object)))
+        (emacspeak-auditory-icon 'select-object)))
 
     (defadvice xslt-process-do-quit (after emacspeak pre act
-					   comp)
+                                           comp)
       "Provide auditory feedback."
       (when (interactive-p)
-	(emacspeak-auditory-icon 'select-object)))
+        (emacspeak-auditory-icon 'select-object)))
 
     (emacspeak-auditory-icon 'close-object)))
 
