@@ -1,13 +1,13 @@
 ;;; html-outline.el --- Extends html-helper-mode to provide outline and imenu support
 ;;; Author: T. V. Raman
-;;; $Id: html-outline.el,v 17.0 2002/11/23 01:29:01 raman Exp $
+;;; $Id: html-outline.el 4047 2006-08-11 19:11:17Z tv.raman.tv $
 ;;; Description: Outlining for HTML helper mode
 ;;; Implements the necessary extensions to make outline minor mode recognize
 ;;; html markup.
 ;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(eval-when-compile (require 'cl))
+(require 'cl)
 ;;{{{  outline help
 
 ;;; Inspired by out-xtra.el (part of auctex)
@@ -18,11 +18,11 @@
   (save-excursion
     (looking-at outline-regexp)
     (skip-chars-forward "<hH ")
-    (string-to-int (buffer-substring (point) (+ 1 (point))))))
+    (string-to-number (buffer-substring (point) (+ 1 (point))))))
 
 (declaim (special outline-level))
 (add-hook 'html-helper-mode-hook
-	  (function (lambda ()
+          (function (lambda ()
                       (require 'outline)
                       (make-local-variable 'outline-regexp)
                       (setq outline-regexp  "[\t ]*<[hH][1-6][]*>.*<\/[hH]")
@@ -38,14 +38,14 @@
  (function
   (lambda ()
     (declare (special imenu-generic-expression
-		      imenu-create-index-function))
+                      imenu-create-index-function))
     (require 'imenu)
     (setq imenu-create-index-function 'imenu-default-create-index-function)
     (setq imenu-generic-expression
-	  '(
-	    (nil
-	     "^ *<[hH][1-6] *><[aA][^>]+>\\(.*\\)</[aA]></[hH][1-6]>" 1)
-	    (nil "^ *<[hH][1-6] *>\\([^<]*\\)</[hH][1-6]>" 1))))))
+          '(
+            (nil
+             "^ *<[hH][1-6] *><[aA][^>]+>\\(.*\\)</[aA]></[hH][1-6]>" 1)
+            (nil "^ *<[hH][1-6] *>\\([^<]*\\)</[hH][1-6]>" 1))))))
 
 ;;}}}
 (provide 'html-outline)
